@@ -24,9 +24,9 @@
 #include "i18n.h"
 #include "calendar.h"
 #include "calendar_utils.h"
+#include "utils.h"
 #include "options_prefs.h"
 #include "stock_icons.h"
-#include "gui_utils.h"
 
 /*------------------------------------------------------------------------------*/
 
@@ -66,9 +66,9 @@ date_calculator_key_press_cb (GtkWidget *widget, GdkEventKey *event, gpointer us
 void
 set_current_date (GtkWidget *year, GtkWidget *month, GtkWidget *day)
 {
-    gtk_spin_button_set_value (GTK_SPIN_BUTTON (year), get_current_year ());
-    gtk_spin_button_set_value (GTK_SPIN_BUTTON (month), get_current_month () + 1);
-    gtk_spin_button_set_value (GTK_SPIN_BUTTON (day), get_current_day ());
+    gtk_spin_button_set_value (GTK_SPIN_BUTTON (year), utl_get_current_year ());
+    gtk_spin_button_set_value (GTK_SPIN_BUTTON (month), utl_get_current_month ());
+    gtk_spin_button_set_value (GTK_SPIN_BUTTON (day), utl_get_current_day ());
 }
 
 /*------------------------------------------------------------------------------*/
@@ -335,7 +335,7 @@ gchar tmpbuf[BUFFER_SIZE];
             day = n;
         }
 
-        julian = date_to_julian (day, month, year);
+        julian = utl_dmy_to_julian (day, month + 1, year);
 
         second += second2;
         minute += minute2 + second / 60;
@@ -364,7 +364,7 @@ gchar tmpbuf[BUFFER_SIZE];
                 day = n;
             }
 
-            julian = date_to_julian (day, month, year);
+            julian = utl_dmy_to_julian (day, month + 1, year);
 
             minute2 += second2 / 60;
             second -= second2 % 60;
@@ -426,7 +426,7 @@ GDate *cdate;
 	cdate = g_date_new_julian (appGUI->cal->julian_jumpto);
 	g_return_if_fail (cdate != NULL);
 
-	calendar_jump_to_date (cdate, appGUI);
+	cal_jump_to_date (cdate, appGUI);
 	update_aux_calendars (appGUI);
 
 	window_date_calculator_close_cb (GTK_WIDGET (button), NULL, user_data);
