@@ -21,7 +21,7 @@
 
 #include "calendar_fullyear.h"
 #include "i18n.h"
-#include "gui_utils.h"
+#include "utils.h"
 #include "options_prefs.h"
 #include "calendar.h"
 #include "calendar_notes.h"
@@ -55,19 +55,15 @@ button_fullyear_window_close_cb (GtkButton *button, gpointer user_data)
 void
 select_date_day_cb (GtkWidget *widget, gpointer user_data)
 {
-guint year, month, day;
-GDate *cdate;
+GDate *date;
 
 	MESSAGE *msg = (MESSAGE *) user_data;
-	cdate = g_date_new_julian ((guint32) msg->data);
-	g_return_if_fail (cdate != NULL);
+	date = g_date_new_julian ((guint32) msg->data);
+	g_return_if_fail (date != NULL);
 
-	day = g_date_get_day (cdate);
-	month = g_date_get_month (cdate);
-	year = g_date_get_year (cdate);
-	g_date_free (cdate);
+	cal_jump_to_date (date, msg->appGUI);
+	g_date_free (date);
 
-	jump_to_date (day, month - 1, year, msg->appGUI);
 	update_aux_calendars (msg->appGUI);
 	fullyear_window_close_cb (GTK_WIDGET (widget), NULL, msg->appGUI);
 }
@@ -160,12 +156,8 @@ gchar tmpbuf[BUFFER_SIZE], tmpbuf2[BUFFER_SIZE];
 void
 change_to_current_year_cb (GtkWidget *widget, gpointer user_data)
 {
-guint current_year;
-
 	GUI *appGUI = (GUI *) user_data;
-
-	current_year = get_gdate_current_year ();
-	gtk_spin_button_set_value (GTK_SPIN_BUTTON (appGUI->cal->fy_spinbutton), current_year);
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON (appGUI->cal->fy_spinbutton), utl_get_current_year ());
 }
 
 /*------------------------------------------------------------------------*/
@@ -209,7 +201,7 @@ guint i, month, year;
 
 	year = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (spinbutton));
 
-	if (year == get_gdate_current_year ()) {
+	if (year == utl_get_current_year ()) {
 		gtk_widget_set_sensitive (appGUI->cal->cyear_button, FALSE);
 	} else {
 		gtk_widget_set_sensitive (appGUI->cal->cyear_button, TRUE);
@@ -226,19 +218,6 @@ guint i, month, year;
 
 /*------------------------------------------------------------------------*/
 
-#ifdef HAVE_LIBICAL
-
-void
-browse_ical_events_cb (GtkWidget *widget, gpointer user_data)
-{
-	GUI *appGUI = (GUI *) user_data;
-	ical_events_browser (appGUI);
-}
-
-#endif  /* HAVE_LIBICAL */
-
-/*------------------------------------------------------------------------------*/
-
 gint
 fullyear_key_press_cb (GtkWidget *widget, GdkEventKey *event, gpointer user_data)
 {
@@ -267,15 +246,15 @@ gchar tmpbuf[BUFFER_SIZE];
 	w_days = 0;
 
 	for (month = G_DATE_JANUARY; month <= G_DATE_DECEMBER; month++) {
-		w_days += get_weekend_days (month, year);
+		w_days += utl_get_weekend_days_in_month_my (month, year);
 	}
 
-	g_snprintf (tmpbuf, BUFFER_SIZE, "%s: %d\n%s: %s\n\n%s: %s\n\n%s: %d\n%s: %d\n%s: %d (%.1f%%)",
+	g_snprintf (tmpbuf, BUFFER_SIZE, "<b>%s</b>: %d\n<b>%s</b>: %s\n\n<b>%s</b>: %s\n\n<b>%s</b>: %d\n<b>%s</b>: %d\n<b>%s</b>: %d (%.1f%%)",
 	            _("Year"), year, _("Leap year"), g_date_is_leap_year (year) ? _("Yes"):_("No"),
 	            _("Chinese year animal"), get_chinese_year_name (year),
-	            _("Number of days"), get_days_per_year (year),
+	            _("Number of days"), utl_get_days_per_year (year),
 	            _("Number of weeks"), weeks_in_year (year),
-	            _("Number of weekend days"), w_days, (double) w_days / get_days_per_year (year) * 100.0);
+	            _("Number of weekend days"), w_days, (double) w_days / utl_get_days_per_year (year) * 100.0);
 
 	gui_create_dialog (GTK_MESSAGE_INFO, tmpbuf, GTK_WINDOW (appGUI->cal->fullyear_window));
 }
@@ -318,9 +297,6 @@ GtkWidget   *fycal_alternative_view_checkbutton;
 GtkWidget   *vseparator;
 GtkWidget   *label;
 GtkWidget   *fycal_label, *fycal_vbox;
-#ifdef HAVE_LIBICAL
-GtkWidget   *button;
-#endif  /* HAVE_LIBICAL */
 gchar       tmpbuf[BUFFER_SIZE], buffer[BUFFER_SIZE];
 gint        i, j, x, y, idx;
 GDate       *cdate;
@@ -357,7 +333,7 @@ guint       month, year;
 	gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
 	gtk_misc_set_padding (GTK_MISC (label), 0, 4);
 
-	fy_spinbutton_adj = gtk_adjustment_new (get_gdate_current_year (), JULIAN_GREGORIAN_YEAR, 9999, 1, 10, 10);
+	fy_spinbutton_adj = gtk_adjustment_new (utl_get_current_year (), JULIAN_GREGORIAN_YEAR, 9999, 1, 10, 10);
 	appGUI->cal->fy_spinbutton = gtk_spin_button_new (GTK_ADJUSTMENT (fy_spinbutton_adj), 1, 0);
 	gtk_widget_show (appGUI->cal->fy_spinbutton);
 	g_signal_connect(appGUI->cal->fy_spinbutton, "value-changed", G_CALLBACK(change_year_spin_button_cb), appGUI);
@@ -430,18 +406,6 @@ guint       month, year;
 	gtk_box_pack_start (GTK_BOX (hbox1), fycal_alternative_view_checkbutton, FALSE, FALSE, 2);
 	gtk_widget_show (fycal_alternative_view_checkbutton);
 
-#ifdef HAVE_LIBICAL
-
-	if (appGUI->calendar_only == FALSE) {
-		button = gtk_button_new_with_label (_("Browse iCal events"));
-		GTK_WIDGET_UNSET_FLAGS(button, GTK_CAN_FOCUS);
-		gtk_widget_show (button);
-		gtk_box_pack_end (GTK_BOX (hbox1), button, FALSE, FALSE, 2);
-		g_signal_connect (button, "clicked", G_CALLBACK (browse_ical_events_cb), appGUI);
-	}
-
-#endif  /* HAVE_LIBICAL */
-
 	fycal_scrolledwindow = gtk_scrolled_window_new (NULL, NULL);
 	gtk_widget_show (fycal_scrolledwindow);
 	gtk_box_pack_start (GTK_BOX (vbox1), fycal_scrolledwindow, TRUE, TRUE, 0);
@@ -606,7 +570,7 @@ guint       month, year;
 		}
 	}
 
-	display_calendar (get_current_year (), appGUI);
+	display_calendar (utl_get_current_year (), appGUI);
 	gtk_widget_set_sensitive (appGUI->cal->cyear_button, FALSE);
 
 	/*-------------------------------------------------------------------------------------*/
