@@ -22,13 +22,36 @@
 
 #include "calendar_notes.h"
 #include "i18n.h"
-#include "gui_utils.h"
+#include "utils.h"
 #include "options_prefs.h"
 #include "calendar.h"
 #include "stock_icons.h"
 
 /*------------------------------------------------------------------------------*/
 
+gboolean
+cal_check_note (GDate *date, GUI *appGUI)
+{
+GSList *lnode;
+struct note *a;
+gint i;
+
+	if (appGUI->cal->notes_list != NULL) {
+
+		for (i = 0, lnode = appGUI->cal->notes_list; lnode != NULL; lnode = lnode->next, i++) {
+			a = g_slist_nth_data (appGUI->cal->notes_list, i);
+
+			if (a->date == g_date_get_julian (date))
+				return TRUE;
+		}
+
+	}
+
+    return FALSE;
+}
+
+/*------------------------------------------------------------------------------*/
+
 gboolean
 check_note (guint day, guint month, guint year, GUI *appGUI) {
 
@@ -52,6 +75,29 @@ gint i;
 
 /*------------------------------------------------------------------------------*/
 
+gchar *
+cal_get_note (GDate *date, GUI *appGUI)
+{
+GSList *lnode;
+struct note *a;
+gint i;
+
+	if (appGUI->cal->notes_list != NULL) {
+
+		for (i = 0, lnode = appGUI->cal->notes_list; lnode != NULL; lnode = lnode->next, i++) {
+			a = g_slist_nth_data (appGUI->cal->notes_list, i);
+
+			if (a->date == g_date_get_julian (date))
+				return a->note;
+		}
+
+	}
+
+    return NULL;
+}
+
+/*------------------------------------------------------------------------------*/
+
 gchar *
 get_note (guint day, guint month, guint year, GUI *appGUI) {
 
@@ -82,6 +128,29 @@ gint i;
 
 /*------------------------------------------------------------------------------*/
 
+gchar *
+cal_get_note_color (GDate *date, GUI *appGUI)
+{
+GSList *lnode;
+struct note *a;
+gint i;
+
+	if (appGUI->cal->notes_list != NULL) {
+
+		for (i = 0, lnode = appGUI->cal->notes_list; lnode != NULL; lnode = lnode->next, i++) {
+			a = g_slist_nth_data (appGUI->cal->notes_list, i);
+
+			if (a->date == g_date_get_julian (date))
+				return a->color;
+		}
+
+	}
+
+    return NULL;
+}
+
+/*------------------------------------------------------------------------------*/
+
 gchar *
 get_color (guint day, guint month, guint year, GUI *appGUI) {
 
@@ -113,327 +182,292 @@ gint i;
 /*------------------------------------------------------------------------------*/
 
 void
-replace_note_color (gchar *old_color, gchar *new_color, GUI *appGUI) {
-
+cal_replace_note_color (gchar *old_color, gchar *new_color, GUI *appGUI)
+{
 GSList *lnode;
 struct note *a;
 gint i;
 
-    if (appGUI->cal->notes_list != NULL) {
+	g_return_if_fail (appGUI->cal->notes_list != NULL);
 
-        for (i = 0, lnode = appGUI->cal->notes_list; lnode != NULL; lnode = lnode->next, i++) {
+	for (i = 0, lnode = appGUI->cal->notes_list; lnode != NULL; lnode = lnode->next, i++) {
+		a = g_slist_nth_data (appGUI->cal->notes_list, i);
 
-            a = g_slist_nth_data (appGUI->cal->notes_list, i);
-
-            if (a->color != NULL) {
-                if (!strncmp(a->color, old_color, MAXCOLORNAME)) {
-                    g_free(a->color);
-                    a->color = g_strdup(new_color);
-                }
-            }
-
-        }
-    }
+		if (a->color != NULL)
+			if (!strncmp (a->color, old_color, MAXCOLORNAME)) {
+				g_free (a->color);
+				a->color = g_strdup (new_color);
+			}
+	}
 }
 
 /*------------------------------------------------------------------------------*/
 
 void
-add_note (guint day, guint month, guint year, gchar *color_str, gchar *text_note, GUI *appGUI) {
-
+cal_add_note (GDate *date, gchar *color_str, gchar *text_note, GUI *appGUI)
+{
 struct note *a;
 
-    if (text_note != NULL) {
+	g_return_if_fail (text_note != NULL);
 
-        a = g_malloc(sizeof(struct note));
-        g_assert (a != NULL);
+	a = g_malloc (sizeof (struct note));
+	g_assert (a != NULL);
 
-        a->day = day;
-        a->month = month;
-        a->year = year;
+	a->date = g_date_get_julian (date);
+	a->day = g_date_get_day (date);
+	a->month = g_date_get_month (date);
+	a->year = g_date_get_year (date);
+	a->color = (color_str != NULL) ? g_strdup (color_str) : NULL;
+	a->note = g_strdup (text_note);
 
-        if (color_str != NULL) {
-            a->color = g_strdup(color_str);
-        } else {
-            a->color = NULL;
-        }
+	cal_remove_note (date, appGUI);
 
-        a->note = g_strdup(text_note);
-
-        remove_note (day, month, year, appGUI);     /* FIXME: check STACK here! */
-
-        appGUI->cal->notes_list = g_slist_append (appGUI->cal->notes_list, a);
-    }
+	appGUI->cal->notes_list = g_slist_append (appGUI->cal->notes_list, a);
 }
 
 /*------------------------------------------------------------------------------*/
 
 void
-remove_note (guint day, guint month, guint year, GUI *appGUI) {
-
+cal_remove_note (GDate *date, GUI *appGUI)
+{
 GSList *lnode;
 struct note *a;
 gint i;
 
-    if (appGUI->cal->notes_list != NULL) {
+	if (appGUI->cal->notes_list == NULL) return;
 
-        for (i = 0, lnode = appGUI->cal->notes_list; lnode != NULL; lnode = lnode->next, i++) {
+	for (i = 0, lnode = appGUI->cal->notes_list; lnode != NULL; lnode = lnode->next, i++) {
+		a = g_slist_nth_data (appGUI->cal->notes_list, i);
 
-            a = g_slist_nth_data (appGUI->cal->notes_list, i);
-
-            if (a->day == day && a->month == month && a->year == year) {
-                if (a->color != NULL) {
-                    g_free(a->color);
-                }
-                if (a->note != NULL) {
-                    g_free(a->note);
-                }
-                appGUI->cal->notes_list = g_slist_remove (appGUI->cal->notes_list, a);
-                break;
-            }
-        }
-    }
+		if (a->date == g_date_get_julian (date)) {
+			if (a->color != NULL) g_free (a->color);
+			if (a->note != NULL) g_free (a->note);
+			appGUI->cal->notes_list = g_slist_remove (appGUI->cal->notes_list, a);
+			break;
+		}
+	}
 }
 
 /*------------------------------------------------------------------------------*/
 
 void
-free_notes_list (GUI *appGUI) {
-
+cal_free_notes_list (GUI *appGUI)
+{
 GSList *node;
 struct note *a;
 gint i = 0;
 
-    for (node = appGUI->cal->notes_list; node != NULL; node = node->next, i++) {
-        a = g_slist_nth_data (appGUI->cal->notes_list, i);
-        if (a->color != NULL) {
-            g_free(a->color);
-        }
-        if (a->note != NULL) {
-            g_free(a->note);
-        }
-    }
+	if (appGUI->cal->notes_list != NULL) {
 
-    if (appGUI->cal->notes_list != NULL) {
-        g_slist_free(appGUI->cal->notes_list);
-        appGUI->cal->notes_list = NULL;
-    }
+		for (node = appGUI->cal->notes_list; node != NULL; node = node->next, i++) {
+			a = g_slist_nth_data (appGUI->cal->notes_list, i);
+			if (a->color != NULL) g_free (a->color);
+			if (a->note != NULL) g_free (a->note);
+		}
+
+		g_slist_free (appGUI->cal->notes_list);
+		appGUI->cal->notes_list = NULL;
+
+	}
 }
 
 /*------------------------------------------------------------------------------*/
 
 void
-read_notes (GUI *appGUI) {
-
+cal_read_notes (GUI *appGUI)
+{
 xmlDocPtr doc;
 xmlChar *key, *prop;
 xmlNodePtr node, cnode, category_node;
 GtkTreeIter iter;
 GdkPixbuf *image;
-guint day, month, year;
-gchar *color_str;
+guint32 julian;
+gint day, month, year;
+gchar *color_str, *note;
+GDate *date;
 
-    appGUI->cal->notes_list = NULL;
+	appGUI->cal->notes_list = NULL;
 
-    if (g_file_test (prefs_get_config_filename(CALENDAR_NOTES_FILENAME, appGUI), G_FILE_TEST_IS_REGULAR) == FALSE) 
-        return;
+	date = g_date_new ();
+	g_return_if_fail (date != NULL);
 
-    if((doc = xmlParseFile(prefs_get_config_filename(CALENDAR_NOTES_FILENAME, appGUI)))) {
+	if (g_file_test (prefs_get_config_filename (CALENDAR_NOTES_FILENAME, appGUI), G_FILE_TEST_IS_REGULAR) == FALSE)
+		return;
 
-        if(!(node = xmlDocGetRootElement(doc))) {
-            return;
-        }
+	if ((doc = xmlParseFile (prefs_get_config_filename (CALENDAR_NOTES_FILENAME, appGUI)))) {
 
-        if(!xmlStrcmp(node->name, (xmlChar *) CALENDAR_NOTES_NAME)) {
+		if (!(node = xmlDocGetRootElement (doc))) return;
 
-            /* read note */
-            node = node->xmlChildrenNode;
+		if (!xmlStrcmp (node->name, (xmlChar *) CALENDAR_NOTES_NAME)) {
 
-            while (node != NULL) {
+			/* read note */
+			node = node->xmlChildrenNode;
 
-                if(!xmlStrcmp(node->name, (xmlChar *) CALENDAR_DAY_CATEGORIES_NAME)) {
+			while (node != NULL) {
 
-                    category_node = node->xmlChildrenNode;
+				if (!xmlStrcmp (node->name, (xmlChar *) CALENDAR_DAY_CATEGORIES_NAME)) {
+					category_node = node->xmlChildrenNode;
 
-                    while (category_node != NULL) {
+					while (category_node != NULL) {
 
-                        if ((!xmlStrcmp(category_node->name, (const xmlChar *) "name"))) {
-                            key = xmlNodeListGetString(doc, category_node->xmlChildrenNode, 1);
-                            prop = xmlGetProp(category_node, (const xmlChar *) "color");
-                            if (key != NULL) {
-                                image = gui_create_color_swatch ((gchar *) prop);
-                                gtk_list_store_append(appGUI->opt->calendar_category_store, &iter);
-                                gtk_list_store_set(appGUI->opt->calendar_category_store, &iter, 0, image, 
-                                                   1, prop, 2, (gchar *) key, -1);
-                                g_object_unref (image);
-                            }
-                            xmlFree(key);
-                        }
-                        category_node = category_node->next;
-                    }
-                }
+						if ((!xmlStrcmp (category_node->name, (const xmlChar *) "name"))) {
+							key = xmlNodeListGetString (doc, category_node->xmlChildrenNode, 1);
+							prop = xmlGetProp (category_node, (const xmlChar *) "color");
+							if (key != NULL) {
+								image = gui_create_color_swatch ((gchar *) prop);
+								gtk_list_store_append (appGUI->opt->calendar_category_store, &iter);
+								gtk_list_store_set (appGUI->opt->calendar_category_store, &iter, 0, image,
+								                    1, prop, 2, (gchar *) key, -1);
+								g_object_unref (image);
+								xmlFree (key);
+							}
+						}
 
-                if(!xmlStrcmp(node->name, (xmlChar *) "note")) {
+						category_node = category_node->next;
+					}
 
-                    cnode = node->xmlChildrenNode;
+				}
 
-                    day = month = year = 0;
-                    color_str = NULL;
+				if (!xmlStrcmp (node->name, (xmlChar *) "note")) {
+					cnode = node->xmlChildrenNode;
+					julian = 0;
+					day = month = year = 0;
+					color_str = NULL;
+					note = NULL;
 
-                    while (cnode != NULL) {
+					while (cnode != NULL) {
+						utl_xml_get_int ("day", &day, cnode, doc);
+						utl_xml_get_int ("month", &month, cnode, doc);
+						utl_xml_get_int ("year", &year, cnode, doc);
+						utl_xml_get_uint ("date", &julian, cnode, doc);
+						utl_xml_get_str ("color", &color_str, cnode, doc);
+						utl_xml_get_str ("message", &note, cnode, doc);
+						cnode = cnode->next;
+					}
 
-                        if ((!xmlStrcmp(cnode->name, (const xmlChar *) "day"))) {
-                            key = xmlNodeListGetString(doc, cnode->xmlChildrenNode, 1);
-                            if (key != NULL)
-                                    day = atoi ((gchar *) key);
-                            xmlFree(key);
-                        }
-                        if ((!xmlStrcmp(cnode->name, (const xmlChar *) "month"))) {
-                            key = xmlNodeListGetString(doc, cnode->xmlChildrenNode, 1);
-                            if (key != NULL)
-                                    month = atoi ((gchar *) key);
-                            xmlFree(key);
-                        }
-                        if ((!xmlStrcmp(cnode->name, (const xmlChar *) "year"))) {
-                            key = xmlNodeListGetString(doc, cnode->xmlChildrenNode, 1);
-                            if (key != NULL)
-                                    year = atoi ((gchar *) key);
-                            xmlFree(key);
-                        }
-                        if ((!xmlStrcmp(cnode->name, (const xmlChar *) "color"))) {
-                            key = xmlNodeListGetString(doc, cnode->xmlChildrenNode, 1);
-                            if (key != NULL)
-                                    color_str = g_strdup((gchar *) key);
-                            xmlFree(key);
-                        }
-                        if ((!xmlStrcmp(cnode->name, (const xmlChar *) "message"))) {
-                            key = xmlNodeListGetString(doc, cnode->xmlChildrenNode, 1);
-                            if (key != NULL) {
-                                add_note (day, month, year, color_str, (gchar *) key, appGUI);
-                                if (color_str != NULL) {
-                                    g_free(color_str);
-                                }
-                            }
-                            xmlFree(key);
-                        }
+					if (note != NULL && (g_date_valid_dmy (day, month, year) || g_date_valid_julian (julian))) {
+						if (g_date_valid_julian (julian)) g_date_set_julian (date, julian);
+						else g_date_set_dmy (date, day, month, year);
 
-                        cnode = cnode->next;
-                    }
+						cal_add_note (date, color_str, note, appGUI);
+						if (color_str != NULL) g_free (color_str);
+						g_free (note);
+					}
+				}
 
-                }
+				node = node->next;
+			}
 
-                node = node->next;
-            }
+		}
 
-        }
-
-        xmlFree(node);
-        xmlFreeDoc(doc);
-    }
+		xmlFree (node);
+		xmlFreeDoc (doc);
+	}
 
+	g_date_free (date);
 }
 
 /*------------------------------------------------------------------------------*/
 
 void
-write_notes (GUI *appGUI) {
-
-GSList *lnode;
-struct note *a;
-gint i;
+cal_write_notes (GUI *appGUI)
+{
 xmlDocPtr doc;
 xmlNodePtr main_node, node, note_node, dc_node;
 xmlAttrPtr attr;
-gchar *category, *color_str;
 GtkTreeIter iter;
-gchar temp[BUFFER_SIZE];
+GSList *lnode;
+struct note *a;
+gchar *category, *color_str;
+gint i;
 
+	if ((appGUI->save_status & WRT_CALENDAR_NOTES) != 0) return;
 
-    doc = xmlNewDoc((const xmlChar *) "1.0");
-    attr = xmlNewDocProp (doc, (const xmlChar *) "encoding", (const xmlChar *) "utf-8");
+	appGUI->save_status |= WRT_CALENDAR_NOTES;
 
-    main_node = xmlNewNode(NULL, (const xmlChar *) CALENDAR_NOTES_NAME);
-    xmlDocSetRootElement(doc, main_node);
+	doc = xmlNewDoc ((const xmlChar *) "1.0");
+	attr = xmlNewDocProp (doc, (const xmlChar *) "encoding", (const xmlChar *) "utf-8");
 
-    node = xmlNewChild(main_node, NULL, (const xmlChar *) CALENDAR_DAY_CATEGORIES_NAME, (xmlChar *) NULL);
+	main_node = xmlNewNode (NULL, (const xmlChar *) CALENDAR_NOTES_NAME);
+	xmlDocSetRootElement (doc, main_node);
 
-    i = 0;
+	node = xmlNewChild (main_node, NULL, (const xmlChar *) CALENDAR_DAY_CATEGORIES_NAME, (xmlChar *) NULL);
 
-    while (gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(appGUI->opt->calendar_category_store), &iter, NULL, i++)) {
+	i = 0;
 
-        gtk_tree_model_get(GTK_TREE_MODEL(appGUI->opt->calendar_category_store), &iter, 1, &color_str, 2, &category, -1);
-        dc_node = xmlNewChild(node, NULL, (const xmlChar *) "name", (xmlChar *) category);
-        g_free(category);
-        xmlNewProp(dc_node, (const xmlChar *) "color", (xmlChar *) color_str);
-        g_free(color_str);
-    }
+	while (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (appGUI->opt->calendar_category_store), &iter, NULL, i++)) {
+		gtk_tree_model_get (GTK_TREE_MODEL (appGUI->opt->calendar_category_store), &iter, 1, &color_str, 2, &category, -1);
+		dc_node = xmlNewChild (node, NULL, (const xmlChar *) "name", (xmlChar *) category);
+		g_free (category);
+		xmlNewProp (dc_node, (const xmlChar *) "color", (xmlChar *) color_str);
+		g_free (color_str);
+	}
 
-    for (i = 0, lnode = appGUI->cal->notes_list; lnode; lnode = lnode->next, i++) {
+	for (i = 0, lnode = appGUI->cal->notes_list; lnode; lnode = lnode->next, i++) {
+		a = g_slist_nth_data (appGUI->cal->notes_list, i);
+		note_node = xmlNewChild (main_node, NULL, (const xmlChar *) "note", (xmlChar *) NULL);
+		utl_xml_put_uint ("date", a->date, note_node);
+		utl_xml_put_int ("day", a->day, note_node);
+		utl_xml_put_int ("month", a->month, note_node);
+		utl_xml_put_int ("year", a->year, note_node);
+		utl_xml_put_str ("color", a->color, note_node);
+		utl_xml_put_str ("message", a->note, note_node);
+	}
 
-        a = g_slist_nth_data (appGUI->cal->notes_list, i);
-        note_node = xmlNewChild(main_node, NULL, (const xmlChar *) "note", (xmlChar *) NULL);
-        sprintf(temp, "%d", a->day);
-        xmlNewChild(note_node, NULL, (const xmlChar *) "day", (xmlChar *) temp);
-        sprintf(temp, "%d", a->month);
-        xmlNewChild(note_node, NULL, (const xmlChar *) "month", (xmlChar *) temp);
-        sprintf(temp, "%d", a->year);
-        xmlNewChild(note_node, NULL, (const xmlChar *) "year", (xmlChar *) temp);
-        xmlNewChild(note_node, NULL, (const xmlChar *) "color", (xmlChar *) a->color);
-        xmlNewChild(note_node, NULL, (const xmlChar *) "message", (xmlChar *) a->note);
-    }
+	xmlSaveFormatFileEnc (prefs_get_config_filename (CALENDAR_NOTES_FILENAME, appGUI), doc, "utf-8", 1);
+	xmlFreeDoc (doc);
 
-    xmlSaveFormatFileEnc(prefs_get_config_filename(CALENDAR_NOTES_FILENAME, appGUI), doc, "utf-8", 1);
-    xmlFreeDoc(doc);
+	appGUI->save_status &= ~WRT_CALENDAR_NOTES;
 }
 
 /*------------------------------------------------------------------------------*/
 
 void
-day_notes_window_close_cb (GtkWidget *widget, GdkEvent *event, gpointer user_data) {
-
-    GUI *appGUI = (GUI *)user_data;
-
-    gtk_widget_destroy (appGUI->cal->day_notes_window);
+day_notes_window_close_cb (GtkWidget *widget, GdkEvent *event, gpointer user_data)
+{
+	GUI *appGUI = (GUI *) user_data;
+	gtk_widget_destroy (appGUI->cal->day_notes_window);
 }
 
 /*------------------------------------------------------------------------------*/
 
 void
-button_day_notes_window_close_cb (GtkButton *button, gpointer user_data) {
-
-    day_notes_window_close_cb (GTK_WIDGET(button), NULL, user_data);
-
+button_day_notes_window_close_cb (GtkButton *button, gpointer user_data)
+{
+	day_notes_window_close_cb (GTK_WIDGET (button), NULL, user_data);
 }
 
 /*------------------------------------------------------------------------------*/
 
-gint 
-day_notes_key_press_cb (GtkWidget *widget, GdkEventKey *event, gpointer data) {
+gint
+day_notes_key_press_cb (GtkWidget *widget, GdkEventKey *event, gpointer user_data)
+{
+	GUI *appGUI = (GUI *) user_data;
 
-    GUI *appGUI = (GUI *)data;
+	switch (event->keyval) {
 
-    switch(event->keyval) {
+		case GDK_Escape:
+			gtk_widget_destroy (appGUI->cal->day_notes_window);
+			return TRUE;
 
-        case GDK_Escape:
-            gtk_widget_destroy(appGUI->cal->day_notes_window);
-            return TRUE;
-    }
+	}
 
-    return FALSE;
+	return FALSE;
 }
 
 /*------------------------------------------------------------------------------*/
 
 gboolean
-notes_filter_combo_box_focus_cb (GtkWidget *widget, GtkDirectionType *arg1, gpointer user_data) {
-    return TRUE;
+notes_filter_combo_box_focus_cb (GtkWidget *widget, GtkDirectionType *arg1, gpointer user_data)
+{
+	return TRUE;
 }
 
 /*------------------------------------------------------------------------------*/
 
 gchar *
-note_reformatting (gchar *note) {
-
+cal_note_remove_empty_lines (gchar *note)
+{
 gchar *tmp_note;
 gint j, k;
 
@@ -461,8 +495,8 @@ gint j, k;
 /*------------------------------------------------------------------------------*/
 
 void
-notes_display_items (guint32 julian_start, guint32 julian_end, gchar *search_string, GUI *appGUI) {
-
+notes_display_items (guint32 julian_start, guint32 julian_end, gchar *search_string, GUI *appGUI)
+{
 GSList          *lnode;
 struct note     *day_note;
 guint32         julian_day;
@@ -472,170 +506,168 @@ gboolean        show_flag, case_state;
 gint            i, l, n, m, n_items;
 gchar           tmpbuf[BUFFER_SIZE];
 
-    n_items = 0;
+	if (appGUI->cal->day_notes_list == NULL || appGUI->cal->day_notes_list_store == NULL) return;
 
-    if (appGUI->cal->day_notes_list != NULL && appGUI->cal->day_notes_list_store != NULL) {
-    
-        gtk_list_store_clear (GTK_LIST_STORE(appGUI->cal->day_notes_list_store));
+	n_items = 0;
+	gtk_list_store_clear (GTK_LIST_STORE (appGUI->cal->day_notes_list_store));
 
-        if (julian_start+julian_end != 0) {
+/*	if (julian_start+julian_end != 0) {*/
 
-            for (i = 0, lnode = appGUI->cal->notes_list; lnode != NULL; lnode = lnode->next, i++) {
+		for (i = 0, lnode = appGUI->cal->notes_list; lnode != NULL; lnode = lnode->next, i++) {
 
-                day_note = g_slist_nth_data (appGUI->cal->notes_list, i);
-                julian_day = date_to_julian (day_note->day, day_note->month-1, day_note->year);
+			day_note = g_slist_nth_data (appGUI->cal->notes_list, i);
+			julian_day = utl_dmy_to_julian (day_note->day, day_note->month, day_note->year);
 
-                tmp_note = note_reformatting (day_note->note);
+			tmp_note = cal_note_remove_empty_lines (day_note->note);
 
-                if (search_string == NULL) {
-                    show_flag = TRUE;
-                } else {
-                    if (strlen(search_string) != 0) {
+			if (search_string == NULL) {
+				show_flag = TRUE;
+			} else {
+				if (strlen(search_string) != 0) {
 
-                        show_flag = FALSE;
+					show_flag = FALSE;
 
-                        l = strlen(search_string);
-                        m = strlen(tmp_note) - l;
+					l = strlen(search_string);
+					m = strlen(tmp_note) - l;
 
-                        if (m >= 0) {
+					if (m >= 0) {
 
-                            case_state = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(appGUI->cal->notes_search_checkbutton));
+						case_state = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(appGUI->cal->notes_search_checkbutton));
 
-                            if (case_state == FALSE) {
-                                search_key_1 = g_utf8_casefold (search_string, l);
-                            } else {
-                                search_key_1 = g_utf8_collate_key (search_string, l);
-                            }
+						if (case_state == FALSE) {
+							search_key_1 = g_utf8_casefold (search_string, l);
+						} else {
+							search_key_1 = g_utf8_collate_key (search_string, l);
+						}
 
-                            for (n = 0; n < m; n++) {
+						for (n = 0; n < m; n++) {
 
-                                if (case_state == FALSE) {
-                                    search_key_2 = g_utf8_casefold (tmp_note+n, l);
-                                } else {
-                                    search_key_2 = g_utf8_collate_key (tmp_note+n, l);
-                                }
+							if (case_state == FALSE) {
+								search_key_2 = g_utf8_casefold (tmp_note+n, l);
+							} else {
+								search_key_2 = g_utf8_collate_key (tmp_note+n, l);
+							}
 
-                                if (g_utf8_collate(search_key_1, search_key_2) == 0) {
-                                    show_flag = TRUE;
-                                    g_free(search_key_2);
-                                    break;
-                                }
+							if (g_utf8_collate(search_key_1, search_key_2) == 0) {
+								show_flag = TRUE;
+								g_free(search_key_2);
+								break;
+							}
 
-                                g_free(search_key_2);
-                            }
+							g_free(search_key_2);
+						}
 
-                            g_free(search_key_1);
-                        }
+						g_free(search_key_1);
+					}
 
-                    } else {
-                        show_flag = TRUE;
-                    }
-                }
+				} else {
+					show_flag = TRUE;
+				}
+			}
 
-                if (((julian_start == -1 && julian_end == -1) || 
-                    (julian_day >= julian_start && julian_day <= julian_end)) && show_flag) {
+			if (((julian_start == 0 && julian_end == 0) ||
+			    (julian_day >= julian_start && julian_day <= julian_end)) && show_flag) {
 
-                    gtk_list_store_append(appGUI->cal->day_notes_list_store, &iter);
-                    gtk_list_store_set(appGUI->cal->day_notes_list_store, &iter, 
-                                       DN_COLUMN_DATE, julian_to_str (julian_day, config.date_format),
-                                       DN_COLUMN_DATE_JULIAN, julian_day, 
-                                       DN_COLUMN_NOTE_LINE, tmp_note, DN_COLUMN_DONE, FALSE, -1);
+				gtk_list_store_append (appGUI->cal->day_notes_list_store, &iter);
+				gtk_list_store_set (appGUI->cal->day_notes_list_store, &iter,
+				                    DN_COLUMN_DATE, julian_to_str (julian_day, config.date_format),
+				                    DN_COLUMN_DATE_JULIAN, julian_day,
+				                    DN_COLUMN_NOTE_LINE, tmp_note,
+				                    DN_COLUMN_DONE, FALSE, -1);
 
-                    if (julian_day < get_julian_for_today() && gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(appGUI->cal->past_notes_checkbutton))) {
-                        gtk_list_store_set(appGUI->cal->day_notes_list_store, &iter, DN_COLUMN_DONE, TRUE, -1);
-                    }
+				if (julian_day < utl_get_current_julian ()
+				    && gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->cal->past_notes_checkbutton))) {
 
-                    n_items++;
+					gtk_list_store_set (appGUI->cal->day_notes_list_store, &iter, DN_COLUMN_DONE, TRUE, -1);
+				}
 
-                }
+				n_items++;
 
-                g_free (tmp_note);
+			}
 
-            }
-        }
+			g_free (tmp_note);
 
-        if (!n_items) {
-            sprintf (tmpbuf, "<i>%s</i>", _("no entries"));
-        } else {
-            sprintf (tmpbuf, "<i>%4d %s</i>", n_items, ngettext ("entry", "entries", n_items));
-        }
+		}
+/*	}*/
 
-        gtk_label_set_markup (GTK_LABEL (appGUI->cal->n_items_label), tmpbuf);
+	if (!n_items) {
+		g_snprintf (tmpbuf, BUFFER_SIZE, "<i>%s</i>", _("no entries"));
+	} else {
+		g_snprintf (tmpbuf, BUFFER_SIZE, "<i>%4d %s</i>", n_items, ngettext ("entry", "entries", n_items));
+	}
 
-    }
+	gtk_label_set_markup (GTK_LABEL (appGUI->cal->n_items_label), tmpbuf);
 }
 
 /*------------------------------------------------------------------------------*/
 
 void
-refresh_notes_list (gint filter_mode, gchar *search_string, GUI *appGUI) {
-
-gint year, month;
+refresh_notes_list (gint filter_mode, gchar *search_string, GUI *appGUI)
+{
 guint32 julian_start, julian_end;
+gint month, year;
 
-    gtk_widget_hide (appGUI->cal->notes_month_spinbutton);
-    gtk_widget_hide (appGUI->cal->notes_year_spinbutton);
+	gtk_widget_hide (appGUI->cal->notes_month_spinbutton);
+	gtk_widget_hide (appGUI->cal->notes_year_spinbutton);
 
-    if (filter_mode == DN_FILTER_SELECTED_MONTH) {
-        gtk_widget_show (appGUI->cal->notes_month_spinbutton);
-    } else if (filter_mode == DN_FILTER_SELECTED_YEAR) {
-        gtk_widget_show (appGUI->cal->notes_year_spinbutton);
-    } else if (filter_mode == DN_FILTER_SELECTED_MONTH_YEAR) {
-        gtk_widget_show (appGUI->cal->notes_month_spinbutton);
-        gtk_widget_show (appGUI->cal->notes_year_spinbutton);
-    } 
-    
-    julian_start = julian_end = 0;
-    month = get_current_month();
-    year = get_current_year();
+	if (filter_mode == DN_FILTER_SELECTED_MONTH) {
+		gtk_widget_show (appGUI->cal->notes_month_spinbutton);
+	} else if (filter_mode == DN_FILTER_SELECTED_YEAR) {
+		gtk_widget_show (appGUI->cal->notes_year_spinbutton);
+	} else if (filter_mode == DN_FILTER_SELECTED_MONTH_YEAR) {
+		gtk_widget_show (appGUI->cal->notes_month_spinbutton);
+		gtk_widget_show (appGUI->cal->notes_year_spinbutton);
+	}
 
-    switch (filter_mode) {
-        case DN_FILTER_CURRENT_MONTH:
-                julian_start = date_to_julian(1, month, year);
-                julian_end = date_to_julian (g_date_get_days_in_month (month + 1, year), month, year);
-                break;
-        case DN_FILTER_SELECTED_MONTH:
-                month = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON(appGUI->cal->notes_month_spinbutton))-1;
-                julian_start = date_to_julian(1, month, year);
-                julian_end = date_to_julian (g_date_get_days_in_month (month + 1, year), month, year);
-                break;
-        case DN_FILTER_CURRENT_YEAR:
-                julian_start = date_to_julian(1, 0, year);
-                julian_end = date_to_julian (g_date_get_days_in_month (12, year), 11, year);
-                break;
-        case DN_FILTER_SELECTED_YEAR:
-                year = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON(appGUI->cal->notes_year_spinbutton));
-                julian_start = date_to_julian(1, 0, year);
-                julian_end = date_to_julian (g_date_get_days_in_month (12, year), 11, year);
-                break;
-        case DN_FILTER_SELECTED_MONTH_YEAR:
-                year = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON(appGUI->cal->notes_year_spinbutton));
-                month = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON(appGUI->cal->notes_month_spinbutton))-1;
-                julian_start = date_to_julian(1, month, year);
-                julian_end = date_to_julian (g_date_get_days_in_month (month + 1, year), month, year);
-                break;
-        case DN_FILTER_ALL_NOTES:
-                julian_start = julian_end = -1;
-                break;
-    }
+	julian_start = julian_end = 0;
+	month = utl_get_current_month ();
+	year = utl_get_current_year ();
 
-    notes_display_items (julian_start, julian_end, search_string, appGUI);
+	switch (filter_mode) {
+		case DN_FILTER_CURRENT_MONTH:
+			julian_start = utl_dmy_to_julian (1, month, year);
+			julian_end = utl_dmy_to_julian (g_date_get_days_in_month (month, year), month, year);
+			break;
+		case DN_FILTER_SELECTED_MONTH:
+			month = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->notes_month_spinbutton));
+			julian_start = utl_dmy_to_julian (1, month, year);
+			julian_end = utl_dmy_to_julian (g_date_get_days_in_month (month, year), month, year);
+			break;
+		case DN_FILTER_CURRENT_YEAR:
+			julian_start = utl_dmy_to_julian (1, 1, year);
+			julian_end = utl_dmy_to_julian (g_date_get_days_in_month (12, year), 12, year);
+			break;
+		case DN_FILTER_SELECTED_YEAR:
+			year = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->notes_year_spinbutton));
+			julian_start = utl_dmy_to_julian (1, 1, year);
+			julian_end = utl_dmy_to_julian (g_date_get_days_in_month (12, year), 12, year);
+			break;
+		case DN_FILTER_SELECTED_MONTH_YEAR:
+			month = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->notes_month_spinbutton));
+			year = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->notes_year_spinbutton));
+			julian_start = utl_dmy_to_julian (1, month, year);
+			julian_end = utl_dmy_to_julian (g_date_get_days_in_month (month, year), month, year);
+			break;
+		case DN_FILTER_ALL_NOTES:
+			julian_start = julian_end = 0;
+			break;
+	}
 
-    if (appGUI->cal->day_notes_list != NULL) {
-        gtk_widget_grab_focus (appGUI->cal->day_notes_list);
-    }
+	notes_display_items (julian_start, julian_end, search_string, appGUI);
+
+	if (appGUI->cal->day_notes_list != NULL) {
+		gtk_widget_grab_focus (appGUI->cal->day_notes_list);
+	}
 }
 
 /*------------------------------------------------------------------------------*/
 
 void
-notes_filter_changed_cb (GtkComboBox *widget, gpointer user_data) {
-
-    GUI *appGUI = (GUI *)user_data;
-
-    config.day_notes_browser_filter = gtk_combo_box_get_active (GTK_COMBO_BOX (appGUI->cal->notes_filter_combobox));
-
-    refresh_notes_list (config.day_notes_browser_filter, NULL, appGUI);
+notes_filter_changed_cb (GtkComboBox *widget, gpointer user_data)
+{
+	GUI *appGUI = (GUI *) user_data;
+	config.day_notes_browser_filter = gtk_combo_box_get_active (GTK_COMBO_BOX (appGUI->cal->notes_filter_combobox));
+	refresh_notes_list (config.day_notes_browser_filter, NULL, appGUI);
 }
 
 /*------------------------------------------------------------------------------*/
@@ -658,51 +690,53 @@ search_entry_key_press_cb (GtkWidget *widget, GdkEventKey *event, gpointer data)
 /*------------------------------------------------------------------------------*/
 
 gint
-day_notes_list_dbclick_cb(GtkWidget * widget, GdkEventButton * event, gpointer func_data) {
-
+day_notes_list_dbclick_cb (GtkWidget *widget, GdkEventButton *event, gpointer user_data)
+{
 GtkTreeIter iter;
 GtkTreeModel *model;
 guint32 julian_day;
-DATE *dest_date;
+GDate *date;
 
-    GUI *appGUI = (GUI *)func_data;
+    GUI *appGUI = (GUI *) user_data;
 
-    if ((event->type==GDK_2BUTTON_PRESS) && (event->button == 1)) {
+	date = g_date_new ();
+	g_return_val_if_fail (date != NULL, FALSE);
+
+    if ((event->type == GDK_2BUTTON_PRESS) && (event->button == 1)) {
 
         if (gtk_tree_selection_get_selected (appGUI->cal->day_notes_list_selection, &model, &iter)) {
-
             gtk_tree_model_get (model, &iter, DN_COLUMN_DATE_JULIAN, &julian_day, -1);
  
-            dest_date = julian_to_date (julian_day);
-            if (dest_date != NULL) {
-                jump_to_date (dest_date->day, dest_date->month-1, dest_date->year, appGUI);
+            if (g_date_valid_julian (julian_day) == TRUE) {
+				g_date_set_julian (date, julian_day);
+                cal_jump_to_date (date, appGUI);
                 update_aux_calendars (appGUI);
                 button_day_notes_window_close_cb (NULL, appGUI);
-                g_free(dest_date);
             }
         }
 
+		g_date_free (date);
         return TRUE;
     }
 
+	g_date_free (date);
     return FALSE;
 }
 
 /*------------------------------------------------------------------------------*/
 
 void
-browser_past_notes_cb (GtkToggleButton *togglebutton, gpointer user_data) {
-
-    GUI *appGUI = (GUI *)user_data;
-
-    refresh_notes_list (config.day_notes_browser_filter, NULL, appGUI);
+browser_past_notes_cb (GtkToggleButton *togglebutton, gpointer user_data)
+{
+	GUI *appGUI = (GUI *)user_data;
+	refresh_notes_list (config.day_notes_browser_filter, NULL, appGUI);
 }
 
 /*------------------------------------------------------------------------------*/
 
 void
-calendar_notes_browser (GUI *appGUI) {
-
+cal_notes_browser (GUI *appGUI)
+{
 GtkWidget           *vbox1;
 GtkWidget           *hbox1;
 GtkWidget           *scrolledwindow;
