@@ -29,6 +29,7 @@
 #define CALENDAR_NOTES_FILENAME          "calendar_notes.xml"
 
 struct note {
+    guint32 date;
     guint day;
     guint month;
     guint year;
@@ -53,19 +54,23 @@ enum {
     DAY_NOTES_NUM_COLUMNS
 };
 
-void        read_notes              (GUI *appGUI);
-void        write_notes             (GUI *appGUI);
-void        free_notes_list         (GUI *appGUI);
+void        cal_read_notes              (GUI *appGUI);
+void        cal_write_notes             (GUI *appGUI);
+void        cal_free_notes_list         (GUI *appGUI);
+void        cal_add_note                (GDate *date, gchar *color_str, gchar *text_note, GUI *appGUI);
+gchar *     cal_get_note                (GDate *date, GUI *appGUI);
+void        cal_remove_note             (GDate *date, GUI *appGUI);
+gboolean    cal_check_note              (GDate *date, GUI *appGUI);
+gchar *     cal_get_note_color          (GDate *date, GUI *appGUI);
+void        cal_replace_note_color      (gchar *old_color, gchar *new_color, GUI *appGUI);
+void        cal_notes_browser           (GUI *appGUI);
+gchar *     cal_note_remove_empty_lines (gchar *note);
+
+/* FIXME: REMOVE */
 gboolean    check_note              (guint day, guint month, guint year, GUI *appGUI);
-void        add_note                (guint day, guint month, guint year, 
-                                     gchar *color_str, gchar *text_note, GUI *appGUI);
 gchar *     get_note                (guint day, guint month, guint year, GUI *appGUI);
 gchar *     get_color               (guint day, guint month, guint year, GUI *appGUI);
-void        replace_note_color      (gchar *old_color, gchar *new_color, GUI *appGUI);
-void        remove_note             (guint day, guint month, guint year, GUI *appGUI);
-gchar *     note_reformatting       (gchar *note);
-
-void        calendar_notes_browser  (GUI *appGUI);
+/* FIXME: THIS */
 
 #endif /* _CALENDAR_NOTES_H */
 
