@@ -22,6 +22,7 @@
 #include "calendar_utils.h"
 #include "i18n.h"
 #include "gui.h"
+#include "utils.h"
 #include "options_prefs.h"
 #include "calendar.h"
 #include "calendar_notes.h"
@@ -40,22 +41,14 @@ is_date_in_the_past (guint32 julian, gint seconds, guint32 ac_julian, gint ac_se
 
 /*------------------------------------------------------------------------------*/
 
-guint
-get_days_in_month (GDate *cdate)
-{
-	return g_date_get_days_in_month (g_date_get_month (cdate), g_date_get_year (cdate));
-}
-
-/*------------------------------------------------------------------------------*/
-
 gint
 calculate_date_time_diff (DATE date_from, TIME time_from, DATE date_to, TIME time_to,
                           DATE *date_diff, TIME *time_diff)
 {
 gint days;
 
-    days = (gint)(date_to_julian (date_to.day, date_to.month, date_to.year)
-                - date_to_julian (date_from.day, date_from.month, date_from.year));
+    days = (gint)(utl_dmy_to_julian (date_to.day, date_to.month + 1, date_to.year)
+                - utl_dmy_to_julian (date_from.day, date_from.month + 1, date_from.year));
 
     if (days < 0 || (days == 0 &&
             time_from.hour * 3600 + time_from.minute * 60 + time_from.second >
@@ -105,251 +98,6 @@ gint days;
 
 /*------------------------------------------------------------------------------*/
 
-void
-sync_cal_date_with_gdate (GUI *appGUI)
-{
-	appGUI->cal->day = g_date_get_day (appGUI->cal->date);
-	appGUI->cal->month = g_date_get_month (appGUI->cal->date) - 1;
-	appGUI->cal->year = g_date_get_year (appGUI->cal->date);
-}
-
-/*------------------------------------------------------------------------------*/
-
-guint
-get_days_in_selected_month (GUI *appGUI)
-{
-	return g_date_get_days_in_month (g_date_get_month (appGUI->cal->date), g_date_get_year (appGUI->cal->date));
-}
-
-/*------------------------------------------------------------------------------*/
-
-guint
-get_current_day (void) {
-    return get_tm_struct()->tm_mday;
-}
-
-/*------------------------------------------------------------------------------*/
-
-guint
-get_current_month (void) {
-    return get_tm_struct()->tm_mon;
-}
-
-/*------------------------------------------------------------------------------*/
-
-guint
-get_current_year (void) {
-    return (get_tm_struct()->tm_year + 1900);
-}
-
-/*------------------------------------------------------------------------------*/
-
-guint
-get_gdate_current_day (void)
-{
-GDate *cdate;
-guint current_day;
-
-	cdate = g_date_new ();
-	g_return_val_if_fail (cdate != NULL, 0);
-
-	g_date_set_time_t (cdate, time (NULL));
-	current_day = g_date_get_day (cdate);
-	g_date_free (cdate);
-
-	return current_day;
-}
-
-/*------------------------------------------------------------------------------*/
-
-guint
-get_gdate_current_month (void)
-{
-GDate *cdate;
-guint current_month;
-
-	cdate = g_date_new ();
-	g_return_val_if_fail (cdate != NULL, 0);
-
-	g_date_set_time_t (cdate, time (NULL));
-	current_month = g_date_get_month (cdate);
-	g_date_free (cdate);
-
-	return current_month;
-}
-
-/*------------------------------------------------------------------------------*/
-
-guint
-get_gdate_current_year (void)
-{
-GDate *cdate;
-guint current_year;
-
-	cdate = g_date_new ();
-	g_return_val_if_fail (cdate != NULL, 0);
-
-	g_date_set_time_t (cdate, time (NULL));
-	current_year = g_date_get_year (cdate);
-	g_date_free (cdate);
-
-	return current_year;
-}
-
-/*------------------------------------------------------------------------------*/
-
-guint32
-get_gdate_current_julian (void)
-{
-GDate *cdate;
-guint32 current_julian;
-
-	cdate = g_date_new ();
-	g_return_val_if_fail (cdate != NULL, 0);
-
-	g_date_set_time_t (cdate, time (NULL));
-	current_julian = g_date_get_julian (cdate);
-	g_date_free (cdate);
-
-	return current_julian;
-}
-
-/*------------------------------------------------------------------------------*/
-
-gchar *
-get_day_name (guint day, gboolean short_name)
-{
-static gchar tmpbuf[BUFFER_SIZE];
-GDate *cdate;
-
-	cdate = g_date_new_dmy (day, 1, 2007);
-	g_return_val_if_fail (cdate != NULL, tmpbuf);
-
-	g_date_strftime (tmpbuf, BUFFER_SIZE, short_name ? "%a" : "%A", cdate);
-	g_date_free (cdate);
-
-	return tmpbuf;
-}
-
-/*------------------------------------------------------------------------------*/
-
-guint
-get_weekend_days (guint month, guint year)
-{
-guint i, wdays, days, day;
-GDate *cdate;
-
-	cdate = g_date_new_dmy (1, month, year);
-	g_return_val_if_fail (cdate != NULL, 0);
-
-	days = g_date_get_days_in_month (month, year);
-	for (wdays = 0, i = 1; i <= days; i++) {
-		g_date_set_day (cdate, i);
-		day = g_date_get_weekday (cdate);
-		if (day == G_DATE_SATURDAY || day == G_DATE_SUNDAY) {
-			wdays++;
-		}
-	}
-
-    return wdays;
-}
-
-/*------------------------------------------------------------------------------*/
-
-gchar *
-get_julianday_name (gint julian_day)
-{
-static gchar tmpbuf[BUFFER_SIZE];
-GDate *cdate;
-
-	cdate = g_date_new_julian (julian_day);
-	g_return_val_if_fail (cdate != NULL, tmpbuf);
-
-	g_date_strftime (tmpbuf, BUFFER_SIZE, "%A", cdate);
-	g_date_free (cdate);
-
-	return tmpbuf;
-}
-
-/*------------------------------------------------------------------------------*/
-
-gchar *
-get_date_name (guint day, guint month, guint year) {
-
-static gchar tmpbuf[BUFFER_SIZE];
-GDate *cdate;
-
-	cdate = g_date_new_dmy (day, month, year);
-	g_return_val_if_fail (cdate != NULL, tmpbuf);
-
-	g_date_strftime (tmpbuf, BUFFER_SIZE, "%e %B %Y", cdate);     /* e.g. 1 August 1999 */
-	g_date_free (cdate);
-
-	return tmpbuf;
-}
-
-/*------------------------------------------------------------------------------*/
-
-gchar *
-calendar_get_date_name (GDate *cdate)
-{
-static gchar tmpbuf[BUFFER_SIZE];
-
-	g_date_strftime (tmpbuf, BUFFER_SIZE, "%e %B %Y", cdate);     /* e.g. 1 August 1999 */
-	return tmpbuf;
-}
-
-/*------------------------------------------------------------------------------*/
-
-guint
-get_days_per_year (guint year)
-{
-	return (g_date_is_leap_year (year) ? 366 : 365);
-}
-
-/*------------------------------------------------------------------------------*/
-/*  This routine has been taken from http://www.voidware.com/moon_phase.htm
-    calculates the moon phase (0-7), accurate to 1 segment: 0 = > new moon, 4 => full moon.
-*/
-
-guint
-calc_moon_phase(gint myear, gint mmonth, gint mday) {
-
-gint b, c, e;
-gdouble jd;
-
-    if (mmonth < 3) {
-        myear--;
-        mmonth += 12;
-    }
-    ++mmonth;
-    c = 365.25 * myear;
-    e = 30.6 * mmonth;
-    jd = c + e + mday - 694039.09;  /* jd is total days elapsed */
-    jd /= 29.53;                    /* divide by the moon cycle (29.53 days) */
-    b = jd;                         /* int(jd) -> b, take integer part of jd */
-    jd -= b;                        /* subtract integer part to leave fractional part of original jd */
-    b = jd * 8 + 0.5;               /* scale fraction from 0-8 and round by adding 0.5 */
-    b = b & 7;                      /* 0 and 8 are the same so turn 8 into 0 */
-
-    return b;
-}
-
-/*------------------------------------------------------------------------------*/
-
-gchar*
-get_moon_phase_name(gint phase) {
-
-const gchar *phase_names[] = {
-    N_("New Moon"), N_("Waxing Crescent Moon"), N_("Quarter Moon"), N_("Waxing Gibbous Moon"),
-    N_("Full Moon"), N_("Waning Gibbous Moon"), N_("Last Quarter Moon"), N_("Waning Crescent Moon")
-};
-
-    return (gchar *)gettext(phase_names[phase]);
-}
-
-/*------------------------------------------------------------------------------*/
-
 gchar*
 julian_to_str (guint32 julian_day, gint date_format)
 {
@@ -357,7 +105,7 @@ static gchar buffer[BUFFER_SIZE];
 GDate *cdate;
 gint i;
 gchar *date_format_str[] = {
-    "%d-%m-%Y", "%m-%d-%Y", "%Y-%m-%d", "%Y-%d-%m", "%e %B", "%e %B %Y"
+    "%d-%m-%Y", "%m-%d-%Y", "%Y-%m-%d", "%Y-%d-%m", "%e %B", "%A", "%e %B %Y"
 };
 
 	if (g_date_valid_julian (julian_day)) {
@@ -476,7 +224,7 @@ gchar *token;
     };
 
     if (g_date_valid_dmy (day, month, year) == TRUE) {
-        return date_to_julian (day, month-1, year);
+        return utl_dmy_to_julian (day, month, year);
     } else {
         return 0;
     }
@@ -484,23 +232,6 @@ gchar *token;
 
 /*------------------------------------------------------------------------------*/
 
-guint32
-date_to_julian (guint day, guint month, guint year)
-{
-GDate *cdate;
-guint32 julian;
-
-	cdate = g_date_new_dmy (day, month + 1, year);
-	g_return_val_if_fail (cdate != NULL, 0);
-	g_return_val_if_fail (g_date_valid (cdate), 0);
-
-	julian = g_date_get_julian (cdate);
-	g_date_free (cdate);
-	return julian;
-}
-
-/*------------------------------------------------------------------------------*/
-
 DATE*
 julian_to_date (guint32 julian_day)
 {
@@ -534,42 +265,30 @@ GDate *cdate;
 /*------------------------------------------------------------------------------*/
 
 gint
-julian_to_year(guint32 julian_day) {
-
-DATE *date;
+julian_to_year (guint32 julian_day)
+{
+GDate *tmpdate;
 gint year;
 
-    date = julian_to_date (julian_day);
-    year = 0;
+	g_return_val_if_fail (g_date_valid_julian (julian_day) == TRUE, 0);
 
-    if (date != NULL) {
-        year = date->year;
-        g_free(date);
-    }
+    tmpdate = g_date_new_julian (julian_day);
+	g_return_val_if_fail (tmpdate != NULL, 0);
+
+	year = g_date_get_year (tmpdate);
+	g_date_free (tmpdate);
 
     return year;
 }
 
 /*------------------------------------------------------------------------------*/
 
-guint32
-get_julian_for_today(void) {
-
-struct tm   *timer;
-
-    timer = get_tm_struct();
-
-    return date_to_julian(timer->tm_mday, timer->tm_mon, timer->tm_year + 1900);
-}
-
-/*------------------------------------------------------------------------------*/
-
 gchar *
 get_current_date_distance_str (guint32 date)
 {
 static gchar buffer[BUFFER_SIZE];
 
-	gint d = date - get_julian_for_today ();
+	gint d = date - utl_get_current_julian ();
 	d = (d < 0) ? -d : d;
 	g_snprintf (buffer, BUFFER_SIZE, "%d", d);
 
@@ -636,7 +355,7 @@ gint n;
 /*------------------------------------------------------------------------------*/
 
 gchar *
-get_zodiac_name (guint day, guint month)
+utl_get_zodiac_name (guint day, guint month)
 {
 gchar *zodiac[] = {
 	N_("Unknown"), N_("Aquarius"), N_("Pisces"), N_("Aries"), N_("Taurus"), N_("Gemini"), N_("Cancer"),
