@@ -23,7 +23,7 @@
 #include "i18n.h"
 #include "calendar.h"
 #include "gui.h"
-#include "gui_utils.h"
+#include "utils.h"
 #include "calendar_notes.h"
 #include "options_prefs.h"
 #include "options_gui_tasks.h"
@@ -129,7 +129,7 @@ guint i;
 
 		if (a->notify == n) {
 			a->time = get_seconds_for_today () + config.postpone_time * 60;
-			a->date = get_julian_for_today ();
+			a->date = utl_get_current_julian ();
 
 			if (a->time >= 24 * 3600) {
 				a->time -= 24 * 3600;
@@ -217,8 +217,7 @@ guint i, id;
 		                                (NotifyActionCallback) tsk_postpone_notify_cb, appGUI, NULL);
 	}
 	notify_notification_add_action (a->notify, "done", _("Done"), (NotifyActionCallback) tsk_done_cb, appGUI, NULL);
-	notify_notification_show (a->notify, NULL);
-
+    notify_notification_show (a->notify, NULL);
 }
 
 /*------------------------------------------------------------------------------*/
@@ -249,7 +248,7 @@ gint current_time, warning_time;
 
 	if (item->active_warning == TRUE && (item->warning_days > 0 || item->warning_time > 0)) {
 
-		current_date = get_julian_for_today ();
+		current_date = utl_get_current_julian ();
 		current_time = get_seconds_for_today ();
 		subtract_from_date (item->due_date_julian, item->due_time,
 		                    item->warning_days, item->warning_time, &warning_date, &warning_time);
@@ -278,7 +277,7 @@ gboolean
 tsk_show_task_notification (TASK_ITEM *item, GtkTreeIter *iter, GUI *appGUI)
 {
 
-	if (is_date_in_the_past (item->due_date_julian, item->due_time, get_julian_for_today(), get_seconds_for_today())) {
+	if (is_date_in_the_past (item->due_date_julian, item->due_time, utl_get_current_julian (), get_seconds_for_today ())) {
 
 		if (item->repeat == TRUE && item->offline_ignore == TRUE) {
 			if (is_date_in_the_past (item->due_date_julian, item->due_time, appGUI->run_date, appGUI->run_time)) {
@@ -306,7 +305,7 @@ GSList *tnode;
 TASK_NTF *a;
 gint i;
 
-	current_date = get_julian_for_today ();
+	current_date = utl_get_current_julian ();
 	current_time = get_seconds_for_today ();
 
 	for (i = 0, tnode = appGUI->tsk->notifications; tnode != NULL; tnode = tnode->next, i++) {
@@ -325,6 +324,11 @@ gint i;
 				}
 				g_snprintf (tmpbuf2, BUFFER_SIZE, "%s (%s)", a->item->summary, _("postponed"));
 				notify_notification_update (a->notify, tmpbuf2, tmpbuf, GTK_STOCK_DIALOG_WARNING);
+
+                if (strlen (config.global_notification_command)) {
+                    gui_save_data_and_run_command (config.global_notification_command, appGUI);
+                }
+
 				notify_notification_show (a->notify, NULL);
 			}
 		}
@@ -350,7 +354,7 @@ gint i;
 
 	show_postponed_notification (appGUI);
 
-	current_date = get_julian_for_today ();
+	current_date = utl_get_current_julian ();
 	current_time = get_seconds_for_today ();
 
 	i = 0;
@@ -411,6 +415,10 @@ gint i;
 						notify_notification_attach_to_status_icon (a->notify, appGUI->osmo_trayicon);
 					}
 
+                    if (strlen (config.global_notification_command)) {
+                        gui_save_data_and_run_command (config.global_notification_command, appGUI);
+                    }
+
 					if (!notify_notification_show (a->notify, NULL)) {
 						g_warning ("Failed to send notification");
 						return FALSE;
@@ -451,6 +459,10 @@ gint i;
 						notify_notification_attach_to_status_icon (a->notify, appGUI->osmo_trayicon);
 					}
 
+                    if (strlen (config.global_notification_command)) {
+                        gui_save_data_and_run_command (config.global_notification_command, appGUI);
+                    }
+
 					if (!notify_notification_show (a->notify, NULL)) {
 						g_warning ("Failed to send notification");
 						return FALSE;
@@ -567,9 +579,13 @@ guint32 date, age;
 
                 if (new_cdate != NULL) {
 
-                    age = appGUI->cal->year - g_date_get_year(new_cdate);
+                    age = g_date_get_year (appGUI->cal->date) - g_date_get_year (new_cdate);
 
                     if (age >= 0) {
+						if (g_date_valid_dmy (g_date_get_day (new_cdate), g_date_get_month (new_cdate),
+						                      g_date_get_year (appGUI->cal->date)) == FALSE) {
+							g_date_subtract_days (new_cdate, 1);
+						}
 
                         g_date_set_year (new_cdate, julian_to_year(julian_day));
                         date = g_date_get_julian (new_cdate);
@@ -622,26 +638,29 @@ button_event_checker_show_osmo_window_cb (GtkButton *button, gpointer user_data)
 /*------------------------------------------------------------------------------*/
 
 void
-event_checker_select_item (GUI *appGUI) {
-
+event_checker_select_item (GUI *appGUI)
+{
 GtkTreeIter iter;
 GtkTreeModel *model;
 guint32 julian_day;
-DATE *dest_date;
+GDate *date;
 
-    if (gtk_tree_selection_get_selected (appGUI->event_checker_list_selection, &model, &iter)) {
+	date = g_date_new ();
+	g_return_if_fail (date != NULL);
 
-        gtk_tree_model_get (model, &iter, CE_COLUMN_DATE_JULIAN, &julian_day, -1);
+	if (gtk_tree_selection_get_selected (appGUI->event_checker_list_selection, &model, &iter)) {
+		gtk_tree_model_get (model, &iter, CE_COLUMN_DATE_JULIAN, &julian_day, -1);
 
-        dest_date = julian_to_date (julian_day);
-        if (dest_date != NULL) {
-            jump_to_date (dest_date->day, dest_date->month-1, dest_date->year, appGUI);
-            update_aux_calendars (appGUI);
-            gtk_notebook_set_current_page (GTK_NOTEBOOK (appGUI->notebook), PAGE_CALENDAR);
-            button_event_checker_show_osmo_window_cb (NULL, appGUI);
-            g_free(dest_date);
-        }
-    }
+		if (g_date_valid_julian (julian_day) == TRUE) {
+			g_date_set_julian (date, julian_day);
+			cal_jump_to_date (date, appGUI);
+			update_aux_calendars (appGUI);
+			gtk_notebook_set_current_page (GTK_NOTEBOOK (appGUI->notebook), PAGE_CALENDAR);
+			button_event_checker_show_osmo_window_cb (NULL, appGUI);
+		}
+	}
+
+	g_date_free (date);
 }
 
 /*------------------------------------------------------------------------------*/
@@ -702,7 +721,7 @@ gchar               *tmp_note, *summary, *first_name, *last_name, *category;
 gchar               tmpbuf[BUFFER_SIZE], template[BUFFER_SIZE], date_str[BUFFER_SIZE];
 
     start_date = config.lastrun_date;           /* - */
-    current_date = get_julian_for_today () + appGUI->check_ndays_events;     /* + */
+    current_date = utl_get_current_julian () + appGUI->check_ndays_events;     /* + */
 
     /* check day notes */
 
@@ -713,7 +732,7 @@ gchar               tmpbuf[BUFFER_SIZE], template[BUFFER_SIZE], date_str[BUFFER_
         for (i = 0, lnode = appGUI->cal->notes_list; lnode != NULL; lnode = lnode->next, i++) {
 
             day_note = g_slist_nth_data (appGUI->cal->notes_list, i);
-            julian_day = date_to_julian (day_note->day, day_note->month-1, day_note->year);
+            julian_day = utl_dmy_to_julian (day_note->day, day_note->month, day_note->year);
 
             j = start_date;
 
@@ -780,7 +799,7 @@ gchar               tmpbuf[BUFFER_SIZE], template[BUFFER_SIZE], date_str[BUFFER_
 
                 if (new_cdate != NULL) {
 
-                    age = appGUI->cal->year - g_date_get_year(new_cdate);
+                    age = g_date_get_year (appGUI->cal->date) - g_date_get_year (new_cdate);
 
                     if (age >= 0) {
 
@@ -852,33 +871,36 @@ gchar               tmpbuf[BUFFER_SIZE], template[BUFFER_SIZE], date_str[BUFFER_
     /* create columns */
 
     renderer = gtk_cell_renderer_text_new();
-    column = gtk_tree_view_column_new_with_attributes(_("Date"), renderer, 
-                                                      "text", CE_COLUMN_DATE, 
-                                                      NULL);
+    column = gtk_tree_view_column_new_with_attributes (_("Date"), renderer, 
+                                                       "text", CE_COLUMN_DATE, 
+                                                       NULL);
     gtk_tree_view_column_set_visible (column, TRUE);
-    gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->event_checker_list), column);
+    gtk_tree_view_append_column (GTK_TREE_VIEW(appGUI->event_checker_list), column);
 
     renderer = gtk_cell_renderer_text_new();
-    julian_day_column = gtk_tree_view_column_new_with_attributes("Julian", renderer, 
-                                                      "text", CE_COLUMN_DATE_JULIAN, 
-                                                      NULL);
+	g_object_set (G_OBJECT(renderer), "xpad", 8, NULL);
+    julian_day_column = gtk_tree_view_column_new_with_attributes ("Julian", renderer, 
+                                                                  "text", CE_COLUMN_DATE_JULIAN, 
+                                                                  NULL);
     gtk_tree_view_column_set_visible (julian_day_column, FALSE);
-    gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->event_checker_list), julian_day_column);
+    gtk_tree_view_append_column (GTK_TREE_VIEW(appGUI->event_checker_list), julian_day_column);
     gtk_tree_view_column_set_sort_column_id (julian_day_column, CE_COLUMN_DATE_JULIAN);
 
     renderer = gtk_cell_renderer_text_new();
-    column = gtk_tree_view_column_new_with_attributes(_("Type"), renderer, 
-                                                      "text", CE_COLUMN_EVENT_TYPE, 
-                                                      NULL);
+	g_object_set (G_OBJECT(renderer), "xpad", 8, NULL);
+    column = gtk_tree_view_column_new_with_attributes (_("Type"), renderer, 
+                                                       "text", CE_COLUMN_EVENT_TYPE, 
+                                                       NULL);
     gtk_tree_view_column_set_visible (column, TRUE);
-    gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->event_checker_list), column);
+    gtk_tree_view_append_column (GTK_TREE_VIEW(appGUI->event_checker_list), column);
 
     renderer = gtk_cell_renderer_text_new();
-    column = gtk_tree_view_column_new_with_attributes(_("Event"), renderer, 
-                                                      "text", CE_COLUMN_EVENT_LINE, 
-                                                      NULL);
+    g_object_set (G_OBJECT(renderer), "ellipsize", PANGO_ELLIPSIZE_END, NULL);
+    column = gtk_tree_view_column_new_with_attributes (_("Event"), renderer, 
+                                                       "text", CE_COLUMN_EVENT_LINE, 
+                                                       NULL);
     gtk_tree_view_column_set_visible (column, TRUE);
-    gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->event_checker_list), column);
+    gtk_tree_view_append_column (GTK_TREE_VIEW(appGUI->event_checker_list), column);
 
     /* insert day notes */
 
@@ -887,16 +909,16 @@ gchar               tmpbuf[BUFFER_SIZE], template[BUFFER_SIZE], date_str[BUFFER_
         for (i = 0, lnode = appGUI->cal->notes_list; lnode != NULL; lnode = lnode->next, i++) {
 
             day_note = g_slist_nth_data (appGUI->cal->notes_list, i);
-            julian_day = date_to_julian (day_note->day, day_note->month-1, day_note->year);
+            julian_day = utl_dmy_to_julian (day_note->day, day_note->month, day_note->year);
 
             j = start_date;
 
             while (j <= current_date) {
                 if (j == julian_day) {                  
-                    tmp_note = note_reformatting (day_note->note);
+                    tmp_note = cal_note_remove_empty_lines (day_note->note);
                     gtk_list_store_append(appGUI->event_checker_list_store, &iter);
                     sprintf(date_str, "%s\n(%s)", 
-                            julian_to_str (julian_day, config.date_format), get_julianday_name(julian_day));
+                            julian_to_str (julian_day, config.date_format), utl_get_julian_day_name (julian_day));
                     gtk_list_store_set(appGUI->event_checker_list_store, &iter, 
                                        CE_COLUMN_DATE, date_str,
                                        CE_COLUMN_DATE_JULIAN, julian_day, 
@@ -928,8 +950,8 @@ gchar               tmpbuf[BUFFER_SIZE], template[BUFFER_SIZE], date_str[BUFFER_
                 if (j == julian_day && (tasks_category_get_state (category, STATE_CALENDAR, appGUI) == TRUE ||
                                         tasks_category_get_state (category, STATE_TASKS, appGUI) == TRUE)) {
                     gtk_list_store_append(appGUI->event_checker_list_store, &iter);
-                    sprintf(date_str, "%s\n(%s)", 
-                            julian_to_str (julian_day, config.date_format), get_julianday_name(julian_day));
+                    g_snprintf (date_str, BUFFER_SIZE, "%s\n(%s)", 
+                            julian_to_str (julian_day, config.date_format), utl_get_julian_day_name (julian_day));
                     gtk_list_store_set(appGUI->event_checker_list_store, &iter, 
                                        CE_COLUMN_DATE, date_str,
                                        CE_COLUMN_DATE_JULIAN, julian_day, 
@@ -967,7 +989,7 @@ gchar               tmpbuf[BUFFER_SIZE], template[BUFFER_SIZE], date_str[BUFFER_
 
                 if (new_cdate != NULL) {
 
-                    age = appGUI->cal->year - g_date_get_year(new_cdate);
+                    age = g_date_get_year (appGUI->cal->date) - g_date_get_year(new_cdate);
 
                     if (age >= 0) {
 
@@ -986,7 +1008,7 @@ gchar               tmpbuf[BUFFER_SIZE], template[BUFFER_SIZE], date_str[BUFFER_
                                 }
                                 gtk_list_store_append(appGUI->event_checker_list_store, &iter);
                                 sprintf(date_str, "%s\n(%s)", 
-                                        julian_to_str (j, config.date_format), get_julianday_name(j));
+                                        julian_to_str (j, config.date_format), utl_get_julian_day_name (j));
                                 gtk_list_store_set(appGUI->event_checker_list_store, &iter, 
                                                    CE_COLUMN_DATE, date_str,
                                                    CE_COLUMN_DATE_JULIAN, j, 
