@@ -22,7 +22,7 @@
 #include "contacts.h"
 #include "i18n.h"
 #include "contacts_items.h"
-#include "gui_utils.h"
+#include "utils.h"
 #include "options_prefs.h"
 #include "stock_icons.h"
 #include "contacts_birthdays.h"
