@@ -21,7 +21,7 @@
 
 #include "contacts_export.h"
 #include "i18n.h"
-#include "gui_utils.h"
+#include "utils.h"
 #include "contacts.h"
 #include "calendar_utils.h"
 #include "stock_icons.h"
@@ -116,7 +116,6 @@ button_export_window_close_cb (GtkWidget *widget, gpointer data) {
 gint
 export_contacts_to_file(gchar *filename, gboolean header, GUI *appGUI) {
 
-gint response;
 GtkTreePath *sort_path, *filter_path, *path;
 gint i, j, a, b, c, e, n, m, max_field, exported;
 gchar *text;
@@ -128,14 +127,8 @@ gchar tmp_buffer_1[BUFFER_SIZE], tmp_buffer_2[BUFFER_SIZE];
 
     exported = 0;
 
-    if (g_file_test(filename, G_FILE_TEST_IS_REGULAR) == TRUE) {
-
-        response = gui_create_dialog(GTK_MESSAGE_QUESTION, _("Selected file exist! Overwrite?"), 
-                                     GTK_WINDOW(appGUI->cnt->export_window));
-
-        if (response == GTK_RESPONSE_NO || response == GTK_RESPONSE_DELETE_EVENT) {
-            return -1;
-        }
+    if (gui_check_overwrite_file (filename, appGUI->cnt->export_window, appGUI) != 0) {
+        return -1;
     }
 
     for(max_field = CONTACTS_NUM_COLUMNS-1; max_field >= 0; --max_field) {
