@@ -23,7 +23,7 @@
 #include "contacts_import_csv.h"
 #include "contacts_import_syncml.h"
 #include "i18n.h"
-#include "gui_utils.h"
+#include "utils.h"
 #include "contacts.h"
 #include "calendar_utils.h"
 #include "stock_icons.h"
