@@ -23,11 +23,11 @@
 #include "i18n.h"
 #include "contacts.h"
 #include "tasks.h"
-#include "gui_utils.h"
 #include "calendar.h"
 #include "calendar_notes.h"
 #include "calendar_widget.h"
 #include "calendar_utils.h"
+#include "utils.h"
 #include "options_prefs.h"
 #include "stock_icons.h"
 
@@ -167,8 +167,12 @@ const gchar *text;
     set_export_active(appGUI);
     gui_systray_tooltip_update(appGUI);
     contacts_fill_ids (appGUI);
-    calendar_refresh_marks (appGUI);
+    cal_refresh_marks (appGUI);
     update_aux_calendars (appGUI);
+
+    if (config.save_data_after_modification) {
+        write_contacts_entries (appGUI);
+    }
 }
 
 /*------------------------------------------------------------------------------*/
@@ -205,6 +209,10 @@ gchar tmpbuf[BUFFER_SIZE];
                     g_signal_emit_by_name(G_OBJECT(appGUI->cal->calendar), "day-selected");
                     set_export_active(appGUI);
                     gui_systray_tooltip_update(appGUI);
+
+                    if (config.save_data_after_modification) {
+                        write_contacts_entries (appGUI);
+                    }
                 }
             }
 
@@ -324,7 +332,7 @@ guint32 julian_day;
     gui_calendar_get_date (s_calendar, &year, &month, &day);
     gtk_widget_destroy(msg->appGUI->cnt->select_date_window);
 
-    julian_day = date_to_julian (day, month, year);
+    julian_day = utl_dmy_to_julian (day, month + 1, year);
 
     if (msg->data == (gpointer)COLUMN_BIRTH_DAY_DATE) {
         temp = julian_to_str (julian_day, DATE_FULL);
@@ -1367,6 +1375,10 @@ guint32 date;
 gchar temp[BUFFER_SIZE];
 xmlChar *escaped;
 
+    if ((appGUI->save_status & WRT_CONTACTS) != 0) return;
+
+    appGUI->save_status |= WRT_CONTACTS;
+
     doc = xmlNewDoc((const xmlChar *) "1.0");
     attr = xmlNewDocProp (doc, (const xmlChar *) "encoding", (const xmlChar *) "utf-8");
 
@@ -1423,6 +1435,8 @@ xmlChar *escaped;
 
     xmlSaveFormatFileEnc(prefs_get_config_filename(CONTACTS_ENTRIES_FILENAME, appGUI), doc, "utf-8", 1);
     xmlFreeDoc(doc);
+
+    appGUI->save_status &= ~WRT_CONTACTS;
 }
 
 /*------------------------------------------------------------------------------*/
