@@ -21,7 +21,7 @@
 
 #include "gui.h"
 #include "i18n.h"
-#include "gui_utils.h"
+#include "utils.h"
 #include "calendar.h"
 #include "calendar_notes.h"
 #include "calendar_fullyear.h"
@@ -55,7 +55,7 @@
 void
 gui_save_data_and_run_command (gchar *command, GUI *appGUI) {
     gui_save_all_data (appGUI);
-    gui_run_command (command);
+    utl_run_command (command);
 }
 
 /*------------------------------------------------------------------------------*/
@@ -63,7 +63,7 @@ gui_save_data_and_run_command (gchar *command, GUI *appGUI) {
 void
 gui_save_all_data (GUI *appGUI) {
 
-    write_notes (appGUI);
+    cal_write_notes (appGUI);
     write_tasks_entries(appGUI);
 #ifdef HAVE_LIBICAL
     write_ical_entries(appGUI);
@@ -125,6 +125,8 @@ gui_quit_osmo (gboolean ignore_geometry, GUI *appGUI) {
         }
 
         config.find_mode = gtk_combo_box_get_active (GTK_COMBO_BOX(appGUI->cnt->contacts_find_combobox));
+        config.current_category_in_tasks = gtk_combo_box_get_active (GTK_COMBO_BOX(appGUI->tsk->cf_combobox));
+        config.current_category_in_notes = gtk_combo_box_get_active (GTK_COMBO_BOX(appGUI->nte->cf_combobox));
 
         gtk_toggle_tool_button_set_active (GTK_TOGGLE_TOOL_BUTTON(appGUI->cal->notes_button), FALSE);
 
@@ -146,11 +148,11 @@ gui_quit_osmo (gboolean ignore_geometry, GUI *appGUI) {
     pango_font_description_free(appGUI->nte->fd_notes_font);
 
     if (appGUI->calendar_only == FALSE) {
-        config.lastrun_date = get_julian_for_today();
+        config.lastrun_date = utl_get_current_julian ();
         config.lastrun_time = get_seconds_for_today();
         gui_save_all_data (appGUI);
         free_notifications_list (appGUI);
-        free_notes_list (appGUI);
+        cal_free_notes_list (appGUI);
     }
 
     gui_url_remove_links (&appGUI->about_links_list, &appGUI->about_link_index);
@@ -342,8 +344,8 @@ gint page;
                 case GDK_space:
                     if (event->state & GDK_CONTROL_MASK) {  /* CTRL + Space */
                         config.enable_day_mark = !config.enable_day_mark;
-                        calendar_refresh_marks(appGUI);
-                        set_day_info (appGUI->cal->day, appGUI->cal->month, appGUI->cal->year, appGUI);
+                        cal_refresh_marks (appGUI);
+                        cal_set_day_info (appGUI);
                         update_aux_calendars (appGUI);
                         return TRUE;
                     } else {
@@ -375,7 +377,7 @@ gint page;
                     return TRUE;
                 case GDK_b:
                     if (appGUI->calendar_only == FALSE) {
-                        calendar_notes_browser (appGUI);
+                        cal_notes_browser (appGUI);
                     }
                     return TRUE;
             }
@@ -987,44 +989,41 @@ systray_popup_menu_show_options_selected_cb (gpointer user_data) {
 /*------------------------------------------------------------------------------*/
 
 void
-gui_systray_tooltip_update (GUI *appGUI) {
+gui_systray_tooltip_update (GUI *appGUI)
+{
+gchar desc[BUFFER_SIZE], tmpbuf[BUFFER_SIZE];
+guint32 julian;
+gboolean flag;
 
-gchar       desc[BUFFER_SIZE], tmpbuf[BUFFER_SIZE];
-gboolean    flag = FALSE;
-guint32     julian_day;
+	flag = FALSE;
+	julian = utl_get_current_julian ();
 
-    sprintf(tmpbuf, "%s", julian_to_str(get_julian_for_today(), DATE_FULL));
-    desc[0] = '\0';
-    strcat(desc, tmpbuf);
+	g_snprintf (tmpbuf, BUFFER_SIZE, "%s", julian_to_str (julian, DATE_FULL));
+	desc[0] = '\0';
+	g_strlcat (desc, tmpbuf, BUFFER_SIZE);
 
-    julian_day = get_julian_for_today();
 
-    if (check_contacts(julian_day, appGUI) == TRUE) {
-        strcat(desc, "\n");
-        flag = TRUE;
-        sprintf(tmpbuf, "\n%s", _("Birthday found"));
-        strcat(desc, tmpbuf);
-    }
+	if (check_contacts (julian, appGUI) == TRUE) {
+		g_strlcat (desc, "\n", BUFFER_SIZE);
+		g_snprintf (tmpbuf, BUFFER_SIZE, "\n%s", _("Birthday found"));
+		g_strlcat (desc, tmpbuf, BUFFER_SIZE);
+		flag = TRUE;
+	}
 
-    if (check_tasks(julian_day, FALSE, appGUI) == TRUE) {
-        if (flag == FALSE) {
-            strcat(desc, "\n");
-            flag = TRUE;
-        }
-        sprintf(tmpbuf, "\n%s", _("Task found"));
-        strcat(desc, tmpbuf);
-    }
+	if (check_tasks (julian, FALSE, appGUI) == TRUE) {
+		if (flag == FALSE) g_strlcat (desc, "\n", BUFFER_SIZE);
+		g_snprintf (tmpbuf, BUFFER_SIZE, "\n%s", _("Task found"));
+		g_strlcat (desc, tmpbuf, BUFFER_SIZE);
+		flag = TRUE;
+	}
 
-    if (check_note(get_current_day(), get_current_month()+1, get_current_year(), appGUI) == TRUE) {
-        if (flag == FALSE) {
-            strcat(desc, "\n");
-            flag = TRUE;
-        }
-        sprintf(tmpbuf, "\n%s", _("Day note available"));
-        strcat(desc, tmpbuf);
-    }
+	if (check_note (utl_get_current_day (), utl_get_current_month (), utl_get_current_year (), appGUI) == TRUE) {
+		if (flag == FALSE) g_strlcat (desc, "\n", BUFFER_SIZE);
+		g_snprintf (tmpbuf, BUFFER_SIZE, "\n%s", _("Day note available"));
+		g_strlcat (desc, tmpbuf, BUFFER_SIZE);
+	}
 
-    gtk_status_icon_set_tooltip (appGUI->osmo_trayicon, desc);
+	gtk_status_icon_set_tooltip (appGUI->osmo_trayicon, desc);
 }
 
 /*------------------------------------------------------------------------------*/
@@ -1100,7 +1099,7 @@ guint32     julian_day;
     g_signal_connect(G_OBJECT(appGUI->osmo_trayicon), "popup-menu",
                      G_CALLBACK(trayicon_popup_cb), appGUI);
 
-    julian_day = get_julian_for_today();
+    julian_day = utl_get_current_julian ();
     if (check_contacts(julian_day, appGUI) == TRUE) {
         gtk_status_icon_set_from_stock (appGUI->osmo_trayicon, OSMO_STOCK_SYSTRAY_BIRTHDAY);
     }
@@ -1188,10 +1187,12 @@ gchar tmpbuf[BUFFER_SIZE];
     appGUI->notebook = gtk_notebook_new();
     GTK_WIDGET_UNSET_FLAGS(appGUI->notebook, GTK_CAN_FOCUS);
     gtk_widget_show (appGUI->notebook);
-    gtk_notebook_set_tab_pos(GTK_NOTEBOOK(appGUI->notebook), config.tabs_position);
-    gtk_container_add(GTK_CONTAINER(appGUI->main_window), appGUI->notebook);
-    g_signal_connect(G_OBJECT(appGUI->notebook), "switch-page", 
-                     G_CALLBACK(notebook_sw_cb), appGUI);
+    gtk_notebook_set_tab_pos (GTK_NOTEBOOK(appGUI->notebook), config.tabs_position);
+    gtk_container_add (GTK_CONTAINER(appGUI->main_window), appGUI->notebook);
+    g_signal_connect (G_OBJECT(appGUI->notebook), "switch-page", 
+                      G_CALLBACK(notebook_sw_cb), appGUI);
+
+    gtk_notebook_set_scrollable (GTK_NOTEBOOK(appGUI->notebook), appGUI->tiny_gui);
 
     if (appGUI->calendar_only == TRUE) {
         gtk_notebook_set_show_tabs (GTK_NOTEBOOK(appGUI->notebook), FALSE);
@@ -1208,7 +1209,7 @@ gchar tmpbuf[BUFFER_SIZE];
         gui_create_options (appGUI);
         gui_create_about (appGUI);
 
-        read_notes (appGUI);
+        cal_read_notes (appGUI);
 
 #ifdef HAVE_LIBICAL
         ics_initialize_timezone ();
@@ -1225,7 +1226,12 @@ gchar tmpbuf[BUFFER_SIZE];
         read_notes_entries (appGUI);
 
         gui_create_category_combobox (GTK_COMBO_BOX (appGUI->nte->cf_combobox), appGUI->opt->notes_category_store, FALSE);
-        gtk_combo_box_set_active (GTK_COMBO_BOX(appGUI->nte->cf_combobox), 0);
+
+        if (config.remember_category_in_notes == TRUE) {
+            gtk_combo_box_set_active (GTK_COMBO_BOX(appGUI->nte->cf_combobox), config.current_category_in_notes);
+        } else {
+            gtk_combo_box_set_active (GTK_COMBO_BOX(appGUI->nte->cf_combobox), 0);
+        }
 #endif  /* HAVE_LIBGRINGOTTS */
 
         refresh_tasks (appGUI);
@@ -1599,11 +1605,11 @@ button_released_cb (GtkButton *button, gpointer user_data) {
 void 
 gui_create_about(GUI *appGUI) {
 
-GtkWidget *vbox1;
+GtkWidget *vbox1, *hbox;
 GtkWidget *label;
 GtkWidget *hseparator;
 GtkWidget *logo_area;
-GdkPixbuf *logo;
+GdkPixbuf *logo, *logo_scaled = NULL;
 GtkWidget *viewport;
 GtkWidget *hbuttonbox;
 GSList    *radiobutton_group = NULL;
@@ -1623,6 +1629,13 @@ char tmpbuf[BUFFER_SIZE];
     gtk_widget_show(logo_area);
     gtk_box_pack_start (GTK_BOX (vbox1), logo_area, FALSE, TRUE, 0);
 
+    if (appGUI->tiny_gui == TRUE) {
+        logo_scaled = gdk_pixbuf_scale_simple(logo,
+                                              gdk_pixbuf_get_width(logo) / 2, 
+                                              gdk_pixbuf_get_height(logo) / 2, 
+                                              GDK_INTERP_HYPER);
+    }
+
 #ifndef REV
     sprintf(tmpbuf, "%s %s", _("version"), VERSION);
 #else
@@ -1633,7 +1646,11 @@ char tmpbuf[BUFFER_SIZE];
     gtk_widget_show (label);
     gtk_box_pack_start (GTK_BOX (vbox1), label, FALSE, TRUE, 4);
 
-    gtk_image_set_from_pixbuf (GTK_IMAGE (logo_area), logo);
+    if (logo_scaled != NULL) {
+        gtk_image_set_from_pixbuf (GTK_IMAGE (logo_area), logo_scaled);
+    } else {
+        gtk_image_set_from_pixbuf (GTK_IMAGE (logo_area), logo);
+    }
 
     hseparator = gtk_hseparator_new ();
     gtk_widget_show (hseparator);
@@ -1641,13 +1658,24 @@ char tmpbuf[BUFFER_SIZE];
 
     /*--------------------------------------------------------------------------*/
 
-    hbuttonbox = gtk_hbutton_box_new ();
-    gtk_widget_show (hbuttonbox);
-    gtk_box_pack_start (GTK_BOX (vbox1), hbuttonbox, FALSE, TRUE, 0);
-    gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_END);
+    if (appGUI->tiny_gui == TRUE) {
+        hbox = gtk_hbox_new (FALSE, 0);
+        gtk_widget_show (hbox);
+        gtk_box_pack_start (GTK_BOX (vbox1), hbox, FALSE, TRUE, 0);
+    } else {
+        hbuttonbox = gtk_hbutton_box_new ();
+        gtk_widget_show (hbuttonbox);
+        gtk_box_pack_start (GTK_BOX (vbox1), hbuttonbox, FALSE, TRUE, 0);
+        gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_END);
+    }
 
-    appGUI->about_radiobutton = gui_stock_label_radio_button(_("About"), 
-                                                             OSMO_STOCK_ABOUT, GTK_ICON_SIZE_LARGE_TOOLBAR);
+    if (appGUI->tiny_gui == TRUE) {
+        appGUI->about_radiobutton = gui_stock_label_radio_button(NULL, OSMO_STOCK_ABOUT, GTK_ICON_SIZE_LARGE_TOOLBAR);
+    } else {
+        appGUI->about_radiobutton = gui_stock_label_radio_button(_("About"), 
+                                                                 OSMO_STOCK_ABOUT, GTK_ICON_SIZE_LARGE_TOOLBAR);
+        gtk_container_add (GTK_CONTAINER (hbuttonbox), appGUI->about_radiobutton);
+    }
     gtk_widget_show (appGUI->about_radiobutton);
 
     gtk_button_set_relief (GTK_BUTTON (appGUI->about_radiobutton), GTK_RELIEF_NONE);
@@ -1656,37 +1684,50 @@ char tmpbuf[BUFFER_SIZE];
     radiobutton_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (appGUI->about_radiobutton));
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (appGUI->about_radiobutton), TRUE);
     gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (appGUI->about_radiobutton), FALSE);
-    gtk_container_add (GTK_CONTAINER (hbuttonbox), appGUI->about_radiobutton);
 
     g_signal_connect (G_OBJECT (appGUI->about_radiobutton), "released",
                       G_CALLBACK(button_released_cb), appGUI);
 
-    appGUI->help_radiobutton = gui_stock_label_radio_button(_("Key shortcuts"), 
-                                                            OSMO_STOCK_HELP, GTK_ICON_SIZE_LARGE_TOOLBAR);
+    if (appGUI->tiny_gui == TRUE) {
+        appGUI->help_radiobutton = gui_stock_label_radio_button(NULL, OSMO_STOCK_HELP, GTK_ICON_SIZE_LARGE_TOOLBAR);
+    } else {
+        appGUI->help_radiobutton = gui_stock_label_radio_button(_("Key shortcuts"), 
+                                                                OSMO_STOCK_HELP, GTK_ICON_SIZE_LARGE_TOOLBAR);
+        gtk_container_add (GTK_CONTAINER (hbuttonbox), appGUI->help_radiobutton);
+    }
     gtk_widget_show (appGUI->help_radiobutton);
     gtk_button_set_relief (GTK_BUTTON (appGUI->help_radiobutton), GTK_RELIEF_NONE);
     GTK_WIDGET_UNSET_FLAGS(appGUI->help_radiobutton, GTK_CAN_FOCUS);
     gtk_radio_button_set_group (GTK_RADIO_BUTTON (appGUI->help_radiobutton), radiobutton_group);
     radiobutton_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (appGUI->help_radiobutton));
     gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (appGUI->help_radiobutton), FALSE);
-    gtk_container_add (GTK_CONTAINER (hbuttonbox), appGUI->help_radiobutton);
 
     g_signal_connect (G_OBJECT (appGUI->help_radiobutton), "released",
                       G_CALLBACK(button_released_cb), appGUI);
 
-    appGUI->license_radiobutton = gui_stock_label_radio_button(_("License"), 
-                                                               OSMO_STOCK_LICENSE, GTK_ICON_SIZE_LARGE_TOOLBAR);
+    if (appGUI->tiny_gui == TRUE) {
+        appGUI->license_radiobutton = gui_stock_label_radio_button(NULL, OSMO_STOCK_LICENSE, GTK_ICON_SIZE_LARGE_TOOLBAR);
+    } else {
+        appGUI->license_radiobutton = gui_stock_label_radio_button(_("License"), 
+                                                                   OSMO_STOCK_LICENSE, GTK_ICON_SIZE_LARGE_TOOLBAR);
+        gtk_container_add (GTK_CONTAINER (hbuttonbox), appGUI->license_radiobutton);
+    }
     gtk_widget_show (appGUI->license_radiobutton);
     gtk_button_set_relief (GTK_BUTTON (appGUI->license_radiobutton), GTK_RELIEF_NONE);  
     GTK_WIDGET_UNSET_FLAGS(appGUI->license_radiobutton, GTK_CAN_FOCUS);
     gtk_radio_button_set_group (GTK_RADIO_BUTTON (appGUI->license_radiobutton), radiobutton_group);
     radiobutton_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (appGUI->license_radiobutton));
     gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (appGUI->license_radiobutton), FALSE);
-    gtk_container_add (GTK_CONTAINER (hbuttonbox), appGUI->license_radiobutton);
 
     g_signal_connect (G_OBJECT (appGUI->license_radiobutton), "released",
                       G_CALLBACK(button_released_cb), appGUI);
 
+    if (appGUI->tiny_gui == TRUE) {
+        gtk_box_pack_end (GTK_BOX (hbox), appGUI->license_radiobutton, FALSE, TRUE, 0);
+        gtk_box_pack_end (GTK_BOX (hbox), appGUI->help_radiobutton, FALSE, TRUE, 0);
+        gtk_box_pack_end (GTK_BOX (hbox), appGUI->about_radiobutton, FALSE, TRUE, 0);
+    }
+
     /*--------------------------------------------------------------------------*/
 
     hseparator = gtk_hseparator_new ();
