@@ -28,6 +28,7 @@
 #include <unistd.h>
 #include <fcntl.h>
 #include <ctype.h>
+#include <math.h>
 
 #include <gtk/gtk.h>
 #include <gdk/gdk.h>
@@ -54,6 +55,7 @@
 #define     MAX_WEEKS               6
 #define     DAYS_PER_WEEK           7
 #define     FULL_YEAR_COLS          37
+#define     OPAQUE                  65535
 #define     BUFFER_SIZE             2048
 
 enum notebook_page {
@@ -75,6 +77,7 @@ enum {                  /* tasks columns */
     TA_COLUMN_DUE_DATE_JULIAN,
     TA_COLUMN_DUE_TIME,
     TA_COLUMN_START_DATE_JULIAN,
+    TA_COLUMN_DONE_DATE_JULIAN,
     TA_COLUMN_PRIORITY,
     TA_COLUMN_CATEGORY,
     TA_COLUMN_SUMMARY,
@@ -126,6 +129,13 @@ enum {                  /* contacts columns */
     CONTACTS_NUM_COLUMNS
 };
 
+enum {
+    WRT_CALENDAR_NOTES = 1,
+    WRT_TASKS = 1 << 1,
+    WRT_CONTACTS = 1 << 2,
+    WRT_NOTES = 1 << 3
+};
+
 typedef struct {
 
     GtkWidget *calendar;
@@ -141,9 +151,6 @@ typedef struct {
     PangoFontDescription *fd_day_name_font;
 
     /* current selected date */
-    guint day;
-    guint month;
-    guint year;
     GDate *date;
 
     /* used for 'jump to' button in date calculator */
@@ -273,6 +280,16 @@ typedef struct {
     GtkWidget *ical_events_list;
     GtkTreeSelection *ical_events_list_selection;
     GtkListStore *ical_events_list_store;
+    GtkWidget *ical_export_window;
+    GtkWidget *output_file_entry;
+    GtkWidget *ical_export_vpaned;
+    GtkWidget *export_begin_period_calendar;
+    GtkWidget *export_end_period_calendar;
+    GtkWidget *export_day_note_textview;
+    GtkWidget *export_events_list_treeview;
+    GtkTreeSelection *export_events_list_selection;
+    GtkListStore *export_events_list_store;
+    GtkWidget *use_date_period_checkbutton;
 
     /* notes browser */
     GtkWidget *day_notes_window;
@@ -519,6 +536,7 @@ typedef struct {
 
     GtkWidget *title_label;
     GtkWidget *editor_textview;
+    GtkWidget *editor_scrolledwindow;
     gboolean changed;
     gboolean find_next_flag;
     gboolean buffer_check_modify_enable;
@@ -621,12 +639,15 @@ typedef struct {
     GtkWidget *ct_delete_items_checkbutton;
     GtkWidget *ct_hide_items_checkbutton;
     GtkWidget *ct_add_item_checkbutton;
+    GtkWidget *ct_remember_category_checkbutton;
     GtkWidget *tasks_enable_rules_hint_checkbutton;
     GtkWidget *vc_due_date_checkbutton;
     GtkWidget *vc_type_checkbutton;
     GtkWidget *vc_category_checkbutton;
     GtkWidget *vc_priority_checkbutton;
     GtkWidget *postpone_time_spinbutton;
+    GtkWidget *global_notification_cmd_entry;
+    GtkWidget *global_notification_valid_image;
 
     /* contacts */
     GtkWidget *contacts_vbox;
@@ -646,8 +667,9 @@ typedef struct {
     GtkWidget *contacts_photo_size_combobox;
     GtkWidget *contact_tag_color_picker;
     GtkWidget *contact_link_color_picker;
-    GtkWidget *name_font_size_spinbutton;
-    GtkWidget *tags_font_size_spinbutton;
+    GtkWidget *vc_age_checkbutton;
+    GtkWidget *vc_birthday_date_checkbutton;
+    GtkWidget *vc_zodiac_sign_checkbutton;
 
     /* notes */
     GtkWidget *notes_vbox;
@@ -665,6 +687,8 @@ typedef struct {
     GtkWidget *notes_sort_mode_combobox;
     GtkWidget *notes_category_add_button;
     GtkWidget *notes_category_remove_button;
+    GtkWidget *cn_remember_category_checkbutton;
+    GtkWidget *cn_use_system_date_checkbutton;
 
     /* general */
     GtkWidget *general_vbox;
@@ -677,6 +701,7 @@ typedef struct {
     GtkWidget *disable_underline_in_links_checkbutton;
     GtkWidget *default_stock_icons_checkbutton;
     GtkWidget *remember_latest_tab_checkbutton;
+    GtkWidget *save_data_checkbutton;
     GtkWidget *enable_systray_checkbutton;
     GtkWidget *start_minimised_checkbutton;
     GtkWidget *hide_calendar_checkbutton;
@@ -710,6 +735,7 @@ typedef struct {
     gboolean check_events;
     gint check_ndays_events;
     gchar *config_path;
+    gboolean tiny_gui;
     
     /* links handling */
     gboolean hovering_over_link;
@@ -740,6 +766,13 @@ typedef struct {
 	guint32 run_date;
 	gint key_counter;
 	gint run_time;
+    gint save_status;
+
+    /* print */
+    gint print_font_size;
+    gint print_nlines;
+    gint print_npages;
+    gint print_lines_per_page;
 
     /* modules */
     CALENDAR *cal;
