@@ -22,6 +22,7 @@
 #include "gui.h"
 #include "calendar.h"
 #include "calendar_utils.h"
+#include "utils.h"
 #include "i18n.h"
 #include "check_events.h"
 #include "options_prefs.h"
@@ -49,12 +50,14 @@ gboolean cmd_calendar = FALSE;
 gboolean cmd_check_events = FALSE;
 gint cmd_check_ndays_events = 0;
 gchar *cmd_cfg_path = NULL;
+gboolean cmd_tiny_gui = FALSE;
 
 GOptionEntry cmd_options[] = {
     { "calendar",   'c', 0, G_OPTION_ARG_NONE, &cmd_calendar, N_("Show small calendar window"), NULL  },
     { "check",      'e', 0, G_OPTION_ARG_NONE, &cmd_check_events, N_("Check for events since last run"), NULL  },
     { "days",       'd', 0, G_OPTION_ARG_INT, &cmd_check_ndays_events, N_("Number of days to check forward for events (default: 0)"), NULL  },
     { "config",     's', 0, G_OPTION_ARG_STRING, &cmd_cfg_path, N_("Set absolute path for settings and data files"), "PATH"  },
+    { "tinygui",    't', 0, G_OPTION_ARG_NONE, &cmd_tiny_gui, N_("Modify GUI to use Osmo on low resolutions"), NULL  },
     { NULL }
 };
 
@@ -80,7 +83,7 @@ GOptionEntry cmd_options[] = {
     appGUI->nte = nte;
     appGUI->opt = opt;
 
-    appGUI->run_date = get_julian_for_today ();
+    appGUI->run_date = utl_get_current_julian ();
     appGUI->run_time = get_seconds_for_today ();
     appGUI->key_counter = 0;
 
@@ -93,6 +96,9 @@ GOptionEntry cmd_options[] = {
 
     appGUI->calendar_only = FALSE;
     appGUI->check_events = FALSE;
+    appGUI->tiny_gui = FALSE;
+    appGUI->save_status = 0;
+    appGUI->print_font_size = 10;
 
 	appGUI->cal->date = g_date_new ();
 	g_return_val_if_fail (appGUI->cal->date != NULL, -1);
@@ -132,6 +138,7 @@ GOptionEntry cmd_options[] = {
     appGUI->check_events = cmd_check_events;
     appGUI->check_ndays_events = cmd_check_ndays_events;
     appGUI->config_path = cmd_cfg_path;
+    appGUI->tiny_gui = cmd_tiny_gui;
 
     if (prefs_get_config_filename (CONFIG_FILENAME, appGUI) == NULL) {
         fprintf(stderr, "%s\n", _("ERROR: Cannot create config files"));
@@ -193,7 +200,7 @@ GOptionEntry cmd_options[] = {
     }
 
     if (appGUI->calendar_only == FALSE) {
-        config.lastrun_date = get_julian_for_today();
+        config.lastrun_date = utl_get_current_julian ();
         config.lastrun_time = get_seconds_for_today();
     }
 
