@@ -22,11 +22,11 @@
 #include "notes.h"
 #include "i18n.h"
 #include "calendar.h"
-#include "gui_utils.h"
 #include "calendar_notes.h"
 #include "options_prefs.h"
 #include "notes_items.h"
 #include "calendar_utils.h"
+#include "utils.h"
 #include "stock_icons.h"
 
 #ifdef HAVE_LIBGRINGOTTS
@@ -39,10 +39,12 @@ void
 notes_show_selector_editor (gint mode, GUI *appGUI) {
 
 GtkTextBuffer *buffer;
+GtkTextMark *cursor;
 GtkTextIter iter;
 GtkTreeIter n_iter;
 GtkTreePath *path, *sort_path, *filter_path;
 gchar *name;
+gint line;
 gchar tmpbuf[BUFFER_SIZE];
 
     if (mode == SELECTOR) { 
@@ -72,16 +74,19 @@ gchar tmpbuf[BUFFER_SIZE];
         gtk_tree_path_free (filter_path);
 
         gtk_tree_model_get_iter (GTK_TREE_MODEL(appGUI->nte->notes_list_store), &n_iter, path);
-        gtk_tree_model_get (GTK_TREE_MODEL(appGUI->nte->notes_list_store), &n_iter, N_COLUMN_NAME, &name, -1);
+        gtk_tree_model_get (GTK_TREE_MODEL(appGUI->nte->notes_list_store), &n_iter, 
+                            N_COLUMN_NAME, &name, 
+                            N_COLUMN_EDITOR_LINE, &line, -1);
         sprintf (tmpbuf, "<i>%s</i>", name);
         gtk_label_set_markup (GTK_LABEL (appGUI->nte->title_label), tmpbuf);
         g_free(name);
         gtk_tree_path_free (path);
 
         buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (appGUI->nte->editor_textview));
-        gtk_text_buffer_get_start_iter (GTK_TEXT_BUFFER (buffer), &iter);
+        gtk_text_buffer_get_iter_at_line (GTK_TEXT_BUFFER (buffer), &iter, line);
         gtk_text_buffer_place_cursor (GTK_TEXT_BUFFER (buffer), &iter);
-
+        cursor = gtk_text_buffer_get_mark (buffer, "insert");
+        gtk_text_view_scroll_to_mark (GTK_TEXT_VIEW (appGUI->nte->editor_textview), cursor, 0.0, TRUE, 0.0, 0.0);
     }
 }
 
@@ -118,7 +123,7 @@ GtkTreeModel *model;
 
         if (gtk_tree_selection_get_selected (appGUI->nte->notes_list_selection, &model, &iter)) {
 
-            current_date = get_julian_for_today ();
+            current_date = utl_get_current_julian ();
             current_time = get_seconds_for_today ();
 
             gtk_tree_model_sort_convert_iter_to_child_iter (GTK_TREE_MODEL_SORT(appGUI->nte->notes_sort), 
@@ -166,8 +171,11 @@ void
 editor_close_cb (GtkWidget *widget, gpointer user_data) {
 
 GtkTextBuffer *buffer;
-GtkTextIter iter_s, iter_e;
-gint response;
+GtkTextIter iter_s, iter_e, l_iter;
+GtkTreeIter n_iter;
+GtkTreePath *path, *sort_path, *filter_path;
+gint response, line;
+GtkTextMark *cursor;
 gchar tmpbuf[BUFFER_SIZE];
 
     GUI *appGUI = (GUI *)user_data;
@@ -196,10 +204,29 @@ gchar tmpbuf[BUFFER_SIZE];
         appGUI->nte->filename = NULL;
     }
 
+    cursor = gtk_text_buffer_get_mark (buffer, "insert");
+    gtk_text_buffer_get_iter_at_mark (buffer, &l_iter, cursor);
+    line = gtk_text_iter_get_line (&l_iter);
+
     gtk_text_buffer_get_bounds(buffer, &iter_s, &iter_e);
     gtk_text_buffer_delete(buffer, &iter_s, &iter_e);  
     appGUI->nte->buffer_check_modify_enable = FALSE;
 
+    gtk_tree_view_get_cursor (GTK_TREE_VIEW (appGUI->nte->notes_list), &sort_path, NULL);
+
+    if (sort_path == NULL) return;
+    filter_path = gtk_tree_model_sort_convert_path_to_child_path (GTK_TREE_MODEL_SORT(appGUI->nte->notes_sort), sort_path);
+    gtk_tree_path_free (sort_path);
+
+    if (filter_path == NULL) return;
+    path = gtk_tree_model_filter_convert_path_to_child_path (GTK_TREE_MODEL_FILTER(appGUI->nte->notes_filter), filter_path);
+    gtk_tree_path_free (filter_path);
+
+    gtk_tree_model_get_iter (GTK_TREE_MODEL(appGUI->nte->notes_list_store), &n_iter, path);
+    gtk_list_store_set (appGUI->nte->notes_list_store, &n_iter, 
+                        N_COLUMN_EDITOR_LINE, line, -1);
+    gtk_tree_path_free (path);
+
     notes_show_selector_editor (SELECTOR, appGUI);
 }
 
@@ -319,6 +346,172 @@ notes_delete_item_cb (GtkWidget *widget, gpointer data) {
 
 /*------------------------------------------------------------------------------*/
 
+void
+insert_current_date_and_time_cb (GtkWidget *widget, gpointer data) {
+
+gchar temp[BUFFER_SIZE];
+time_t tmm;
+
+    GUI *appGUI = (GUI *)data;
+
+    if (config.use_system_date_in_notes == TRUE) {
+        tmm = time(NULL);
+        gtk_text_buffer_insert_at_cursor (gtk_text_view_get_buffer (GTK_TEXT_VIEW (appGUI->nte->editor_textview)), 
+                                          asctime (localtime (&tmm)), -1);
+    } else {
+        g_snprintf (temp, BUFFER_SIZE, "%s\n", 
+                    get_date_time_full_str (utl_get_current_julian(), get_seconds_for_today()));
+        gtk_text_buffer_insert_at_cursor (gtk_text_view_get_buffer (GTK_TEXT_VIEW (appGUI->nte->editor_textview)), 
+                                          temp, -1);
+    }
+}
+
+/*------------------------------------------------------------------------------*/
+
+void
+insert_separator_cb (GtkWidget *widget, gpointer data) {
+
+gint chars, i, sbwidth;
+gchar tmpbuf[BUFFER_SIZE];
+PangoLayout *layout;
+PangoRectangle logical_rect;
+GtkWidget *vscrollbar;
+GValue *value;
+
+    GUI *appGUI = (GUI *)data;
+
+    value = g_new0 (GValue, 1);
+	value = g_value_init (value, G_TYPE_INT);
+    vscrollbar = gtk_scrolled_window_get_vscrollbar (GTK_SCROLLED_WINDOW (appGUI->nte->editor_scrolledwindow));
+    gtk_widget_style_get_property (vscrollbar, "slider-width", value);
+    sbwidth = g_value_get_int (value);
+	g_value_unset (value);
+    g_free (value);
+
+    memset (tmpbuf, 0, BUFFER_SIZE);
+
+    tmpbuf[0] = config.text_separator;
+    layout = gtk_widget_create_pango_layout (widget, NULL);
+    pango_layout_set_font_description (layout, appGUI->nte->fd_notes_font);
+    pango_layout_set_text (layout, tmpbuf, -1);
+    pango_layout_get_pixel_extents (layout, NULL, &logical_rect);
+
+    if (GTK_WIDGET_VISIBLE(vscrollbar) == TRUE) {
+        chars = ((appGUI->nte->editor_textview)->allocation.width) / logical_rect.width;
+    } else {
+        chars = ((appGUI->nte->editor_textview)->allocation.width - sbwidth) / logical_rect.width;
+    }
+    chars = (chars > BUFFER_SIZE) ? BUFFER_SIZE - 2 : chars;
+
+    g_object_unref (G_OBJECT(layout));
+
+    i = 0;
+    tmpbuf[i++] = '\n';
+    while (i < chars) tmpbuf[i++] = config.text_separator;
+    tmpbuf[i++] = '\n';
+
+    gtk_text_buffer_insert_at_cursor (gtk_text_view_get_buffer (GTK_TEXT_VIEW (appGUI->nte->editor_textview)), 
+                                      tmpbuf, -1);
+}
+
+/*------------------------------------------------------------------------------*/
+
+void
+text_info_cb (GtkWidget *widget, gpointer user_data)
+{
+GtkTreeIter n_iter;
+GtkTreePath *path, *sort_path, *filter_path;
+GtkTextIter start_iter, end_iter;
+gchar tmpbuf[BUFFER_SIZE], temp[BUFFER_SIZE];
+GtkTextBuffer *buffer;
+guint32 modified_date, created_date;
+gint modified_time, created_time;
+gchar *text;
+gchar *modified_date_str, *created_date_str;
+PangoLogAttr *attrs;
+gint i, words, lines, chars, white_chars, bytes;
+
+	GUI *appGUI = (GUI *) user_data;
+
+    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (appGUI->nte->editor_textview));
+
+    if (gtk_text_buffer_get_has_selection (buffer) == TRUE) {
+        gtk_text_buffer_get_selection_bounds (buffer, &start_iter, &end_iter);
+    } else {
+        gtk_text_buffer_get_start_iter (buffer, &start_iter);
+        gtk_text_buffer_get_end_iter (buffer, &end_iter);
+    }
+
+    text = gtk_text_buffer_get_text (GTK_TEXT_BUFFER (buffer), &start_iter, &end_iter, FALSE);
+    if (text == NULL) return;
+
+    words = 0;
+    white_chars = 0;
+    lines = gtk_text_buffer_get_line_count (buffer);
+    bytes = strlen (text);
+    chars = g_utf8_strlen (text, -1);
+
+    attrs = g_new0 (PangoLogAttr, chars + 1);   /* based on code by Paolo Maggi */
+    pango_get_log_attrs (text, -1, 0, pango_language_from_string ("C"), attrs, chars + 1);
+
+    for (i=0; i < chars; i++) {
+        if (attrs[i].is_white) white_chars++;
+        if (attrs[i].is_word_start) words++;
+    }
+
+    if (chars == 0) lines = 0;
+
+    gtk_tree_view_get_cursor (GTK_TREE_VIEW (appGUI->nte->notes_list), &sort_path, NULL);
+
+    if (sort_path == NULL) return;
+    filter_path = gtk_tree_model_sort_convert_path_to_child_path (GTK_TREE_MODEL_SORT(appGUI->nte->notes_sort), sort_path);
+    gtk_tree_path_free (sort_path);
+
+    if (filter_path == NULL) return;
+    path = gtk_tree_model_filter_convert_path_to_child_path (GTK_TREE_MODEL_FILTER(appGUI->nte->notes_filter), filter_path);
+    gtk_tree_path_free (filter_path);
+
+    gtk_tree_model_get_iter (GTK_TREE_MODEL(appGUI->nte->notes_list_store), &n_iter, path);
+    gtk_tree_model_get (GTK_TREE_MODEL(appGUI->nte->notes_list_store), &n_iter, 
+                        N_COLUMN_LAST_CHANGES_DATE_JULIAN, &modified_date, 
+                        N_COLUMN_LAST_CHANGES_TIME, &modified_time,
+                        N_COLUMN_CREATE_DATE_JULIAN, &created_date,
+                        N_COLUMN_CREATE_TIME, &created_time,
+                        -1);
+
+    g_snprintf (temp, BUFFER_SIZE, "%s", 
+                get_date_time_full_str (modified_date, modified_time));
+    g_snprintf (tmpbuf, BUFFER_SIZE, " (%s)", julian_to_str(modified_date, DATE_DAY_OF_WEEK_NAME));
+	g_strlcat (temp, tmpbuf, BUFFER_SIZE);
+    modified_date_str = g_strdup(temp);
+
+    g_snprintf (temp, BUFFER_SIZE, "%s", 
+                get_date_time_full_str (created_date, created_time));
+    g_snprintf (tmpbuf, BUFFER_SIZE, " (%s)", julian_to_str(created_date, DATE_DAY_OF_WEEK_NAME));
+	g_strlcat (temp, tmpbuf, BUFFER_SIZE);
+    created_date_str = g_strdup(temp);
+
+	g_snprintf (tmpbuf, BUFFER_SIZE, "<b>%s</b>: %d\n<b>%s</b>: %d\n<b>%s</b>: %d\n<b>%s</b>: %d\n<b>%s</b>: %d\n\n<b>%s</b>: %s\n<b>%s</b>: %s\n",
+                _("Words"), words,
+                _("Lines"), lines,
+                _("Characters"), chars,
+                _("White characters"), white_chars,
+                _("Bytes"), bytes,
+                _("Modified"), modified_date_str,
+                _("Created"), created_date_str);
+
+    g_free (modified_date_str);
+    g_free (created_date_str);
+    gtk_tree_path_free (path);
+
+    g_free (text);
+    g_free (attrs);
+
+	gui_create_dialog (GTK_MESSAGE_INFO, tmpbuf, GTK_WINDOW (appGUI->main_window));
+}
+
+/*------------------------------------------------------------------------------*/
+
 gint
 notes_list_dbclick_cb(GtkWidget * widget, GdkEventButton * event, gpointer func_data) {
 
@@ -561,10 +754,10 @@ guint32 last_changes_date_s;
         return 0;
     }
 
-    gtk_tree_model_get(model, iter_a, N_COLUMN_NAME, &name_a, 
-                       N_COLUMN_LAST_CHANGES_DATE_JULIAN, &last_changes_date_a, N_COLUMN_CATEGORY, &category_a, -1);
-    gtk_tree_model_get(model, iter_b, N_COLUMN_NAME, &name_b, 
-                       N_COLUMN_LAST_CHANGES_DATE_JULIAN, &last_changes_date_b, N_COLUMN_CATEGORY, &category_b, -1);
+    gtk_tree_model_get (model, iter_a, N_COLUMN_NAME, &name_a, 
+                        N_COLUMN_LAST_CHANGES_DATE_JULIAN, &last_changes_date_a, N_COLUMN_CATEGORY, &category_a, -1);
+    gtk_tree_model_get (model, iter_b, N_COLUMN_NAME, &name_b, 
+                        N_COLUMN_LAST_CHANGES_DATE_JULIAN, &last_changes_date_b, N_COLUMN_CATEGORY, &category_b, -1);
 
     
     if (name_a == NULL) {
@@ -675,7 +868,7 @@ guint32 last_changes_date_s;
 /*------------------------------------------------------------------------------*/
 
 void 
-gui_create_notes(GUI *appGUI) {
+gui_create_notes (GUI *appGUI) {
 
 GtkWidget           *vbox1;
 GtkWidget           *scrolled_win;
@@ -722,6 +915,10 @@ const gchar *ui_info_editor =
 "    <toolitem name=\"mark_color\" action=\"mark_color\" />\n"
 "    <toolitem name=\"clear\" action=\"clear\" />\n"
 "    <separator name=\"sep2\" />\n"
+"    <toolitem name=\"insert_date_time\" action=\"insert_date_time\" />\n"
+"    <toolitem name=\"insert_separator\" action=\"insert_separator\" />\n"
+"    <toolitem name=\"text_info\" action=\"text_info\" />\n"
+"    <separator name=\"sep3\" />\n"
 "    <toolitem name=\"close\" action=\"close\" />\n"
 "  </toolbar>\n";
 
@@ -734,6 +931,9 @@ GtkActionEntry entries_editor[] = {
   { "mark_color", OSMO_STOCK_EDITOR_HIGHLIGHT, _("Highlight"), NULL, _("Highlight"), NULL },
   { "clear", OSMO_STOCK_EDITOR_CLEAR, _("Clear attributes"), NULL, _("Clear attributes"), NULL },
   { "save", OSMO_STOCK_EDITOR_SAVE, _("Save note"), NULL, _("Save note"), NULL },
+  { "insert_date_time", OSMO_STOCK_EDITOR_INSERT_DATE_TIME, _("Insert current date and time"), NULL, _("Insert current date and time"), NULL },
+  { "insert_separator", OSMO_STOCK_EDITOR_INSERT_SEPARATOR, _("Insert separator"), NULL, _("Insert separator"), NULL },
+  { "text_info", OSMO_STOCK_EDITOR_INFO, _("Statistics"), NULL, _("Statistics"), NULL },
   { "close", OSMO_STOCK_CLOSE, _("Close editor"), NULL, _("Close editor"), NULL },
 };
 
@@ -839,9 +1039,15 @@ guint n_entries_editor = G_N_ELEMENTS (entries_editor);
     gtk_widget_show (appGUI->nte->cf_combobox);
     gtk_combo_box_set_focus_on_click (GTK_COMBO_BOX (appGUI->nte->cf_combobox), FALSE);
     GTK_WIDGET_UNSET_FLAGS(appGUI->nte->cf_combobox, GTK_CAN_FOCUS);
-    gtk_table_attach (GTK_TABLE (table), appGUI->nte->cf_combobox, 1, 2, 0, 1,
-                     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
-                     (GtkAttachOptions) (GTK_FILL), 0, 0);
+    if (appGUI->tiny_gui == TRUE) {
+        gtk_table_attach (GTK_TABLE (table), appGUI->nte->cf_combobox, 1, 2, 0, 1,
+                         (GtkAttachOptions) (0),
+                         (GtkAttachOptions) (0), 0, 0);
+    } else {
+        gtk_table_attach (GTK_TABLE (table), appGUI->nte->cf_combobox, 1, 2, 0, 1,
+                         (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
+                         (GtkAttachOptions) (GTK_FILL), 0, 0);
+    }
     g_signal_connect(appGUI->nte->cf_combobox, "changed", 
                      G_CALLBACK(notes_category_filter_cb), appGUI);
     g_signal_connect(G_OBJECT(appGUI->nte->cf_combobox), "focus", 
@@ -849,7 +1055,9 @@ guint n_entries_editor = G_N_ELEMENTS (entries_editor);
 
     appGUI->nte->n_items_label = gtk_label_new ("");
     gtk_widget_show (appGUI->nte->n_items_label);
-    gtk_widget_set_size_request (appGUI->nte->n_items_label, 100, -1);
+    if (appGUI->tiny_gui == FALSE) {
+        gtk_widget_set_size_request (appGUI->nte->n_items_label, 100, -1);
+    }
     gtk_table_attach (GTK_TABLE (table), appGUI->nte->n_items_label, 3, 4, 0, 1,
                      (GtkAttachOptions) (GTK_FILL),
                      (GtkAttachOptions) (0), 0, 0);
@@ -875,7 +1083,7 @@ guint n_entries_editor = G_N_ELEMENTS (entries_editor);
                                                        G_TYPE_STRING, G_TYPE_STRING,
                                                        G_TYPE_STRING, G_TYPE_UINT, G_TYPE_UINT,
                                                        G_TYPE_STRING, G_TYPE_UINT, G_TYPE_UINT,
-                                                       G_TYPE_STRING);
+                                                       G_TYPE_UINT, G_TYPE_STRING);
 
     appGUI->nte->notes_filter = gtk_tree_model_filter_new(GTK_TREE_MODEL(appGUI->nte->notes_list_store), NULL);
     gtk_tree_model_filter_set_visible_func (GTK_TREE_MODEL_FILTER(appGUI->nte->notes_filter), 
@@ -966,6 +1174,14 @@ guint n_entries_editor = G_N_ELEMENTS (entries_editor);
     gtk_tree_view_column_set_visible (column, FALSE);
     gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->nte->notes_list), column);
 
+    renderer = gtk_cell_renderer_text_new();
+    column = gtk_tree_view_column_new_with_attributes(NULL,
+                                                      renderer,
+                                                      "text", N_COLUMN_EDITOR_LINE,
+                                                      NULL);
+    gtk_tree_view_column_set_visible (column, FALSE);
+    gtk_tree_view_append_column (GTK_TREE_VIEW(appGUI->nte->notes_list), column);
+
     renderer = gtk_cell_renderer_text_new();
     column = gtk_tree_view_column_new_with_attributes(NULL,
                                                       renderer,
@@ -1002,15 +1218,15 @@ guint n_entries_editor = G_N_ELEMENTS (entries_editor);
     gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport), GTK_SHADOW_IN);
     gtk_box_pack_start (GTK_BOX (appGUI->nte->vbox_editor), viewport, TRUE, TRUE, 0);
   
-    scrolled_win = gtk_scrolled_window_new (NULL, NULL);
-    gtk_widget_show (scrolled_win);
-    gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_win), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-    gtk_container_add (GTK_CONTAINER (viewport), scrolled_win);
+    appGUI->nte->editor_scrolledwindow = gtk_scrolled_window_new (NULL, NULL);
+    gtk_widget_show (appGUI->nte->editor_scrolledwindow);
+    gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (appGUI->nte->editor_scrolledwindow), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+    gtk_container_add (GTK_CONTAINER (viewport), appGUI->nte->editor_scrolledwindow);
 
     appGUI->nte->editor_textview = gtk_text_view_new ();
     gtk_widget_show (appGUI->nte->editor_textview);
-    gtk_container_add (GTK_CONTAINER (scrolled_win), appGUI->nte->editor_textview);
-    gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (appGUI->nte->editor_textview), GTK_WRAP_WORD);
+    gtk_container_add (GTK_CONTAINER (appGUI->nte->editor_scrolledwindow), appGUI->nte->editor_textview);
+    gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (appGUI->nte->editor_textview), GTK_WRAP_WORD_CHAR);
     gtk_text_view_set_pixels_above_lines(GTK_TEXT_VIEW(appGUI->nte->editor_textview), 4);
     gtk_text_view_set_left_margin(GTK_TEXT_VIEW(appGUI->nte->editor_textview), 4);
     gtk_text_view_set_right_margin(GTK_TEXT_VIEW(appGUI->nte->editor_textview), 4);
@@ -1050,6 +1266,12 @@ guint n_entries_editor = G_N_ELEMENTS (entries_editor);
     g_signal_connect (G_OBJECT (gtk_ui_manager_get_widget (appGUI->nte->notes_uim_editor_widget, "/toolbar/mark_color")), 
                       "clicked", G_CALLBACK (set_text_attribute_cb), appGUI);
 
+    g_signal_connect (G_OBJECT(gtk_ui_manager_get_widget (appGUI->nte->notes_uim_editor_widget, "/toolbar/insert_date_time")), 
+                      "clicked", G_CALLBACK(insert_current_date_and_time_cb), appGUI);
+    g_signal_connect (G_OBJECT(gtk_ui_manager_get_widget (appGUI->nte->notes_uim_editor_widget, "/toolbar/insert_separator")), 
+                      "clicked", G_CALLBACK(insert_separator_cb), appGUI);
+    g_signal_connect (G_OBJECT(gtk_ui_manager_get_widget (appGUI->nte->notes_uim_editor_widget, "/toolbar/text_info")), 
+                      "clicked", G_CALLBACK(text_info_cb), appGUI);
     g_signal_connect (G_OBJECT (gtk_ui_manager_get_widget (appGUI->nte->notes_uim_editor_widget, "/toolbar/clear")), 
                       "clicked", G_CALLBACK (clear_text_attributes_cb), appGUI);
     g_signal_connect (G_OBJECT (gtk_ui_manager_get_widget (appGUI->nte->notes_uim_editor_widget, "/toolbar/close")), 
