@@ -21,7 +21,6 @@
 
 #include "notes_items.h"
 #include "i18n.h"
-#include "gui_utils.h"
 #include "options_gui.h"
 #include "options_prefs.h"
 #include "notes.h"
@@ -29,6 +28,7 @@
 #include "calendar_notes.h"
 #include "calendar_widget.h"
 #include "calendar_utils.h"
+#include "utils.h"
 #include "stock_icons.h"
 #include "options_gui_notes.h"
 
@@ -133,6 +133,10 @@ gint i, n;
         gtk_tree_path_free (path);
 
         notes_edit_close_cb (widget, NULL, data);
+
+        if (config.save_data_after_modification) {
+            write_notes_entries (appGUI);
+        }
     }
 
 }
@@ -370,6 +374,10 @@ gchar tmpbuf[BUFFER_SIZE];
                 gtk_list_store_remove(list_store, &iter);
                 gtk_tree_path_free(path);
                 update_notes_items(appGUI);
+
+                if (config.save_data_after_modification) {
+                    write_notes_entries (appGUI);
+                }
             }
         }
     }
@@ -445,7 +453,7 @@ gboolean flag;
 
     notes_add_close_cb (NULL, NULL, appGUI);
 
-    current_date = get_julian_for_today ();
+    current_date = utl_get_current_julian ();
     current_time = get_seconds_for_today ();
     current_filename = g_strdup (notes_get_filename (appGUI));
 	context = grg_context_initialize_defaults ((unsigned char*) "OSM");
@@ -492,10 +500,15 @@ gboolean flag;
                            N_COLUMN_CREATE_DATE, get_date_time_str (current_date, current_time),
                            N_COLUMN_CREATE_DATE_JULIAN, current_date,
                            N_COLUMN_CREATE_TIME, current_time,
+                           N_COLUMN_EDITOR_LINE, 0,
                            N_COLUMN_FILENAME, current_filename, -1);
         g_free (category);
 
         update_notes_items(appGUI);
+
+        if (config.save_data_after_modification) {
+            write_notes_entries (appGUI);
+        }
     }
 
     g_free(current_filename);
@@ -901,7 +914,7 @@ xmlNodePtr node, cnode, category_node, main_node;
 GtkTreeIter iter;
 gchar name[BUFFER_SIZE], category[BUFFER_SIZE];
 gchar *notes_dir;
-gint last_changes_time, create_time;
+gint last_changes_time, create_time, editor_line;
 guint32 last_changes_date_julian, create_date_julian;
 
     notes_dir = g_strdup(prefs_get_config_filename(NOTES_DIRNAME, appGUI));
@@ -962,6 +975,7 @@ guint32 last_changes_date_julian, create_date_julian;
 
                         cnode = node->xmlChildrenNode;
 
+                        editor_line = 0;
 
                         while (cnode != NULL) {
 
@@ -1012,6 +1026,14 @@ guint32 last_changes_date_julian, create_date_julian;
                                     xmlFree(key);
                                 }
                             }
+
+                            if ((!xmlStrcmp(cnode->name, (const xmlChar *) "editor_line"))) {
+                                key = xmlNodeListGetString(doc, cnode->xmlChildrenNode, 1);
+                                if (key != NULL) {
+                                    sscanf((gchar *) key, "%d", &editor_line);
+                                    xmlFree(key);
+                                }
+                            }
  
                             if ((!xmlStrcmp(cnode->name, (const xmlChar *) "filename"))) {
                                 key = xmlNodeListGetString(doc, cnode->xmlChildrenNode, 1);
@@ -1027,6 +1049,7 @@ guint32 last_changes_date_julian, create_date_julian;
                                                            N_COLUMN_CREATE_DATE, get_date_time_str (create_date_julian, create_time),
                                                            N_COLUMN_CREATE_DATE_JULIAN, create_date_julian,
                                                            N_COLUMN_CREATE_TIME, create_time,
+                                                           N_COLUMN_EDITOR_LINE, editor_line,
                                                            N_COLUMN_FILENAME, (gchar *)key, -1);
                                     }
                                     xmlFree(key);
@@ -1070,9 +1093,13 @@ xmlAttrPtr attr;
 GtkTreeIter iter;
 gchar temp[BUFFER_SIZE];
 gchar *category, *name, *note_filename;
-gint last_changes_time, create_time;
+gint last_changes_time, create_time, editor_line;
 guint32 last_changes_date_julian, create_date_julian;
 
+    if ((appGUI->save_status & WRT_NOTES) != 0) return;
+
+    appGUI->save_status |= WRT_NOTES;
+
     doc = xmlNewDoc((const xmlChar *) "1.0");
     attr = xmlNewDocProp (doc, (const xmlChar *) "encoding", (const xmlChar *) "utf-8");
 
@@ -1103,6 +1130,7 @@ guint32 last_changes_date_julian, create_date_julian;
                            N_COLUMN_LAST_CHANGES_TIME, &last_changes_time,
                            N_COLUMN_CREATE_DATE_JULIAN, &create_date_julian,
                            N_COLUMN_CREATE_TIME, &create_time,
+                           N_COLUMN_EDITOR_LINE, &editor_line,
                            N_COLUMN_FILENAME, &note_filename, -1);
 
         note_node = xmlNewChild(node, NULL, (const xmlChar *) "entry", (xmlChar *) NULL);
@@ -1119,12 +1147,16 @@ guint32 last_changes_date_julian, create_date_julian;
         xmlNewChild(note_node, NULL, (const xmlChar *) "create_date", (xmlChar *) temp);
         sprintf(temp, "%d", (guint32) create_time);
         xmlNewChild(note_node, NULL, (const xmlChar *) "create_time", (xmlChar *) temp);
+        sprintf(temp, "%d", (guint32) editor_line);
+        xmlNewChild(note_node, NULL, (const xmlChar *) "editor_line", (xmlChar *) temp);
         xmlNewChild(note_node, NULL, (const xmlChar *) "filename", (xmlChar *) note_filename);
         g_free (note_filename);
     }
 
     xmlSaveFormatFileEnc(prefs_get_config_filename(NOTES_ENTRIES_FILENAME, appGUI), doc, "utf-8", 1);
     xmlFreeDoc(doc);
+
+    appGUI->save_status &= ~WRT_NOTES;
 }
 
 /*------------------------------------------------------------------------------*/
