@@ -20,7 +20,7 @@
  */
 
 #include "options_gui.h"
-#include "gui_utils.h"
+#include "utils.h"
 #include "calendar.h"
 #include "calendar_notes.h"
 #include "calendar_widget.h"
@@ -179,7 +179,7 @@ options_button_released_cb (GtkButton *button, gpointer user_data) {
 void
 gui_create_options(GUI *appGUI) {
 
-GtkWidget           *vbox1, *vbox2;
+GtkWidget           *vbox1, *vbox2, *hbox;
 GtkWidget           *hseparator;
 GtkWidget           *hbuttonbox;
 GtkWidget           *scrolledwindow;
@@ -199,13 +199,24 @@ GSList              *radiobutton_group = NULL;
 
     /*--------------------------------------------------------------------------*/
 
-    hbuttonbox = gtk_hbutton_box_new ();
-    gtk_widget_show (hbuttonbox);
-    gtk_box_pack_start (GTK_BOX (vbox1), hbuttonbox, FALSE, TRUE, 0);
-    gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_END);
+    if (appGUI->tiny_gui == TRUE) {
+        hbox = gtk_hbox_new (FALSE, 0);
+        gtk_widget_show (hbox);
+        gtk_box_pack_start (GTK_BOX (vbox1), hbox, FALSE, TRUE, 0);
+    } else {
+        hbuttonbox = gtk_hbutton_box_new ();
+        gtk_widget_show (hbuttonbox);
+        gtk_box_pack_start (GTK_BOX (vbox1), hbuttonbox, FALSE, TRUE, 0);
+        gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_END);
+    }
 
-    appGUI->opt->calendar_options_radiobutton = gui_stock_label_radio_button(_("Calendar"), 
-                                                             OSMO_STOCK_CALENDAR, GTK_ICON_SIZE_LARGE_TOOLBAR);
+    if (appGUI->tiny_gui == TRUE) {
+        appGUI->opt->calendar_options_radiobutton = gui_stock_label_radio_button(NULL, OSMO_STOCK_CALENDAR, GTK_ICON_SIZE_LARGE_TOOLBAR);
+    } else {
+        appGUI->opt->calendar_options_radiobutton = gui_stock_label_radio_button(_("Calendar"), 
+                                                                 OSMO_STOCK_CALENDAR, GTK_ICON_SIZE_LARGE_TOOLBAR);
+        gtk_container_add (GTK_CONTAINER (hbuttonbox), appGUI->opt->calendar_options_radiobutton);
+    }
     gtk_widget_show (appGUI->opt->calendar_options_radiobutton);
     gtk_button_set_relief (GTK_BUTTON (appGUI->opt->calendar_options_radiobutton), GTK_RELIEF_NONE);  
     GTK_WIDGET_UNSET_FLAGS(appGUI->opt->calendar_options_radiobutton, GTK_CAN_FOCUS);
@@ -213,67 +224,92 @@ GSList              *radiobutton_group = NULL;
     radiobutton_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (appGUI->opt->calendar_options_radiobutton));
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (appGUI->opt->calendar_options_radiobutton), TRUE);
     gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (appGUI->opt->calendar_options_radiobutton), FALSE);
-    gtk_container_add (GTK_CONTAINER (hbuttonbox), appGUI->opt->calendar_options_radiobutton);
 
     g_signal_connect (G_OBJECT (appGUI->opt->calendar_options_radiobutton), "released",
                       G_CALLBACK(options_button_released_cb), appGUI);
 
-    appGUI->opt->tasks_options_radiobutton = gui_stock_label_radio_button(_("Tasks"), 
-                                                             OSMO_STOCK_TASKS, GTK_ICON_SIZE_LARGE_TOOLBAR);
+    if (appGUI->tiny_gui == TRUE) {
+        appGUI->opt->tasks_options_radiobutton = gui_stock_label_radio_button(NULL, OSMO_STOCK_TASKS, GTK_ICON_SIZE_LARGE_TOOLBAR);
+    } else {
+        appGUI->opt->tasks_options_radiobutton = gui_stock_label_radio_button(_("Tasks"), 
+                                                                 OSMO_STOCK_TASKS, GTK_ICON_SIZE_LARGE_TOOLBAR);
+        gtk_container_add (GTK_CONTAINER (hbuttonbox), appGUI->opt->tasks_options_radiobutton);
+    }
     gtk_widget_show (appGUI->opt->tasks_options_radiobutton);
     gtk_button_set_relief (GTK_BUTTON (appGUI->opt->tasks_options_radiobutton), GTK_RELIEF_NONE);  
     GTK_WIDGET_UNSET_FLAGS(appGUI->opt->tasks_options_radiobutton, GTK_CAN_FOCUS);
     gtk_radio_button_set_group (GTK_RADIO_BUTTON (appGUI->opt->tasks_options_radiobutton), radiobutton_group);
     radiobutton_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (appGUI->opt->tasks_options_radiobutton));
     gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (appGUI->opt->tasks_options_radiobutton), FALSE);
-    gtk_container_add (GTK_CONTAINER (hbuttonbox), appGUI->opt->tasks_options_radiobutton);
 
     g_signal_connect (G_OBJECT (appGUI->opt->tasks_options_radiobutton), "released",
                       G_CALLBACK(options_button_released_cb), appGUI);
 
-    appGUI->opt->contacts_options_radiobutton = gui_stock_label_radio_button(_("Contacts"), 
-                                                             OSMO_STOCK_CONTACTS, GTK_ICON_SIZE_LARGE_TOOLBAR);
+    if (appGUI->tiny_gui == TRUE) {
+        appGUI->opt->contacts_options_radiobutton = gui_stock_label_radio_button(NULL, OSMO_STOCK_CONTACTS, GTK_ICON_SIZE_LARGE_TOOLBAR);
+    } else {
+        appGUI->opt->contacts_options_radiobutton = gui_stock_label_radio_button(_("Contacts"), 
+                                                                 OSMO_STOCK_CONTACTS, GTK_ICON_SIZE_LARGE_TOOLBAR);
+        gtk_container_add (GTK_CONTAINER (hbuttonbox), appGUI->opt->contacts_options_radiobutton);
+    }
     gtk_widget_show (appGUI->opt->contacts_options_radiobutton);
     gtk_button_set_relief (GTK_BUTTON (appGUI->opt->contacts_options_radiobutton), GTK_RELIEF_NONE);  
     GTK_WIDGET_UNSET_FLAGS(appGUI->opt->contacts_options_radiobutton, GTK_CAN_FOCUS);
     gtk_radio_button_set_group (GTK_RADIO_BUTTON (appGUI->opt->contacts_options_radiobutton), radiobutton_group);
     radiobutton_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (appGUI->opt->contacts_options_radiobutton));
     gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (appGUI->opt->contacts_options_radiobutton), FALSE);
-    gtk_container_add (GTK_CONTAINER (hbuttonbox), appGUI->opt->contacts_options_radiobutton);
 
     g_signal_connect (G_OBJECT (appGUI->opt->contacts_options_radiobutton), "released",
                       G_CALLBACK(options_button_released_cb), appGUI);
 
 #ifdef HAVE_LIBGRINGOTTS
 
-    appGUI->opt->notes_options_radiobutton = gui_stock_label_radio_button(_("Notes"), 
-                                                             OSMO_STOCK_NOTES, GTK_ICON_SIZE_LARGE_TOOLBAR);
+    if (appGUI->tiny_gui == TRUE) {
+        appGUI->opt->notes_options_radiobutton = gui_stock_label_radio_button(NULL, OSMO_STOCK_NOTES, GTK_ICON_SIZE_LARGE_TOOLBAR);
+    } else {
+        appGUI->opt->notes_options_radiobutton = gui_stock_label_radio_button(_("Notes"), 
+                                                                 OSMO_STOCK_NOTES, GTK_ICON_SIZE_LARGE_TOOLBAR);
+        gtk_container_add (GTK_CONTAINER (hbuttonbox), appGUI->opt->notes_options_radiobutton);
+    }
     gtk_widget_show (appGUI->opt->notes_options_radiobutton);
     gtk_button_set_relief (GTK_BUTTON (appGUI->opt->notes_options_radiobutton), GTK_RELIEF_NONE);  
     GTK_WIDGET_UNSET_FLAGS(appGUI->opt->notes_options_radiobutton, GTK_CAN_FOCUS);
     gtk_radio_button_set_group (GTK_RADIO_BUTTON (appGUI->opt->notes_options_radiobutton), radiobutton_group);
     radiobutton_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (appGUI->opt->notes_options_radiobutton));
     gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (appGUI->opt->notes_options_radiobutton), FALSE);
-    gtk_container_add (GTK_CONTAINER (hbuttonbox), appGUI->opt->notes_options_radiobutton);
 
     g_signal_connect (G_OBJECT (appGUI->opt->notes_options_radiobutton), "released",
                       G_CALLBACK(options_button_released_cb), appGUI);
 
 #endif  /* HAVE_LIBGRINGOTTS */
 
-    appGUI->opt->general_options_radiobutton = gui_stock_label_radio_button(_("General"), 
-                                                             OSMO_STOCK_PREFERENCES, GTK_ICON_SIZE_LARGE_TOOLBAR);
+    if (appGUI->tiny_gui == TRUE) {
+        appGUI->opt->general_options_radiobutton = gui_stock_label_radio_button(NULL, OSMO_STOCK_PREFERENCES, GTK_ICON_SIZE_LARGE_TOOLBAR);
+    } else {
+        appGUI->opt->general_options_radiobutton = gui_stock_label_radio_button(_("General"), 
+                                                                 OSMO_STOCK_PREFERENCES, GTK_ICON_SIZE_LARGE_TOOLBAR);
+        gtk_container_add (GTK_CONTAINER (hbuttonbox), appGUI->opt->general_options_radiobutton);
+    }
     gtk_widget_show (appGUI->opt->general_options_radiobutton);
     gtk_button_set_relief (GTK_BUTTON (appGUI->opt->general_options_radiobutton), GTK_RELIEF_NONE);  
     GTK_WIDGET_UNSET_FLAGS(appGUI->opt->general_options_radiobutton, GTK_CAN_FOCUS);
     gtk_radio_button_set_group (GTK_RADIO_BUTTON (appGUI->opt->general_options_radiobutton), radiobutton_group);
     radiobutton_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (appGUI->opt->general_options_radiobutton));
     gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (appGUI->opt->general_options_radiobutton), FALSE);
-    gtk_container_add (GTK_CONTAINER (hbuttonbox), appGUI->opt->general_options_radiobutton);
 
     g_signal_connect (G_OBJECT (appGUI->opt->general_options_radiobutton), "released",
                       G_CALLBACK(options_button_released_cb), appGUI);
 
+    if (appGUI->tiny_gui == TRUE) {
+        gtk_box_pack_end (GTK_BOX (hbox), appGUI->opt->general_options_radiobutton, FALSE, TRUE, 0);
+#ifdef HAVE_LIBGRINGOTTS
+        gtk_box_pack_end (GTK_BOX (hbox), appGUI->opt->notes_options_radiobutton, FALSE, TRUE, 0);
+#endif  /* HAVE_LIBGRINGOTTS */
+        gtk_box_pack_end (GTK_BOX (hbox), appGUI->opt->contacts_options_radiobutton, FALSE, TRUE, 0);
+        gtk_box_pack_end (GTK_BOX (hbox), appGUI->opt->tasks_options_radiobutton, FALSE, TRUE, 0);
+        gtk_box_pack_end (GTK_BOX (hbox), appGUI->opt->calendar_options_radiobutton, FALSE, TRUE, 0);
+    }
+
     /*--------------------------------------------------------------------------*/
 
     hseparator = gtk_hseparator_new ();
@@ -363,6 +399,8 @@ GSList              *radiobutton_group = NULL;
                                   config.start_minimised_in_systray);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->remember_latest_tab_checkbutton), 
                                   config.remember_latest_tab);
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->save_data_checkbutton), 
+                                  config.save_data_after_modification);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->tasks_enable_rules_hint_checkbutton), 
                                   config.tasks_rules_hint);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->ct_bold_items_checkbutton), 
@@ -373,6 +411,8 @@ GSList              *radiobutton_group = NULL;
                                   config.delete_completed);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->ct_add_item_checkbutton), 
                                   config.add_edit);
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->ct_remember_category_checkbutton), 
+                                  config.remember_category_in_tasks);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->vc_due_date_checkbutton), 
                                   config.visible_due_date_column);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->vc_type_checkbutton), 
@@ -387,6 +427,18 @@ GSList              *radiobutton_group = NULL;
                                   config.show_after_search);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->contacts_hide_group_column_checkbutton), 
                                   config.hide_group_column);
+
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->cn_remember_category_checkbutton), 
+                                  config.remember_category_in_notes);
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->cn_use_system_date_checkbutton), 
+                                  config.use_system_date_in_notes);
+
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->vc_age_checkbutton), 
+                                  config.visible_age_column);
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->vc_birthday_date_checkbutton), 
+                                  config.visible_birthday_date_column);
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->vc_zodiac_sign_checkbutton), 
+                                  config.visible_zodiac_sign_column);
  
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->hide_calendar_checkbutton), 
                                   config.hide_calendar);
@@ -395,6 +447,10 @@ GSList              *radiobutton_group = NULL;
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->hide_contacts_checkbutton), 
                                   config.hide_contacts);
 
+    gtk_entry_set_text(GTK_ENTRY(appGUI->opt->global_notification_cmd_entry), config.global_notification_command);
+    gui_update_command_status (appGUI->opt->global_notification_cmd_entry, 
+                               appGUI->opt->global_notification_valid_image, appGUI);
+
 #ifdef HAVE_LIBGRINGOTTS
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->hide_notes_checkbutton), 
                                   config.hide_notes);
