@@ -20,7 +20,7 @@
  */
 
 #include "options_gui_contacts.h"
-#include "gui_utils.h"
+#include "utils.h"
 #include "calendar.h"
 #include "calendar_notes.h"
 #include "calendar_widget.h"
@@ -258,37 +258,6 @@ contacts_hide_group_column_changed_cb (GtkComboBox *widget, gpointer user_data)
 
 /*------------------------------------------------------------------------------*/
 
-void
-name_font_size_changed_cb (GtkSpinButton *spinbutton, gpointer user_data) {
-
-    GUI *appGUI = (GUI *)user_data;
-
-    if (!appGUI->opt->callback_active) return;
-
-    /*config.name_font_size = (gint) gtk_spin_button_get_value (GTK_SPIN_BUTTON(appGUI->opt->name_font_size_spinbutton));*/
-
-    /*g_object_set (G_OBJECT (appGUI->cnt->contact_name_tag_object), "size", config.name_font_size * PANGO_SCALE, NULL);*/
-
-}
-
-/*------------------------------------------------------------------------------*/
-
-void
-tags_font_size_changed_cb (GtkSpinButton *spinbutton, gpointer user_data) {
-
-    GUI *appGUI = (GUI *)user_data;
-
-    if (!appGUI->opt->callback_active) return;
-
-    /*config.tags_font_size = (gint) gtk_spin_button_get_value (GTK_SPIN_BUTTON(appGUI->opt->tags_font_size_spinbutton));*/
-
-    /*g_object_set (G_OBJECT (appGUI->cnt->contact_color_tag_object), "size", config.tags_font_size * PANGO_SCALE, NULL);*/
-    /*g_object_set (G_OBJECT (appGUI->cnt->contact_tags_value_tag_object), "size", config.tags_font_size * PANGO_SCALE, NULL);*/
-
-}
-
-/*------------------------------------------------------------------------------*/
-
 void
 contacts_photo_size_changed_cb (GtkComboBox *widget, gpointer user_data) {
 
@@ -382,10 +351,26 @@ GtkTreeModel *model;
 
 /*------------------------------------------------------------------------------*/
 
+void
+visible_bb_columns_changed_cb (GtkComboBox *widget, gpointer user_data) {
+
+    GUI *appGUI = (GUI *)user_data;
+
+    if (!appGUI->opt->callback_active) return;
+
+    config.visible_age_column = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->opt->vc_age_checkbutton));
+    config.visible_birthday_date_column = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->opt->vc_birthday_date_checkbutton));
+    config.visible_zodiac_sign_column = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->opt->vc_zodiac_sign_checkbutton));
+
+}
+
+/*------------------------------------------------------------------------------*/
+
 void
 gui_create_contacts_options_page (GtkWidget *vbox, GUI *appGUI) {
 
 GtkWidget           *appearance_vbox, *sorting_vbox, *groups_vbox;
+GtkWidget           *visible_columns_vbox;
 GtkWidget           *label;
 GtkWidget           *colors_hbox, *photo_hbox;
 GtkWidget           *frame;
@@ -767,6 +752,58 @@ gint i;
     gtk_combo_box_append_text (GTK_COMBO_BOX (appGUI->opt->contacts_sort_mode_combobox), tmpbuf);
     gtk_combo_box_set_active (GTK_COMBO_BOX(appGUI->opt->contacts_sort_mode_combobox), config.contacts_sorting_mode);
 
+    frame = gtk_frame_new (NULL);
+    gtk_widget_show (frame);
+    gtk_box_pack_start (GTK_BOX (appGUI->opt->contacts_vbox), frame, FALSE, TRUE, 0);
+    gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
+    sprintf(tmpbuf, "<b>%s</b>", _("Visible columns in birthdays browser"));
+    label = gtk_label_new (tmpbuf);
+    gtk_widget_show (label);
+    gtk_frame_set_label_widget (GTK_FRAME (frame), label);
+    gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
+    gtk_misc_set_padding (GTK_MISC (label), 0, 4);
+
+    alignment = gtk_alignment_new (0.5, 0.5, 1, 1);
+    gtk_widget_show (alignment);
+    gtk_container_add (GTK_CONTAINER (frame), alignment);
+    gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 12, 12, 0);
+
+    visible_columns_vbox = gtk_vbox_new (FALSE, 0);
+    gtk_widget_show (visible_columns_vbox);
+    gtk_container_add (GTK_CONTAINER (alignment), visible_columns_vbox);
+
+    table = gtk_table_new (1, 3, FALSE);
+    gtk_widget_show (table);
+    gtk_box_pack_start (GTK_BOX (visible_columns_vbox), table, FALSE, FALSE, 0);
+    gtk_table_set_row_spacings (GTK_TABLE (table), 4);
+    gtk_table_set_col_spacings (GTK_TABLE (table), 8);
+
+    appGUI->opt->vc_age_checkbutton = gtk_check_button_new_with_mnemonic (_("Age"));
+    GTK_WIDGET_UNSET_FLAGS(appGUI->opt->vc_age_checkbutton, GTK_CAN_FOCUS);
+    gtk_widget_show (appGUI->opt->vc_age_checkbutton);
+    g_signal_connect (G_OBJECT (appGUI->opt->vc_age_checkbutton), "toggled",
+                      G_CALLBACK (visible_bb_columns_changed_cb), appGUI);
+    gtk_table_attach (GTK_TABLE (table), appGUI->opt->vc_age_checkbutton, 0, 1, 0, 1,
+                      (GtkAttachOptions) (GTK_FILL | GTK_EXPAND),
+                      (GtkAttachOptions) (0), 0, 0);
+
+    appGUI->opt->vc_birthday_date_checkbutton = gtk_check_button_new_with_mnemonic (_("Birthday date"));
+    GTK_WIDGET_UNSET_FLAGS(appGUI->opt->vc_birthday_date_checkbutton, GTK_CAN_FOCUS);
+    gtk_widget_show (appGUI->opt->vc_birthday_date_checkbutton);
+    g_signal_connect (G_OBJECT (appGUI->opt->vc_birthday_date_checkbutton), "toggled",
+                      G_CALLBACK (visible_bb_columns_changed_cb), appGUI);
+    gtk_table_attach (GTK_TABLE (table), appGUI->opt->vc_birthday_date_checkbutton, 1, 2, 0, 1,
+                      (GtkAttachOptions) (GTK_FILL | GTK_EXPAND),
+                      (GtkAttachOptions) (0), 0, 0);
+
+    appGUI->opt->vc_zodiac_sign_checkbutton = gtk_check_button_new_with_mnemonic (_("Zodiac sign"));
+    GTK_WIDGET_UNSET_FLAGS(appGUI->opt->vc_zodiac_sign_checkbutton, GTK_CAN_FOCUS);
+    gtk_widget_show (appGUI->opt->vc_zodiac_sign_checkbutton);
+    g_signal_connect (G_OBJECT (appGUI->opt->vc_zodiac_sign_checkbutton), "toggled",
+                      G_CALLBACK (visible_bb_columns_changed_cb), appGUI);
+    gtk_table_attach (GTK_TABLE (table), appGUI->opt->vc_zodiac_sign_checkbutton, 2, 3, 0, 1,
+                      (GtkAttachOptions) (GTK_FILL | GTK_EXPAND),
+                      (GtkAttachOptions) (0), 0, 0);
 }
 
 /*------------------------------------------------------------------------------*/
