@@ -20,7 +20,7 @@
  */
 
 #include "options_gui_general.h"
-#include "gui_utils.h"
+#include "utils.h"
 #include "calendar.h"
 #include "calendar_notes.h"
 #include "calendar_widget.h"
@@ -249,6 +249,19 @@ remember_latest_tab_changed_cb (GtkComboBox *widget, gpointer user_data) {
 
 /*------------------------------------------------------------------------------*/
 
+void
+save_data_changed_cb (GtkComboBox *widget, gpointer user_data) {
+
+    GUI *appGUI = (GUI *)user_data;
+
+    if (!appGUI->opt->callback_active) return;
+ 
+    config.save_data_after_modification = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(appGUI->opt->save_data_checkbutton));
+
+}
+
+/*------------------------------------------------------------------------------*/
+
 void
 helpers_entry_changed_cb (GtkEntry *entry, gpointer  user_data) {
 
@@ -523,7 +536,7 @@ gchar       tmpbuf[BUFFER_SIZE];
     gtk_widget_show (general_vbox);
     gtk_container_add (GTK_CONTAINER (alignment), general_vbox);
 
-    table = gtk_table_new (3, 4, FALSE);
+    table = gtk_table_new (4, 4, FALSE);
     gtk_widget_show (table);
     gtk_box_pack_start (GTK_BOX (general_vbox), table, FALSE, FALSE, 0);
     gtk_table_set_col_spacings (GTK_TABLE (table), 16);
@@ -592,6 +605,14 @@ gchar       tmpbuf[BUFFER_SIZE];
                     (GtkAttachOptions) (GTK_FILL),
                     (GtkAttachOptions) (GTK_FILL), 0, 0);
 
+    appGUI->opt->save_data_checkbutton = gtk_check_button_new_with_mnemonic (_("Save data after every modification"));
+    GTK_WIDGET_UNSET_FLAGS(appGUI->opt->save_data_checkbutton, GTK_CAN_FOCUS);
+    gtk_widget_show (appGUI->opt->save_data_checkbutton);
+    g_signal_connect (G_OBJECT (appGUI->opt->save_data_checkbutton), "toggled",
+                      G_CALLBACK (save_data_changed_cb), appGUI);
+    gtk_table_attach (GTK_TABLE (table), appGUI->opt->save_data_checkbutton, 0, 4, 3, 4,
+                    (GtkAttachOptions) (GTK_FILL),
+                    (GtkAttachOptions) (GTK_FILL), 0, 0);
 
     frame = gtk_frame_new (NULL);
     gtk_widget_show (frame);
