@@ -20,7 +20,7 @@
  */
 
 #include "options_gui_notes.h"
-#include "gui_utils.h"
+#include "utils.h"
 #include "calendar.h"
 #include "calendar_notes.h"
 #include "calendar_widget.h"
@@ -336,10 +336,27 @@ notes_sort_mode_changed_cb (GtkComboBox *widget, gpointer user_data) {
 
 /*------------------------------------------------------------------------------*/
 
+void
+remember_notes_category_cb (GtkToggleButton *togglebutton, gpointer user_data) {
+
+    config.remember_category_in_notes = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (togglebutton));
+}
+
+/*------------------------------------------------------------------------------*/
+
+void
+use_system_date_cb (GtkToggleButton *togglebutton, gpointer user_data) {
+
+    config.use_system_date_in_notes = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (togglebutton));
+}
+
+/*------------------------------------------------------------------------------*/
+
 void
 gui_create_notes_options_page (GtkWidget *vbox, GUI *appGUI) {
 
-GtkWidget           *sorting_vbox, *appearance_vbox, *encryption_vbox, *categories_vbox;
+GtkWidget           *sorting_vbox, *appearance_vbox, *encryption_vbox;
+GtkWidget           *categories_vbox, *notes_opt_vbox;
 GtkWidget           *frame;
 GtkWidget           *alignment;
 GtkWidget           *table;
@@ -695,6 +712,39 @@ gchar tmpbuf[BUFFER_SIZE];
     gtk_combo_box_append_text (GTK_COMBO_BOX (appGUI->opt->notes_sort_mode_combobox), tmpbuf);
     gtk_combo_box_set_active (GTK_COMBO_BOX(appGUI->opt->notes_sort_mode_combobox), config.notes_sorting_mode);
 
+    frame = gtk_frame_new (NULL);
+    gtk_widget_show (frame);
+    gtk_box_pack_start (GTK_BOX (appGUI->opt->notes_vbox), frame, FALSE, TRUE, 0);
+    gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
+    sprintf(tmpbuf, "<b>%s</b>", _("Notes options"));
+    label = gtk_label_new (tmpbuf);
+    gtk_widget_show (label);
+    gtk_frame_set_label_widget (GTK_FRAME (frame), label);
+    gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
+    gtk_misc_set_padding (GTK_MISC (label), 0, 4);
+
+    alignment = gtk_alignment_new (0.5, 0.5, 1, 1);
+    gtk_widget_show (alignment);
+    gtk_container_add (GTK_CONTAINER (frame), alignment);
+    gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 12, 12, 0);
+
+    notes_opt_vbox = gtk_vbox_new (FALSE, 0);
+    gtk_widget_show (notes_opt_vbox);
+    gtk_container_add (GTK_CONTAINER (alignment), notes_opt_vbox);
+
+    appGUI->opt->cn_remember_category_checkbutton = gtk_check_button_new_with_mnemonic (_("Remember the last selected category"));
+    GTK_WIDGET_UNSET_FLAGS(appGUI->opt->cn_remember_category_checkbutton, GTK_CAN_FOCUS);
+    gtk_widget_show (appGUI->opt->cn_remember_category_checkbutton);
+    gtk_box_pack_start (GTK_BOX (notes_opt_vbox), appGUI->opt->cn_remember_category_checkbutton, FALSE, FALSE, 4);
+    g_signal_connect (G_OBJECT (appGUI->opt->cn_remember_category_checkbutton), "toggled",
+                      G_CALLBACK (remember_notes_category_cb), appGUI);
+
+    appGUI->opt->cn_use_system_date_checkbutton = gtk_check_button_new_with_mnemonic (_("Use system format for date and time"));
+    GTK_WIDGET_UNSET_FLAGS(appGUI->opt->cn_use_system_date_checkbutton, GTK_CAN_FOCUS);
+    gtk_widget_show (appGUI->opt->cn_use_system_date_checkbutton);
+    gtk_box_pack_start (GTK_BOX (notes_opt_vbox), appGUI->opt->cn_use_system_date_checkbutton, FALSE, FALSE, 4);
+    g_signal_connect (G_OBJECT (appGUI->opt->cn_use_system_date_checkbutton), "toggled",
+                      G_CALLBACK (use_system_date_cb), appGUI);
 }
 
 /*------------------------------------------------------------------------------*/
