@@ -19,17 +19,13 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#include "options_gui_tasks.h"
-#include "gui_utils.h"
+#include "utils.h"
 #include "calendar.h"
-#include "calendar_notes.h"
-#include "calendar_widget.h"
 #include "i18n.h"
 #include "tasks.h"
 #include "options_gui.h"
-#include "options_gui_calendar.h"
+#include "options_gui_tasks.h"
 #include "options_prefs.h"
-#include "contacts.h"
 #include "stock_icons.h"
 
 /*------------------------------------------------------------------------------*/
@@ -110,6 +106,14 @@ add_item_cb (GtkToggleButton *togglebutton, gpointer user_data) {
 
 /*------------------------------------------------------------------------------*/
 
+void
+remember_category_cb (GtkToggleButton *togglebutton, gpointer user_data) {
+
+    config.remember_category_in_tasks = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (togglebutton));
+}
+
+/*------------------------------------------------------------------------------*/
+
 gboolean
 tasks_category_get_state (gchar *category_name, gint type, GUI *appGUI) {
 
@@ -439,8 +443,8 @@ GtkTreeModel *model;
         gtk_tree_model_get_iter (model, &iter, path);   /* get toggled iter */
         gtk_tree_model_get (model, &iter, TC_COLUMN_CALENDAR, &done_status, -1);
         gtk_list_store_set (GTK_LIST_STORE(model), &iter, TC_COLUMN_CALENDAR, !done_status, -1);
-        set_day_info (appGUI->cal->day, appGUI->cal->month, appGUI->cal->year, appGUI);
-        calendar_refresh_marks (appGUI);
+        cal_set_day_info (appGUI);
+        cal_refresh_marks (appGUI);
         gtk_tree_path_free (path);
     }
 }
@@ -471,6 +475,21 @@ GtkTreeModel *model;
 
 /*------------------------------------------------------------------------------*/
 
+gint
+global_notification_entry_key_release_cb (GtkWidget *widget, GdkEventKey *event, gpointer user_data)
+{
+	GUI *appGUI = (GUI *) user_data;
+    gui_update_command_status (appGUI->opt->global_notification_cmd_entry, 
+                               appGUI->opt->global_notification_valid_image, appGUI);
+    
+	g_strlcpy (config.global_notification_command, 
+               gtk_entry_get_text(GTK_ENTRY(appGUI->opt->global_notification_cmd_entry)), MAXHELPERCMD);
+
+	return FALSE;
+}
+
+/*------------------------------------------------------------------------------*/
+
 void
 gui_create_tasks_options_page   (GtkWidget *vbox, GUI *appGUI) {
 
@@ -478,6 +497,7 @@ GtkWidget           *appearance_vbox, *categories_vbox;
 GtkWidget           *sorting_vbox, *tasks_opt_vbox, *visible_columns_vbox;
 GtkWidget           *label;
 GtkWidget           *colors_hbox;
+GtkWidget           *valid_hbox;
 GtkWidget           *frame;
 GtkWidget           *table;
 GtkWidget           *alignment;
@@ -515,7 +535,7 @@ gchar tmpbuf[BUFFER_SIZE];
     gtk_widget_show (appearance_vbox);
     gtk_container_add (GTK_CONTAINER (alignment), appearance_vbox);
 
-    table = gtk_table_new (3, 4, FALSE);
+    table = gtk_table_new (4, 4, FALSE);
     gtk_widget_show (table);
     gtk_box_pack_start (GTK_BOX (appearance_vbox), table, FALSE, FALSE, 0);
     gtk_table_set_col_spacings (GTK_TABLE (table), 4);
@@ -599,6 +619,15 @@ gchar tmpbuf[BUFFER_SIZE];
                       (GtkAttachOptions) (GTK_FILL),
                       (GtkAttachOptions) (0), 0, 0);
 
+    appGUI->opt->ct_bold_items_checkbutton = gtk_check_button_new_with_mnemonic (_("Show in bold tasks with high priority"));
+    GTK_WIDGET_UNSET_FLAGS(appGUI->opt->ct_bold_items_checkbutton, GTK_CAN_FOCUS);
+    gtk_widget_show (appGUI->opt->ct_bold_items_checkbutton);
+    gtk_table_attach (GTK_TABLE (table), appGUI->opt->ct_bold_items_checkbutton, 0, 3, 3, 4,
+                      (GtkAttachOptions) (GTK_FILL),
+                      (GtkAttachOptions) (0), 0, 0);
+    g_signal_connect (G_OBJECT (appGUI->opt->ct_bold_items_checkbutton), "toggled",
+                      G_CALLBACK (bold_items_cb), appGUI);
+
     frame = gtk_frame_new (NULL);
     gtk_widget_show (frame);
     gtk_box_pack_start (GTK_BOX (appGUI->opt->tasks_vbox), frame, FALSE, TRUE, 0);
@@ -861,13 +890,6 @@ gchar tmpbuf[BUFFER_SIZE];
     gtk_widget_show (tasks_opt_vbox);
     gtk_container_add (GTK_CONTAINER (alignment), tasks_opt_vbox);
 
-    appGUI->opt->ct_bold_items_checkbutton = gtk_check_button_new_with_mnemonic (_("Show in bold tasks with high priority"));
-    GTK_WIDGET_UNSET_FLAGS(appGUI->opt->ct_bold_items_checkbutton, GTK_CAN_FOCUS);
-    gtk_widget_show (appGUI->opt->ct_bold_items_checkbutton);
-    gtk_box_pack_start (GTK_BOX (tasks_opt_vbox), appGUI->opt->ct_bold_items_checkbutton, FALSE, FALSE, 4);
-    g_signal_connect (G_OBJECT (appGUI->opt->ct_bold_items_checkbutton), "toggled",
-                      G_CALLBACK (bold_items_cb), appGUI);
-
     appGUI->opt->ct_hide_items_checkbutton = gtk_check_button_new_with_mnemonic (_("Hide completed tasks"));
     GTK_WIDGET_UNSET_FLAGS(appGUI->opt->ct_hide_items_checkbutton, GTK_CAN_FOCUS);
     gtk_widget_show (appGUI->opt->ct_hide_items_checkbutton);
@@ -893,6 +915,13 @@ gchar tmpbuf[BUFFER_SIZE];
     g_signal_connect (G_OBJECT (appGUI->opt->ct_add_item_checkbutton), "toggled",
                       G_CALLBACK (add_item_cb), appGUI);
 
+    appGUI->opt->ct_remember_category_checkbutton = gtk_check_button_new_with_mnemonic (_("Remember the last selected category"));
+    GTK_WIDGET_UNSET_FLAGS(appGUI->opt->ct_remember_category_checkbutton, GTK_CAN_FOCUS);
+    gtk_widget_show (appGUI->opt->ct_remember_category_checkbutton);
+    gtk_box_pack_start (GTK_BOX (tasks_opt_vbox), appGUI->opt->ct_remember_category_checkbutton, FALSE, FALSE, 4);
+    g_signal_connect (G_OBJECT (appGUI->opt->ct_remember_category_checkbutton), "toggled",
+                      G_CALLBACK (remember_category_cb), appGUI);
+
     frame = gtk_frame_new (NULL);
     gtk_widget_show (frame);
     gtk_box_pack_start (GTK_BOX (appGUI->opt->tasks_vbox), frame, FALSE, TRUE, 0);
@@ -909,7 +938,7 @@ gchar tmpbuf[BUFFER_SIZE];
     gtk_container_add (GTK_CONTAINER (frame), alignment);
     gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 12, 12, 0);
 
-    table = gtk_table_new (1, 4, FALSE);
+    table = gtk_table_new (2, 4, FALSE);
     gtk_widget_show (table);
     gtk_container_add (GTK_CONTAINER (alignment), table);
     gtk_container_set_border_width (GTK_CONTAINER (table), 4);
@@ -944,6 +973,29 @@ gchar tmpbuf[BUFFER_SIZE];
                       (GtkAttachOptions) (0), 0, 0);
     gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 
+    g_snprintf (tmpbuf, BUFFER_SIZE, "%s:", _("Global notification command"));
+    label = gtk_label_new (tmpbuf);
+    gtk_widget_show (label);
+    gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2,
+                      (GtkAttachOptions) (GTK_FILL),
+                      (GtkAttachOptions) (0), 0, 0);
+    gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+
+    valid_hbox = gtk_hbox_new (FALSE, 2);
+    gtk_widget_show (valid_hbox);
+    gtk_table_attach (GTK_TABLE (table), valid_hbox, 1, 3, 1, 2,
+                    (GtkAttachOptions) (GTK_FILL | GTK_EXPAND),
+                    (GtkAttachOptions) (GTK_FILL), 0, 0);
+
+    appGUI->opt->global_notification_cmd_entry = gtk_entry_new ();
+    gtk_widget_show (appGUI->opt->global_notification_cmd_entry);
+    g_signal_connect (G_OBJECT (appGUI->opt->global_notification_cmd_entry), "key_release_event",
+                      G_CALLBACK (global_notification_entry_key_release_cb), appGUI);
+    gtk_box_pack_start (GTK_BOX (valid_hbox), appGUI->opt->global_notification_cmd_entry, TRUE, TRUE, 0);
+
+    appGUI->opt->global_notification_valid_image = gtk_image_new ();
+    gtk_widget_show (appGUI->opt->global_notification_valid_image);
+    gtk_box_pack_start (GTK_BOX (valid_hbox), appGUI->opt->global_notification_valid_image, FALSE, FALSE, 0);
 }
 
 /*------------------------------------------------------------------------------*/
