@@ -45,6 +45,7 @@ struct osmo_prefs
     gint        latest_tab;
     gint        tabs_position;
     gint        remember_latest_tab;
+    gint        save_data_after_modification;
     gint        default_stock_icons;
     gint        disable_underline_links;
     gint        date_format;
@@ -92,6 +93,7 @@ struct osmo_prefs
     gint        event_marker_type;
     gint        today_marker_type;
     gint        day_notes_browser_filter;
+    gint        ical_export_pane_pos;
     gchar       header_color[MAXCOLORNAME];
     gchar       weekend_color[MAXCOLORNAME];
     gchar       selection_color[MAXCOLORNAME];
@@ -109,6 +111,8 @@ struct osmo_prefs
     gint        hide_completed;
     gint        delete_completed;
     gint        add_edit;
+    gint        remember_category_in_tasks;
+    gint        current_category_in_tasks;
     gint        tasks_pane_pos;
     gint        tasks_sorting_order;
     gint        tasks_sorting_mode;
@@ -125,6 +129,7 @@ struct osmo_prefs
     gchar       due_7days_color[MAXCOLORNAME];
     gchar       past_due_color[MAXCOLORNAME];
     gchar       task_info_font[MAXFONTNAME];
+    gchar       global_notification_command[MAXHELPERCMD];
 
     /* CONTACTS */
     gint        find_mode;
@@ -133,6 +138,9 @@ struct osmo_prefs
     gint        contacts_pane_pos;
     gint        contacts_rules_hint;
     gint        photo_width;
+    gint        visible_age_column;
+    gint        visible_birthday_date_column;
+    gint        visible_zodiac_sign_column;
     gint        contacts_sorting_order;
     gint        contacts_sorting_mode;
     gint        contacts_addedit_win_x;
@@ -149,6 +157,8 @@ struct osmo_prefs
     gint        contacts_import_win_y;
     gint        contacts_import_win_w;
     gint        contacts_import_win_h;
+    gint        contacts_birthdays_win_w;
+    gint        contacts_birthdays_win_h;
     gchar       contact_tag_color[MAXCOLORNAME];
     gchar       contact_link_color[MAXCOLORNAME];
     gchar       contact_name_font[MAXFONTNAME];
@@ -170,6 +180,10 @@ struct osmo_prefs
     gint        notes_comp_ratio;
     gint        notes_sorting_order;
     gint        notes_sorting_mode;
+    gint        remember_category_in_notes;
+    gint        current_category_in_notes;
+    gint        use_system_date_in_notes;
+    gchar       text_separator;
     gchar       notes_editor_font[MAXFONTNAME];
 };
 
