@@ -78,6 +78,9 @@ GtkStockItem osmo_stock_items[] = {
     { (gchar*) OSMO_STOCK_EDITOR_CLEAR,            (gchar*) N_("Clear"),                        0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_EDITOR_FIND,             (gchar*) N_("Find"),                         0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_EDITOR_HIGHLIGHT,        (gchar*) N_("Highlight"),                    0, 0, TRANSLATION_DOMAIN },
+    { (gchar*) OSMO_STOCK_EDITOR_INFO,             (gchar*) N_("Info"),                         0, 0, TRANSLATION_DOMAIN },
+    { (gchar*) OSMO_STOCK_EDITOR_INSERT_DATE_TIME, (gchar*) N_("Insert current date and time"), 0, 0, TRANSLATION_DOMAIN },
+    { (gchar*) OSMO_STOCK_EDITOR_INSERT_SEPARATOR, (gchar*) N_("Insert separator"),             0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_EDITOR_ITALIC,           (gchar*) N_("Italic"),                       0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_EDITOR_SAVE,             (gchar*) N_("Save"),                         0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_EDITOR_STRIKETHROUGH,    (gchar*) N_("Strikethrough"),                0, 0, TRANSLATION_DOMAIN },
@@ -108,6 +111,7 @@ GtkStockItem osmo_stock_items[] = {
     { (gchar*) OSMO_STOCK_TASKS_TYPE_RECURRENT,    (gchar*) N_("Recurrent task"),               0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_TASKS,                   (gchar*) N_("Tasks"),                        0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_TODAY,                   (gchar*) N_("Today"),                        0, 0, TRANSLATION_DOMAIN },
+    { (gchar*) OSMO_STOCK_PRINT,                   (gchar*) N_("Print"),                        0, 0, TRANSLATION_DOMAIN }
 };
 
 const guint8* osmo_stock_item_data[] = {
@@ -154,6 +158,9 @@ const guint8* osmo_stock_item_data[] = {
     (const guint8*) osmo_stock_editor_clear,
     (const guint8*) osmo_stock_editor_find,
     (const guint8*) osmo_stock_editor_highlight,
+    (const guint8*) osmo_stock_editor_info,
+    (const guint8*) osmo_stock_editor_insert_date_time,
+    (const guint8*) osmo_stock_editor_insert_separator,
     (const guint8*) osmo_stock_editor_italic,
     (const guint8*) osmo_stock_editor_save,
     (const guint8*) osmo_stock_editor_strikethrough,
@@ -184,6 +191,7 @@ const guint8* osmo_stock_item_data[] = {
     (const guint8*) osmo_stock_tasks_type_recurrent,
     (const guint8*) osmo_stock_tasks,
     (const guint8*) osmo_stock_today,
+    (const guint8*) osmo_stock_print
 };
 
     gtk_stock_add (osmo_stock_items, G_N_ELEMENTS (osmo_stock_items));
