@@ -66,6 +66,9 @@
 #define     OSMO_STOCK_EDITOR_CLEAR             "osmo-editor-clear"
 #define     OSMO_STOCK_EDITOR_FIND              "osmo-editor-find"
 #define     OSMO_STOCK_EDITOR_HIGHLIGHT         "osmo-editor-highlight"
+#define     OSMO_STOCK_EDITOR_INFO              "osmo-editor-info"
+#define     OSMO_STOCK_EDITOR_INSERT_DATE_TIME  "osmo-editor-insert_date_time"
+#define     OSMO_STOCK_EDITOR_INSERT_SEPARATOR  "osmo-editor-insert_separator"
 #define     OSMO_STOCK_EDITOR_ITALIC            "osmo-editor-italic"
 #define     OSMO_STOCK_EDITOR_SAVE              "osmo-editor-save"
 #define     OSMO_STOCK_EDITOR_STRIKETHROUGH     "osmo-editor-strikethrough"
@@ -96,6 +99,7 @@
 #define     OSMO_STOCK_TASKS_TYPE_RECURRENT     "osmo-tasks-type-recurrent"
 #define     OSMO_STOCK_TASKS                    "osmo-tasks"
 #define     OSMO_STOCK_TODAY                    "osmo-today"
+#define     OSMO_STOCK_PRINT                    "osmo-print"
 
 void    osmo_register_stock_icons   (void);
 
