@@ -20,12 +20,13 @@
  */
 
 #include "tasks.h"
-#include "gui_utils.h"
 #include "i18n.h"
 #include "tasks_items.h"
+#include "tasks_print.h"
 #include "calendar.h"
 #include "calendar_widget.h"
 #include "calendar_utils.h"
+#include "utils.h"
 #include "options_prefs.h"
 #include "options_gui_tasks.h"
 #include "stock_icons.h"
@@ -57,18 +58,15 @@ gint i;
 
 /*------------------------------------------------------------------------------*/
 
-gchar*
-get_priority_text (gint index) {
-
+gchar* 
+get_priority_text (gint index)
+{
 gchar *priority_table[] = {
     N_("Low"), N_("Medium"), N_("High")
 };
 
-    if (index >=0 && index <= 2) {
-        return gettext(priority_table[index]);
-    } else {
-        return NULL;
-    }
+	g_return_val_if_fail (index >=0 && index <= 2, NULL);
+	return gettext (priority_table[index]);
 }
 
 /*------------------------------------------------------------------------------*/
@@ -83,7 +81,7 @@ gint i, j;
 
 	if (month_mode == TRUE) {
 
-		days_in_month = get_days_in_month (cdate);
+		days_in_month = utl_get_days_in_month (cdate);
 		start_day = g_date_get_day (cdate);
 
 		for (i = 0; i < 7; i++) {
@@ -130,7 +128,7 @@ gboolean repeat_time, repeat_date, set_start_time;
 	set_start_time = TRUE;
 
 	cycles = 0;
-	current_julian = get_gdate_current_julian ();
+	current_julian = utl_get_current_julian ();
 	current_time = get_seconds_for_today ();
 	*new_date = item->due_date_julian;
 	*new_time = item->due_time;
@@ -165,7 +163,7 @@ gboolean repeat_time, repeat_date, set_start_time;
 			g_date_add_days (cdate, item->repeat_day_interval);
 
 			if (item->repeat_month_interval > 0 && item->repeat_day_interval == 0) {
-				days_in_month = get_days_in_month (cdate);
+				days_in_month = utl_get_days_in_month (cdate);
 
 				if (item->repeat_start_day > days_in_month) {
 					g_date_set_day (cdate, days_in_month);
@@ -323,7 +321,7 @@ GtkTextIter titer;
 GtkTextBuffer *text_buffer;
 GtkTextChildAnchor *anchor;
 GtkWidget *hseparator;
-guint32 start_date_julian, due_date_julian;
+guint32 start_date_julian, done_date_julian, due_date_julian;
 gint due_time;
 gchar tmpbuf[BUFFER_SIZE];
 gboolean repeat, prev_state, next_state;
@@ -341,12 +339,13 @@ gboolean repeat, prev_state, next_state;
         gtk_tree_model_get (model, &iter, TA_COLUMN_DESCRIPTION, &text,
                             TA_COLUMN_DUE_DATE_JULIAN, &due_date_julian,
                             TA_COLUMN_START_DATE_JULIAN, &start_date_julian,
+                            TA_COLUMN_DONE_DATE_JULIAN, &done_date_julian,
                             TA_COLUMN_DUE_TIME, &due_time,
                             TA_COLUMN_REPEAT, &repeat, -1);
 
 		if (repeat == TRUE) {
 			prev_state = FALSE;
-			next_state = is_date_in_the_past (due_date_julian, due_time, get_julian_for_today (), get_seconds_for_today ());
+			next_state = is_date_in_the_past (due_date_julian, due_time, utl_get_current_julian (), get_seconds_for_today ());
 		} else {
 			prev_state = next_state = (due_date_julian != 0) ? TRUE : FALSE;
 		}
@@ -354,7 +353,8 @@ gboolean repeat, prev_state, next_state;
         gtk_widget_set_sensitive (gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/prev_day"), prev_state);
         gtk_widget_set_sensitive (gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/next_day"), next_state);
 
-        g_snprintf (tmpbuf, BUFFER_SIZE, "\n%s: %s\n", _("Started"), julian_to_str (start_date_julian, DATE_FULL));
+        g_snprintf (tmpbuf, BUFFER_SIZE, "\n%s: %s\n", 
+                    _("Started"), julian_to_str (start_date_julian, DATE_FULL));
 
         if (text != NULL) {
             gtk_text_buffer_insert_with_tags_by_name (text_buffer, &titer, text, -1,
@@ -367,11 +367,18 @@ gboolean repeat, prev_state, next_state;
             anchor = gtk_text_buffer_create_child_anchor (text_buffer, &titer);
             gtk_text_buffer_insert_with_tags_by_name (text_buffer, &titer, tmpbuf, -1, 
                                                       "italic", NULL);
+            if (done_date_julian != 0) {
+                g_snprintf (tmpbuf, BUFFER_SIZE, "%s: %s\n", 
+                            _("Finished"), julian_to_str (done_date_julian, DATE_FULL));
+                gtk_text_buffer_insert_with_tags_by_name (text_buffer, &titer, tmpbuf, -1, 
+                                                          "italic", NULL);
+            }
+
             gtk_text_view_set_buffer(GTK_TEXT_VIEW(appGUI->tsk->tasks_desc_textview), text_buffer);
 
             hseparator = gtk_hseparator_new ();
             gtk_widget_show (hseparator);
-            gtk_widget_set_size_request (hseparator, 240, -1);
+            gtk_widget_set_size_request (hseparator, 320, -1);
             gtk_text_view_add_child_at_anchor (GTK_TEXT_VIEW(appGUI->tsk->tasks_desc_textview), hseparator, anchor);
         }
 
@@ -470,12 +477,22 @@ tasks_change_due_date_to_next_day_cb (GtkWidget *widget, gpointer data) {
 
 /*------------------------------------------------------------------------------*/
 
+void
+tasks_print_visible_items_cb (GtkWidget *widget, gpointer data) {
+
+    GUI *appGUI = (GUI *)data;
+    tasks_print (appGUI);
+}
+
+/*------------------------------------------------------------------------------*/
+
 void
 done_toggled (GtkCellRendererToggle *cell, gchar *path_str, gpointer user_data)
 {
 GtkTreePath *sort_path, *filter_path, *path;
 GtkTreeIter  iter;
 gboolean done_status;
+guint32 done_date;
 GtkTreeModel *model;
 
     GUI *appGUI = (GUI *) user_data;
@@ -492,7 +509,16 @@ GtkTreeModel *model;
             if (path != NULL) {
                 gtk_tree_model_get_iter (model, &iter, path);   /* get toggled iter */
                 gtk_tree_model_get (model, &iter, TA_COLUMN_DONE, &done_status, -1);
-                gtk_list_store_set (GTK_LIST_STORE (model), &iter, TA_COLUMN_DONE, !done_status, -1);
+
+                if (done_status == FALSE) {
+                    done_date = utl_get_current_julian ();
+                } else {
+                    done_date = 0;
+                }
+
+                gtk_list_store_set (GTK_LIST_STORE (model), &iter, 
+                                    TA_COLUMN_DONE, !done_status, 
+                                    TA_COLUMN_DONE_DATE_JULIAN, done_date, -1);
 
                 if (done_status == FALSE && config.delete_completed) {
                     gtk_list_store_remove (GTK_LIST_STORE (model), &iter);
@@ -508,7 +534,7 @@ GtkTreeModel *model;
     }
 
     apply_task_attributes (appGUI);
-    set_day_info (appGUI->cal->day, appGUI->cal->month, appGUI->cal->year, appGUI);
+    cal_set_day_info (appGUI);
 }
 
 /*------------------------------------------------------------------------------*/
@@ -525,7 +551,7 @@ gint32 r;
 
 	if (julian_day != 0 && done == FALSE) {
 
-		r = julian_day - get_julian_for_today ();
+		r = julian_day - utl_get_current_julian ();
 
 		if (r == 0) {
 			if (time >= 0 && current_time > time) {
@@ -607,7 +633,11 @@ gboolean done, tasks_state;
         g_free(category);
     }
 
-    gtk_combo_box_set_active (GTK_COMBO_BOX(appGUI->tsk->cf_combobox), 0);
+    if (config.remember_category_in_tasks == TRUE) {
+        gtk_combo_box_set_active (GTK_COMBO_BOX(appGUI->tsk->cf_combobox), config.current_category_in_tasks);
+    } else {
+        gtk_combo_box_set_active (GTK_COMBO_BOX(appGUI->tsk->cf_combobox), 0);
+    }
 
     i = 0;
 
@@ -645,8 +675,10 @@ gchar tmpbuf[BUFFER_SIZE];
 
 	if (i > 0) {
 		g_snprintf (tmpbuf, BUFFER_SIZE, "<i>%4d %s</i>", i, ngettext ("entry", "entries", i));
+        gtk_widget_set_sensitive(gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/print"), TRUE);
 	} else {
 		g_snprintf (tmpbuf, BUFFER_SIZE, "<i>%s</i>", _("no entries"));
+        gtk_widget_set_sensitive(gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/print"), FALSE);
 	}
 
 	gtk_label_set_markup (GTK_LABEL (appGUI->tsk->n_items_label), tmpbuf);
@@ -668,6 +700,7 @@ const gchar *stock_id;
 	gtk_list_store_set (appGUI->tsk->tasks_list_store, &iter, TA_COLUMN_DONE, item->done,
 	                    TA_COLUMN_DUE_DATE_JULIAN, item->due_date_julian,
 	                    TA_COLUMN_START_DATE_JULIAN, item->start_date_julian,
+	                    TA_COLUMN_DONE_DATE_JULIAN, item->done_date_julian,
 	                    TA_COLUMN_DUE_TIME, item->due_time,
 	                    TA_COLUMN_PRIORITY, item->priority, TA_COLUMN_CATEGORY, item->category,
 	                    TA_COLUMN_SUMMARY, item->summary, TA_COLUMN_DESCRIPTION, item->desc,
@@ -993,6 +1026,8 @@ gchar tmpbuf[BUFFER_SIZE];
 "    <separator name=\"sep2\" />\n"
 "    <toolitem name=\"prev_day\" action=\"prev_day\" />\n"
 "    <toolitem name=\"next_day\" action=\"next_day\" />\n"
+"    <separator name=\"sep3\" />\n"
+"    <toolitem name=\"print\" action=\"print\" />\n"
 "  </toolbar>\n";
 
 GtkActionEntry entries[] = {
@@ -1001,6 +1036,7 @@ GtkActionEntry entries[] = {
   { "delete", OSMO_STOCK_TASKS_REMOVE, _("Remove task"), NULL, _("Remove task"), NULL },
   { "prev_day", OSMO_STOCK_TASKS_PREV_DAY, _("Change due date to previous day"), NULL, _("Change due date to previous day"), NULL },
   { "next_day", OSMO_STOCK_TASKS_NEXT_DAY, _("Change due date to next day"), NULL, _("Change due date to next day"), NULL },
+  { "print", OSMO_STOCK_PRINT, _("Print visible tasks list"), NULL, _("Print visible tasks list"), NULL },
 };
 
 guint n_entries = G_N_ELEMENTS (entries);
@@ -1052,6 +1088,8 @@ guint n_entries = G_N_ELEMENTS (entries);
                       G_CALLBACK(tasks_change_due_date_to_prev_day_cb), appGUI);
     g_signal_connect (G_OBJECT(gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/next_day")), "clicked", 
                       G_CALLBACK(tasks_change_due_date_to_next_day_cb), appGUI);
+    g_signal_connect (G_OBJECT(gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/print")), "clicked", 
+                      G_CALLBACK(tasks_print_visible_items_cb), appGUI);
 
     /*-------------------------------------------------------------------------------------*/
 
@@ -1059,6 +1097,7 @@ guint n_entries = G_N_ELEMENTS (entries);
     gtk_widget_set_sensitive(gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/delete"), FALSE);
     gtk_widget_set_sensitive(gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/prev_day"), FALSE);
     gtk_widget_set_sensitive(gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/next_day"), FALSE);
+    gtk_widget_set_sensitive(gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/print"), FALSE);
 
     hseparator = gtk_hseparator_new ();
     gtk_widget_show (hseparator);
@@ -1081,9 +1120,15 @@ guint n_entries = G_N_ELEMENTS (entries);
     gtk_widget_show (appGUI->tsk->cf_combobox);
     gtk_combo_box_set_focus_on_click (GTK_COMBO_BOX (appGUI->tsk->cf_combobox), FALSE);
     GTK_WIDGET_UNSET_FLAGS(appGUI->tsk->cf_combobox, GTK_CAN_FOCUS);
-    gtk_table_attach (GTK_TABLE (table), appGUI->tsk->cf_combobox, 1, 2, 0, 1,
-                     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
-                     (GtkAttachOptions) (GTK_FILL), 0, 0);
+    if (appGUI->tiny_gui == TRUE) {
+        gtk_table_attach (GTK_TABLE (table), appGUI->tsk->cf_combobox, 1, 2, 0, 1,
+                         (GtkAttachOptions) (0),
+                         (GtkAttachOptions) (0), 0, 0);
+    } else {
+        gtk_table_attach (GTK_TABLE (table), appGUI->tsk->cf_combobox, 1, 2, 0, 1,
+                         (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
+                         (GtkAttachOptions) (GTK_FILL), 0, 0);
+    }
     g_signal_connect(G_OBJECT(appGUI->tsk->cf_combobox), "changed", 
                      G_CALLBACK(category_filter_cb), appGUI);
     g_signal_connect(G_OBJECT(appGUI->tsk->cf_combobox), "focus", 
@@ -1091,7 +1136,9 @@ guint n_entries = G_N_ELEMENTS (entries);
 
     appGUI->tsk->n_items_label = gtk_label_new ("");
     gtk_widget_show (appGUI->tsk->n_items_label);
-    gtk_widget_set_size_request (appGUI->tsk->n_items_label, 100, -1);
+    if (appGUI->tiny_gui == FALSE) {
+        gtk_widget_set_size_request (appGUI->tsk->n_items_label, 100, -1);
+    }
     gtk_table_attach (GTK_TABLE (table), appGUI->tsk->n_items_label, 3, 4, 0, 1,
                      (GtkAttachOptions) (GTK_FILL),
                      (GtkAttachOptions) (0), 0, 0);
@@ -1122,7 +1169,7 @@ guint n_entries = G_N_ELEMENTS (entries);
 
 	appGUI->tsk->tasks_list_store = gtk_list_store_new (TASKS_NUM_COLUMNS,
 	                                    G_TYPE_BOOLEAN, GDK_TYPE_PIXBUF, G_TYPE_STRING, G_TYPE_UINT, G_TYPE_INT,
-	                                    G_TYPE_UINT, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
+	                                    G_TYPE_UINT, G_TYPE_UINT, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
 	                                    G_TYPE_STRING, G_TYPE_STRING, G_TYPE_UINT, G_TYPE_BOOLEAN,
 	                                    G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_INT,
 	                                    G_TYPE_INT, G_TYPE_INT, G_TYPE_INT, G_TYPE_INT, G_TYPE_INT, G_TYPE_INT,
@@ -1212,6 +1259,17 @@ guint n_entries = G_N_ELEMENTS (entries);
     gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[TA_COLUMN_START_DATE_JULIAN], FALSE);
     gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_START_DATE_JULIAN]);
 
+    renderer = gtk_cell_renderer_text_new();
+    appGUI->tsk->tasks_columns[TA_COLUMN_DONE_DATE_JULIAN] = gtk_tree_view_column_new_with_attributes(NULL,
+                              renderer,
+                              "text", TA_COLUMN_DONE_DATE_JULIAN,
+                              "strikethrough", TA_COLUMN_DONE,
+                              "foreground", TA_COLUMN_COLOR,
+                              "weight", TA_COLUMN_BOLD,
+                              NULL);
+    gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[TA_COLUMN_DONE_DATE_JULIAN], FALSE);
+    gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_DONE_DATE_JULIAN]);
+
     renderer = gtk_cell_renderer_text_new();
     appGUI->tsk->tasks_columns[TA_COLUMN_PRIORITY] = gtk_tree_view_column_new_with_attributes(_("Priority"),
                               renderer,
@@ -1235,8 +1293,8 @@ guint n_entries = G_N_ELEMENTS (entries);
     gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_CATEGORY]);
 
     renderer = gtk_cell_renderer_text_new();
-    g_object_set(G_OBJECT(renderer), "ellipsize", PANGO_ELLIPSIZE_END, NULL);
-    gtk_cell_renderer_set_fixed_size(renderer, 0, -1);
+    g_object_set (G_OBJECT(renderer), "ellipsize", PANGO_ELLIPSIZE_END, NULL);
+    gtk_cell_renderer_set_fixed_size (renderer, 0, -1);
     appGUI->tsk->tasks_columns[TA_COLUMN_SUMMARY] = gtk_tree_view_column_new_with_attributes(_("Summary"),
                               renderer,
                               "text", TA_COLUMN_SUMMARY,
@@ -1244,7 +1302,7 @@ guint n_entries = G_N_ELEMENTS (entries);
                               "foreground", TA_COLUMN_COLOR,
                               "weight", TA_COLUMN_BOLD,
                               NULL);
-    gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_SUMMARY]);
+    gtk_tree_view_append_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_SUMMARY]);
 
 
     renderer = gtk_cell_renderer_text_new();
@@ -1253,7 +1311,7 @@ guint n_entries = G_N_ELEMENTS (entries);
                               "text", TA_COLUMN_DESCRIPTION,
                               NULL);
     gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[TA_COLUMN_DESCRIPTION], FALSE);
-    gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_DESCRIPTION]);
+    gtk_tree_view_append_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_DESCRIPTION]);
 
     renderer = gtk_cell_renderer_text_new();
     appGUI->tsk->tasks_columns[TA_COLUMN_COLOR] = gtk_tree_view_column_new_with_attributes(NULL,
@@ -1261,7 +1319,7 @@ guint n_entries = G_N_ELEMENTS (entries);
                               "text", TA_COLUMN_COLOR,
                               NULL);
     gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[TA_COLUMN_COLOR], FALSE);
-    gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_COLOR]);
+    gtk_tree_view_append_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_COLOR]);
 
     renderer = gtk_cell_renderer_text_new();
     appGUI->tsk->tasks_columns[TA_COLUMN_BOLD] = gtk_tree_view_column_new_with_attributes(NULL,
@@ -1269,7 +1327,7 @@ guint n_entries = G_N_ELEMENTS (entries);
                               "text", TA_COLUMN_BOLD,
                               NULL);
     gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[TA_COLUMN_BOLD], FALSE);
-    gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_BOLD]);
+    gtk_tree_view_append_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_BOLD]);
 
     renderer = gtk_cell_renderer_toggle_new();
     appGUI->tsk->tasks_columns[TA_COLUMN_ACTIVE] = gtk_tree_view_column_new_with_attributes (NULL,
@@ -1301,7 +1359,7 @@ guint n_entries = G_N_ELEMENTS (entries);
                               "text", TA_COLUMN_REPEAT_DAY,
                               NULL);
     gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[TA_COLUMN_REPEAT_DAY], FALSE);
-    gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_REPEAT_DAY]);
+    gtk_tree_view_append_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_REPEAT_DAY]);
 
 	renderer = gtk_cell_renderer_text_new();
     appGUI->tsk->tasks_columns[TA_COLUMN_REPEAT_MONTH_INTERVAL] = gtk_tree_view_column_new_with_attributes(NULL,
@@ -1309,7 +1367,7 @@ guint n_entries = G_N_ELEMENTS (entries);
                               "text", TA_COLUMN_REPEAT_MONTH_INTERVAL,
                               NULL);
     gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[TA_COLUMN_REPEAT_MONTH_INTERVAL], FALSE);
-    gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_REPEAT_MONTH_INTERVAL]);
+    gtk_tree_view_append_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_REPEAT_MONTH_INTERVAL]);
 
 	renderer = gtk_cell_renderer_text_new();
     appGUI->tsk->tasks_columns[TA_COLUMN_REPEAT_DAY_INTERVAL] = gtk_tree_view_column_new_with_attributes(NULL,
@@ -1317,7 +1375,7 @@ guint n_entries = G_N_ELEMENTS (entries);
                               "text", TA_COLUMN_REPEAT_DAY_INTERVAL,
                               NULL);
     gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[TA_COLUMN_REPEAT_DAY_INTERVAL], FALSE);
-    gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_REPEAT_DAY_INTERVAL]);
+    gtk_tree_view_append_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_REPEAT_DAY_INTERVAL]);
 
 	renderer = gtk_cell_renderer_text_new();
     appGUI->tsk->tasks_columns[TA_COLUMN_REPEAT_START_DAY] = gtk_tree_view_column_new_with_attributes(NULL,
@@ -1333,7 +1391,7 @@ guint n_entries = G_N_ELEMENTS (entries);
                               "text", TA_COLUMN_REPEAT_TIME_START,
                               NULL);
     gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[TA_COLUMN_REPEAT_TIME_START], FALSE);
-    gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_REPEAT_TIME_START]);
+    gtk_tree_view_append_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_REPEAT_TIME_START]);
 
 	renderer = gtk_cell_renderer_text_new();
     appGUI->tsk->tasks_columns[TA_COLUMN_REPEAT_TIME_END] = gtk_tree_view_column_new_with_attributes(NULL,
@@ -1341,7 +1399,7 @@ guint n_entries = G_N_ELEMENTS (entries);
                               "text", TA_COLUMN_REPEAT_TIME_END,
                               NULL);
     gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[TA_COLUMN_REPEAT_TIME_END], FALSE);
-    gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_REPEAT_TIME_END]);
+    gtk_tree_view_append_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_REPEAT_TIME_END]);
 
 	renderer = gtk_cell_renderer_text_new();
     appGUI->tsk->tasks_columns[TA_COLUMN_REPEAT_TIME_INTERVAL] = gtk_tree_view_column_new_with_attributes(NULL,
@@ -1349,7 +1407,7 @@ guint n_entries = G_N_ELEMENTS (entries);
                               "text", TA_COLUMN_REPEAT_TIME_INTERVAL,
                               NULL);
     gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[TA_COLUMN_REPEAT_TIME_INTERVAL], FALSE);
-    gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_REPEAT_TIME_INTERVAL]);
+    gtk_tree_view_append_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_REPEAT_TIME_INTERVAL]);
 
 	renderer = gtk_cell_renderer_text_new();
     appGUI->tsk->tasks_columns[TA_COLUMN_REPEAT_COUNTER] = gtk_tree_view_column_new_with_attributes(NULL,
@@ -1357,7 +1415,7 @@ guint n_entries = G_N_ELEMENTS (entries);
                               "text", TA_COLUMN_REPEAT_COUNTER,
                               NULL);
     gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[TA_COLUMN_REPEAT_COUNTER], FALSE);
-    gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_REPEAT_COUNTER]);
+    gtk_tree_view_append_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_REPEAT_COUNTER]);
 
 	renderer = gtk_cell_renderer_text_new();
     appGUI->tsk->tasks_columns[TA_COLUMN_ALARM_COMMAND] = gtk_tree_view_column_new_with_attributes(NULL,
@@ -1365,7 +1423,7 @@ guint n_entries = G_N_ELEMENTS (entries);
                               "text", TA_COLUMN_ALARM_COMMAND,
                               NULL);
     gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[TA_COLUMN_ALARM_COMMAND], FALSE);
-    gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_ALARM_COMMAND]);
+    gtk_tree_view_append_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_ALARM_COMMAND]);
 
 	renderer = gtk_cell_renderer_text_new();
     appGUI->tsk->tasks_columns[TA_COLUMN_WARNING_DAYS] = gtk_tree_view_column_new_with_attributes(NULL,
@@ -1373,7 +1431,7 @@ guint n_entries = G_N_ELEMENTS (entries);
                               "text", TA_COLUMN_WARNING_DAYS,
                               NULL);
     gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[TA_COLUMN_WARNING_DAYS], FALSE);
-    gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_WARNING_DAYS]);
+    gtk_tree_view_append_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_WARNING_DAYS]);
 
 	renderer = gtk_cell_renderer_text_new();
     appGUI->tsk->tasks_columns[TA_COLUMN_WARNING_TIME] = gtk_tree_view_column_new_with_attributes(NULL,
@@ -1381,7 +1439,7 @@ guint n_entries = G_N_ELEMENTS (entries);
                               "text", TA_COLUMN_WARNING_TIME,
                               NULL);
     gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[TA_COLUMN_WARNING_TIME], FALSE);
-    gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_WARNING_TIME]);
+    gtk_tree_view_append_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_WARNING_TIME]);
 
     renderer = gtk_cell_renderer_text_new();
     appGUI->tsk->tasks_columns[TA_COLUMN_ID] = gtk_tree_view_column_new_with_attributes(NULL,
@@ -1389,7 +1447,7 @@ guint n_entries = G_N_ELEMENTS (entries);
                               "text", TA_COLUMN_ID,
                               NULL);
     gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[TA_COLUMN_ID], FALSE);
-    gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_ID]);
+    gtk_tree_view_append_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_ID]);
 
     /* configure list options */
 
@@ -1398,12 +1456,15 @@ guint n_entries = G_N_ELEMENTS (entries);
 
     /* configure sorting */
 
-    gtk_tree_sortable_set_sort_func((GtkTreeSortable *)appGUI->tsk->tasks_sort, 0, 
-                                    (GtkTreeIterCompareFunc)custom_tasks_sort_function, NULL, NULL);
+    gtk_tree_sortable_set_sort_func ((GtkTreeSortable *)appGUI->tsk->tasks_sort, 0, 
+                                     (GtkTreeIterCompareFunc)custom_tasks_sort_function, NULL, NULL);
 
-    gtk_tree_sortable_set_sort_column_id((GtkTreeSortable *)appGUI->tsk->tasks_sort, TA_COLUMN_DUE_DATE, config.tasks_sorting_order);
-    gtk_tree_sortable_set_sort_column_id((GtkTreeSortable *)appGUI->tsk->tasks_sort, TA_COLUMN_PRIORITY, config.tasks_sorting_order);
-    gtk_tree_sortable_set_sort_column_id((GtkTreeSortable *)appGUI->tsk->tasks_sort, TA_COLUMN_DONE, config.tasks_sorting_order);
+    gtk_tree_sortable_set_sort_column_id ((GtkTreeSortable *)appGUI->tsk->tasks_sort, 
+                                          TA_COLUMN_DUE_DATE, config.tasks_sorting_order);
+    gtk_tree_sortable_set_sort_column_id ((GtkTreeSortable *)appGUI->tsk->tasks_sort, 
+                                          TA_COLUMN_PRIORITY, config.tasks_sorting_order);
+    gtk_tree_sortable_set_sort_column_id ((GtkTreeSortable *)appGUI->tsk->tasks_sort, 
+                                          TA_COLUMN_DONE, config.tasks_sorting_order);
 
     /*----------------------------------------------------------------------------*/
 
